(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1184165,      32575]
NotebookOptionsPosition[   1164495,      31999]
NotebookOutlinePosition[   1165266,      32025]
CellTagsIndexPosition[   1165223,      32022]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Radiation from a D-dimensional collision of shock waves: Analytic Calculations\
\>", "Title",
 CellChangeTimes->{{3.576562826724646*^9, 3.576562853477954*^9}, 
   3.57656734124079*^9, {3.576568137711131*^9, 3.576568146522943*^9}, {
   3.576568178426497*^9, 3.576568185453454*^9}, 3.5765682192006407`*^9}],

Cell["Marco O. P. Sampaio", "Author",
 CellChangeTimes->{{3.57656766431563*^9, 3.5765677001589727`*^9}}],

Cell["Universidade de Aveiro", "Department",
 CellChangeTimes->{{3.576567711593129*^9, 3.576567725174079*^9}}],

Cell["NRHEP2 School 13-14 March 2013", "Date",
 CellChangeTimes->{{3.576567739800049*^9, 3.576567759261277*^9}, {
  3.576567807772276*^9, 3.576567814516036*^9}}],

Cell["\<\
This notebook is a companion to the lecture notes and presentations of the \
NRHEP2 school. It contain some analytic calculations for the problem of \
Aichelburg-Sexl head on shock wave collisions in D\[GreaterEqual]4, some of \
which with the xAct packages.\
\>", "Text",
 CellChangeTimes->{{3.576567828172926*^9, 3.576568031835332*^9}, {
  3.577884238922604*^9, 3.577884266112307*^9}}],

Cell[CellGroupData[{

Cell["1. The Aichelburg-Sexl Ultra-Boost", "Section",
 CellChangeTimes->{{3.5765628635615253`*^9, 3.576562872729622*^9}, {
   3.5765629119299393`*^9, 3.5765629143255787`*^9}, 3.576567341241108*^9, 
   3.577036962556772*^9, {3.577883855280799*^9, 3.577883858414133*^9}}],

Cell["\<\
This section supports the exercises which are necessary to perform the \
ultra-boost of the D-dimensional Schwarzschild-Tangherlini solution and to \
analyse its curvature properties.\
\>", "Text",
 CellChangeTimes->{{3.5778868876037893`*^9, 3.577886983423402*^9}}],

Cell[BoxData["Quit"], "Input",
 CellChangeTimes->{{3.577883422550436*^9, 3.5778834229681797`*^9}}],

Cell[CellGroupData[{

Cell["1.1 Isotropic coordinates & boost", "Subsection",
 CellChangeTimes->{{3.5765629599090443`*^9, 3.5765629773297567`*^9}, 
   3.576567341241407*^9, {3.577883862977906*^9, 3.577883863503793*^9}}],

Cell["\<\
In this section we derive the coordinate transformation from Schwarzschild to \
isotropic coordinates, for the D-dimensional SchwarzschildTangherlini \
solution.\
\>", "Text",
 CellChangeTimes->{{3.577884298012857*^9, 3.577884380095544*^9}}],

Cell["\<\
First we define the line element for the D-dimensional \
Schwarzschild-Tangherlini solution, making use of the total derivative \
operator, Dt, in mathematica.\
\>", "Text",
 CellChangeTimes->{{3.576579234203669*^9, 3.576579277665614*^9}, {
   3.5778844327498827`*^9, 3.577884461075283*^9}, 3.577886960776091*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ds2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"V", "[", "r", "]"}]}], 
    RowBox[{
     RowBox[{"Dt", "[", "t", "]"}], "^", "2"}]}], "+", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"V", "[", "r", "]"}]}], 
    RowBox[{
     RowBox[{"Dt", "[", "r", "]"}], "^", "2"}]}], "+", 
   RowBox[{
    RowBox[{"r", "^", "2"}], 
    RowBox[{
     RowBox[{"Dt", "[", "\[CapitalOmega]", "]"}], "^", "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.576587531271627*^9, 3.576587626862844*^9}, 
   3.577884565657427*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["r", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Dt", "[", "\[CapitalOmega]", "]"}], "2"]}], "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"Dt", "[", "r", "]"}], "2"], 
   RowBox[{"V", "[", "r", "]"}]], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Dt", "[", "t", "]"}], "2"], " ", 
   RowBox[{"V", "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5765876287073708`*^9, 3.576588674006133*^9, 3.576937369448147*^9, 
   3.577018009309415*^9, {3.577018256174828*^9, 3.577018268218336*^9}, 
   3.577019352143218*^9, 3.577019383307169*^9, 3.5770195088398323`*^9, 
   3.577019546358357*^9, 3.5770197226698437`*^9, 3.577020163088561*^9, 
   3.5770218956030827`*^9, 3.577022954727605*^9, 3.577023796643442*^9, 
   3.577786236716683*^9, 3.5778846058665943`*^9, 3.5778846494744787`*^9}]
}, Open  ]],

Cell["\<\
Then, we replace r by a generic change of variables f[R] (to be determined), \
where R is the new isotropic coordinate. We also impose identity \
dR\.b2+R\.b2d\[CapitalOmega]\.b2=\[CapitalSigma]dx\.b2_i, where x_i  will be \
the new isotropic spatial coordinates which asymptote to cartesian \
coordinates:\
\>", "Text",
 CellChangeTimes->{{3.5765876450044394`*^9, 3.5765876690798903`*^9}, {
  3.577884482444807*^9, 3.5778845565519323`*^9}, {3.577884665494668*^9, 
  3.577884726913677*^9}, {3.577884795894766*^9, 3.577884945831015*^9}, {
  3.578073836026278*^9, 3.578073836347164*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ds2new", "=", 
  RowBox[{
   RowBox[{"ds2", "/.", 
    RowBox[{"r", "\[Rule]", " ", 
     RowBox[{"f", "[", "R", "]"}]}]}], "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"Dt", "[", "\[CapitalOmega]", "]"}], "^", "2"}], "\[Rule]", " ", 
    
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Dt", "[", "xi", "]"}], "^", "2"}], "-", 
       RowBox[{
        RowBox[{"Dt", "[", "R", "]"}], "^", "2"}]}], ")"}], "/", 
     RowBox[{"R", "^", "2"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.576587637250223*^9, 3.576587637875382*^9}, {
  3.576587670861354*^9, 3.5765876859920053`*^9}, {3.576587720040971*^9, 
  3.576587816203341*^9}, {3.577884567194664*^9, 3.5778845682194*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"Dt", "[", "R", "]"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{"Dt", "[", "xi", "]"}], "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"f", "[", "R", "]"}], "2"]}], 
   SuperscriptBox["R", "2"]], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Dt", "[", "t", "]"}], "2"], " ", 
   RowBox[{"V", "[", 
    RowBox[{"f", "[", "R", "]"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Dt", "[", "R", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "R", "]"}], "2"]}], 
   RowBox[{"V", "[", 
    RowBox[{"f", "[", "R", "]"}], "]"}]]}]], "Output",
 CellChangeTimes->{
  3.576587687976407*^9, 3.576587784187839*^9, 3.576587816848979*^9, 
   3.576588675408844*^9, 3.576937371084649*^9, 3.5770180093491898`*^9, {
   3.5770182562184467`*^9, 3.577018268259345*^9}, 3.577019352325173*^9, 
   3.57701938341037*^9, 3.5770195088821783`*^9, 3.577019546407341*^9, 
   3.5770197227737637`*^9, 3.577020163200993*^9, 3.57702189560951*^9, 
   3.577022954777038*^9, 3.577023796673382*^9, 3.5777862367702913`*^9, 
   3.577884950317361*^9}]
}, Open  ]],

Cell["\<\
Now we extract the coefficient we want to cancel to obtain the correct form\
\>", "Text",
 CellChangeTimes->{{3.577884971340082*^9, 3.577885006628829*^9}, {
  3.5780738436506453`*^9, 3.578073843743374*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Coeff0", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"ds2new", ",", 
    RowBox[{
     RowBox[{"Dt", "[", "R", "]"}], "^", "2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.576587819572097*^9, 3.576587858043665*^9}, {
   3.5765879371165457`*^9, 3.576588013876367*^9}, {3.5765881986161127`*^9, 
   3.5765882086242123`*^9}, {3.5765882776058397`*^9, 3.576588293525496*^9}, {
   3.576588342781774*^9, 3.576588400178718*^9}, {3.576588617733754*^9, 
   3.5765886437249517`*^9}, {3.576588680796266*^9, 3.576588688245296*^9}, {
   3.5765887261720257`*^9, 3.576588727937874*^9}, 3.577885010786059*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"f", "[", "R", "]"}], "2"], 
    SuperscriptBox["R", "2"]]}], "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "R", "]"}], "2"], 
   RowBox[{"V", "[", 
    RowBox[{"f", "[", "R", "]"}], "]"}]]}]], "Output",
 CellChangeTimes->{
  3.576588208964136*^9, 3.576588294048786*^9, {3.576588346273725*^9, 
   3.576588400842863*^9}, {3.576588619668695*^9, 3.57658864505015*^9}, 
   3.576588689163515*^9, 3.57658872865135*^9, 3.5769373720921173`*^9, 
   3.577018009404642*^9, {3.5770182562275476`*^9, 3.577018268269973*^9}, 
   3.577019352336097*^9, 3.5770193834251623`*^9, 3.577019508925665*^9, 
   3.577019546462467*^9, 3.577019722780984*^9, 3.5770201634051037`*^9, 
   3.5770218956139727`*^9, 3.5770229547825727`*^9, 3.577023796701874*^9, 
   3.577786236776017*^9, 3.577885011707309*^9}]
}, Open  ]],

Cell["\<\
And solve the equation to get f'[R], with V replaced by the expression for \
the Schwarzschild-Tangherlini solution\
\>", "Text",
 CellChangeTimes->{{3.577885025974814*^9, 3.577885046471868*^9}, {
   3.577885082469473*^9, 3.577885105332817*^9}, 3.5780738513939238`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Deriv", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], "[", "R", "]"}], "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"Coeff0", "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "R", "]"}]}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"f", "[", "R", "]"}], "]"}], "\[Rule]", " ", 
    RowBox[{"1", "-", 
     RowBox[{"\[Mu]", "/", 
      RowBox[{
       RowBox[{"f", "[", "R", "]"}], "^", 
       RowBox[{"(", 
        RowBox[{"d", "-", "3"}], ")"}]}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.576588730795042*^9, 3.57658874959111*^9}, {
  3.576588837605886*^9, 3.576588908115098*^9}, {3.576589171190927*^9, 
  3.576589171768409*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"f", "[", "R", "]"}], " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"f", "[", "R", "]"}], 
       RowBox[{"3", "-", "d"}]]}]}]]}], "R"]], "Output",
 CellChangeTimes->{{3.576588742548657*^9, 3.576588750427882*^9}, 
   3.576588855937602*^9, {3.576588886262767*^9, 3.576588908906896*^9}, 
   3.576589172787098*^9, 3.576937373771936*^9, 3.577018009445469*^9, {
   3.5770182562695103`*^9, 3.577018268312059*^9}, 3.577019352434382*^9, 
   3.577019383530031*^9, 3.577019508973106*^9, 3.5770195465202923`*^9, 
   3.577019722824733*^9, 3.5770201635163507`*^9, 3.577021895665255*^9, 
   3.5770229548250313`*^9, 3.577023796738693*^9, 3.577786236887454*^9, 
   3.577885061310606*^9}]
}, Open  ]],

Cell["\<\
Now we need to integrate the first order equation (basically f'[R]=Deriv), \
but it is convenient to organise the expression differently. Here we move \
some parts to the left hand side \
\>", "Text",
 CellChangeTimes->{{3.5778851142517443`*^9, 3.5778852739296494`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Term1", "=", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"Deriv", "*", "R"}], ")"}]}], "/.", 
   RowBox[{
    RowBox[{"f", "[", "R", "]"}], "\[Rule]", " ", "f"}]}]}]], "Input",
 CellChangeTimes->{{3.576589055199379*^9, 3.576589096944025*^9}, {
  3.5765891755575123`*^9, 3.576589176104229*^9}}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"f", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     RowBox[{
      SuperscriptBox["f", 
       RowBox[{"3", "-", "d"}]], " ", "\[Mu]"}]}]]}]]], "Output",
 CellChangeTimes->{{3.576589065143361*^9, 3.5765890974260063`*^9}, 
   3.5765891771008863`*^9, 3.576937375492263*^9, 3.577018009488995*^9, {
   3.5770182563052263`*^9, 3.5770182683509197`*^9}, 3.577019352562868*^9, 
   3.577019383649343*^9, 3.5770195090177317`*^9, 3.577019546576593*^9, 
   3.5770197228693943`*^9, 3.577020163662231*^9, 3.577021895717183*^9, 
   3.5770229548723392`*^9, 3.577023796742735*^9, 3.577786237058813*^9, 
   3.5778851119692802`*^9, 3.577885300650738*^9}]
}, Open  ]],

Cell["And then integrate the left hand side first", "Text",
 CellChangeTimes->{{3.57788527768773*^9, 3.577885287625058*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LHS", "=", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"f", " ", 
       SqrtBox[
        RowBox[{"1", "-", " ", 
         RowBox[{"\[Mu]", "/", 
          RowBox[{"f", "^", "a"}]}]}]]}]], ",", "f"}], "]"}], "//", 
   "TrigToExp"}]}]], "Input",
 CellChangeTimes->{{3.576589090159945*^9, 3.576589162180921*^9}, {
  3.576589361860181*^9, 3.576589378365418*^9}, {3.576589430101014*^9, 
  3.576589438743807*^9}, {3.57658947205118*^9, 3.576589487046804*^9}, {
  3.576589607767057*^9, 3.576589610124135*^9}, {3.576589679618153*^9, 
  3.576589856060796*^9}, {3.576589897304414*^9, 3.57658994701958*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{
         SuperscriptBox["f", 
          RowBox[{"-", "a"}]], " ", "\[Mu]"}]}]]}], "]"}], "a"]}], "+", 
  FractionBox[
   RowBox[{"Log", "[", 
    RowBox[{"1", "+", 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{
        SuperscriptBox["f", 
         RowBox[{"-", "a"}]], " ", "\[Mu]"}]}]]}], "]"}], "a"]}]], "Output",
 CellChangeTimes->{{3.576589150162486*^9, 3.576589162827382*^9}, 
   3.5765892049082413`*^9, {3.576589363319317*^9, 3.5765893787507067`*^9}, {
   3.5765894341765633`*^9, 3.57658943962003*^9}, {3.5765894776709003`*^9, 
   3.5765894879664593`*^9}, 3.576589685926712*^9, 3.5765897470661087`*^9, {
   3.576589779541765*^9, 3.576589856806532*^9}, {3.5765898988977213`*^9, 
   3.576589947583786*^9}, 3.576937379383416*^9, 3.577018009535699*^9, {
   3.5770182563642*^9, 3.5770182684011602`*^9}, 3.577019352668304*^9, 
   3.577019383821781*^9, 3.57701950908729*^9, 3.577019546642405*^9, 
   3.577019722920699*^9, 3.577020163823398*^9, 3.577021895786366*^9, 
   3.57702295495308*^9, 3.577023796799386*^9, 3.577786237262313*^9, 
   3.577885302670719*^9}]
}, Open  ]],

Cell["\<\
Finally we equate to the integral of the right hand side where we have \
introduced an integration constant R0, which can be chosen appropriately. \
This can be simplified to the result in the lecture notes by a suitable \
choice of R0.\
\>", "Text",
 CellChangeTimes->{{3.5778853111678047`*^9, 3.5778854219259644`*^9}, {
  3.57807388091299*^9, 3.5780738812702312`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fofR", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "/.", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"LHS", "\[Equal]", 
         RowBox[{"Log", "[", 
          RowBox[{"R", "/", "R0"}], "]"}]}], ",", "f", ",", 
        RowBox[{"InverseFunctions", "\[Rule]", " ", "True"}]}], "]"}]}], "/.",
      " ", 
     RowBox[{"a", "\[Rule]", " ", 
      RowBox[{"d", "-", "3"}]}]}], ")"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.576589183189415*^9, 3.5765891964105663`*^9}, {
  3.57658924238057*^9, 3.576589298443008*^9}, {3.576589333725954*^9, 
  3.576589346496883*^9}, {3.576589862658874*^9, 3.5765898765050163`*^9}, {
  3.576589956086936*^9, 3.576590016222624*^9}, {3.5765901140234423`*^9, 
  3.5765901468403463`*^9}, {3.576590409732934*^9, 3.576590411834506*^9}, {
  3.5765905865287523`*^9, 3.576590590799293*^9}, {3.576590633355036*^9, 
  3.576590635087364*^9}, {3.576590891066731*^9, 3.5765909301278057`*^9}, {
  3.5769374323030157`*^9, 3.576937464014296*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["4", 
   RowBox[{"-", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"-", "3"}], "+", "d"}]]}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["R", "R0"], ")"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "d"}]]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["R", "R0"], ")"}], 
      RowBox[{"3", "-", "d"}]], " ", "\[Mu]"}], ")"}], 
   FractionBox["1", 
    RowBox[{
     RowBox[{"-", "3"}], "+", "d"}]]]}]], "Output",
 CellChangeTimes->{
  3.576589197318026*^9, 3.5765892536424513`*^9, {3.5765892865452747`*^9, 
   3.5765892991466503`*^9}, {3.5765893414737177`*^9, 3.576589348267063*^9}, 
   3.576589495718298*^9, {3.57658986332707*^9, 3.576589890259653*^9}, {
   3.576589952910028*^9, 3.57659001655844*^9}, 3.576590147567577*^9, 
   3.576590412323344*^9, 3.576590591520252*^9, 3.576590635787981*^9, {
   3.576590891856308*^9, 3.576590930747292*^9}, 3.576937387657585*^9, 
   3.5769374370818872`*^9, 3.5770180096277637`*^9, {3.57701825645083*^9, 
   3.577018268498975*^9}, 3.5770193528507442`*^9, 3.577019383954935*^9, 
   3.577019509222064*^9, 3.577019546720992*^9, 3.5770197230478563`*^9, 
   3.5770201640153923`*^9, 3.577021895882701*^9, 3.577022955045849*^9, 
   3.577023796886648*^9, 3.577786237360115*^9, 3.577885377449492*^9, 
   3.577885440191453*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2 Limiting form: Einstein  and Riemann Tensors", "Subsection",
 CellChangeTimes->{{3.576562995011442*^9, 3.576563027738065*^9}, {
   3.57656306420429*^9, 3.576563067698544*^9}, {3.576563116681479*^9, 
   3.5765631195391703`*^9}, {3.576567189477126*^9, 3.576567190334343*^9}, 
   3.576567341261842*^9, {3.577883867037572*^9, 3.577883867689186*^9}, {
   3.5778855572499943`*^9, 3.57788556413663*^9}}],

Cell["\<\
In this section, we take advantage of the xCoba package of xAct, to compute \
the Einstein tensor and Riemann tensor for AS shock waves for particular \
values of D. This is a useful exercise also to illustrate the capabilities of \
xAct to work with a chart.
We start by quiting the kernel to avoid clashing definitions:\
\>", "Text",
 CellChangeTimes->{{3.577885489046714*^9, 3.577885524360572*^9}, {
  3.577885567973996*^9, 3.577885691602076*^9}}],

Cell[BoxData["Quit"], "Input",
 CellChangeTimes->{{3.577639231590382*^9, 3.5776392329445868`*^9}, 
   3.577776867127529*^9}],

Cell["This just loads the package:", "Text",
 CellChangeTimes->{{3.577885659070683*^9, 3.5778856940616293`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "xAct/xCoba.m"}]], "Input",
 CellChangeTimes->{{3.57656721216646*^9, 3.576567213653059*^9}, 
   3.576567341261936*^9, {3.577017963672985*^9, 3.577017992265006*^9}, {
   3.577028488538759*^9, 3.577028499984462*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.57807397010949*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.0\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2013", ",", "1", ",", "27"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.0", ", ", {2013, 1, 27}],
  
  Editable->False]], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970141857*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2013, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970148177*^9}],

Cell[BoxData["\<\"Connecting to external linux executable...\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970150566*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970152669*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.5780739701548843`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.5\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2013", ",", "1", ",", "30"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.0.5", ", ", {2013, 1, 30}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970157301*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2013, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970159683*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970370685*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xCoba`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.8.0\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2013", ",", "1", ",", "30"}], "}"}]}],
  SequenceForm["Package xAct`xCoba`  version ", "0.8.0", ", ", {2013, 1, 30}],
  
  Editable->False]], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.5780739704079638`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2013, David Yllanes and Jose M. \
Martin-Garcia, under the General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.5780739704449167`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970486691*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970550737*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.577017974353714*^9, 3.577018009826536*^9}, {
   3.577018256568212*^9, 3.577018268651062*^9}, 3.5770193529742107`*^9, 
   3.5770193841301193`*^9, 3.577019509376541*^9, 3.577019546941423*^9, 
   3.5770197231878223`*^9, 3.577020164183235*^9, 3.577021896030402*^9, 
   3.577022955170594*^9, 3.577023797094244*^9, 3.5770283430204887`*^9, {
   3.577028484828918*^9, 3.577028510825182*^9}, {3.577030520681141*^9, 
   3.577030527951503*^9}, 3.577038044127191*^9, {3.577776865026952*^9, 
   3.577776888215282*^9}, 3.5778856492839403`*^9, 3.577885701706523*^9, 
   3.578073970608877*^9}]
}, Open  ]]
}, Open  ]],

Cell["Some useful options to control verbosity:", "Text",
 CellChangeTimes->{{3.57788570947849*^9, 3.577885725065939*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$DefInfoQ", "=", "False"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"$CVVerbose", "=", "False"}], ";"}]}], "Input",
 CellChangeTimes->{{3.57702188863673*^9, 3.577021889083396*^9}, {
  3.5770286140011663`*^9, 3.577028667754014*^9}, {3.577030503113998*^9, 
  3.577030507724866*^9}}],

Cell[CellGroupData[{

Cell["4D  Case", "Subsubsection",
 CellChangeTimes->{{3.57702839359064*^9, 3.577028405046021*^9}}],

Cell["\<\
First thing is to define a 4-dimensional manifold and choose some names for \
the indices to be used for display:\
\>", "Text",
 CellChangeTimes->{{3.577885742389948*^9, 3.5778857789002857`*^9}, {
  3.578073922302273*^9, 3.578073922598111*^9}}],

Cell[BoxData[
 RowBox[{"DefManifold", "[", 
  RowBox[{"M4", ",", "4", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.577018134134692*^9, 3.577018136596263*^9}, {
  3.5770192532124023`*^9, 3.577019256026484*^9}}],

Cell["\<\
Then we define the metric and a covariant derivative which we call CD4:\
\>", "Text",
 CellChangeTimes->{{3.577885782219482*^9, 3.577885801092868*^9}}],

Cell[BoxData[
 RowBox[{"DefMetric", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "CD4", ",", 
   RowBox[{"SymbolOfCovD", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<|\>\"", ",", "\"\<D\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5770182398281317`*^9, 3.577018272376926*^9}, {
  3.5770285189636927`*^9, 3.577028537452413*^9}}],

Cell["\<\
xCoba allows us to define a chart (named chart4 here) with coordinates \
u,v,x,y which (for the purpose of the internal workings of the package) are \
declared to be scalar functions  of no arguments:\
\>", "Text",
 CellChangeTimes->{{3.577885807211535*^9, 3.5778858126182528`*^9}, {
  3.5778858606678123`*^9, 3.577885923007392*^9}, {3.5780739460429296`*^9, 
  3.578073946365675*^9}}],

Cell[BoxData[
 RowBox[{"DefChart", "[", 
  RowBox[{"chart4", ",", "M4", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "]"}], ",", 
     RowBox[{"v", "[", "]"}], ",", 
     RowBox[{"x", "[", "]"}], ",", 
     RowBox[{"y", "[", "]"}]}], "}"}], ",", 
   RowBox[{"BasisColor", "\[Rule]", "Green"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.57701838623041*^9, 3.577018393627659*^9}, {
   3.577019261962961*^9, 3.577019276560557*^9}, 3.577023918122942*^9, {
   3.577776917906681*^9, 3.577776920036975*^9}, {3.577885821418519*^9, 
   3.577885823274777*^9}}],

Cell["\<\
Now we define a matrix to hold the metric components. We have kept \[Delta] \
and \[CapitalPhi] generic functions because they do not need to be specified. \
\>", "Text",
 CellChangeTimes->{{3.5778859406239653`*^9, 3.577885988474867*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefConstantSymbol", "[", 
    RowBox[{"kappa", ",", 
     RowBox[{"PrintAs", "\[Rule]", "\"\<\[Kappa]\>\""}]}], "]"}], ";"}], " ", 
  
  RowBox[{"(*", 
   RowBox[{
   "Energy", " ", "parameter", " ", "of", " ", "the", " ", "shock", " ", 
    "wave"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"ASMetric", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kappa", " ", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "[", "]"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"y", "[", "]"}], "^", "2"}]}], "]"}], "]"}], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"u", "[", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.577019019153061*^9, 3.577019209746903*^9}, {
   3.577019284319552*^9, 3.577019373671884*^9}, 3.5770195004633512`*^9, {
   3.577023913869446*^9, 3.577023914549135*^9}, {3.57702396258523*^9, 
   3.577023977903294*^9}, {3.5778859908736973`*^9, 3.577886018486088*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`kappa,
        Editable->False], " ", 
       RowBox[{"\[Delta]", "[", 
        InterpretationBox[
         StyleBox["u",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[],
         Editable->False], "]"}], " ", 
       RowBox[{"\[CapitalPhi]", "[", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["x",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`x[],
            Editable->False], "2"], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["y",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`y[],
            Editable->False], "2"]}]], "]"}]}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0", "0", "0"},
     {"0", "0", "1", "0"},
     {"0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.577019355330209*^9, 3.577019387016568*^9, 3.5770195110703573`*^9, 
   3.577019547723238*^9, 3.577019724500979*^9, 3.577020165511153*^9, 
   3.5770218969223537`*^9, 3.57702295600801*^9, 3.5770237980228777`*^9, 
   3.577023907652025*^9, 3.577023978684304*^9, 3.577028556013475*^9, 
   3.577030484988751*^9, 3.577030541525634*^9, 3.577776879996323*^9, 
   3.5777769275870237`*^9, {3.577886010392333*^9, 3.57788601997375*^9}, 
   3.5780739809092073`*^9}]
}, Open  ]],

Cell["\<\
Now we assign  the matrix to the metric elements using the corresponding \
xCoba function, in chart4:\
\>", "Text",
 CellChangeTimes->{{3.577886042407721*^9, 3.577886093263253*^9}, 
   3.577886133759375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricInBasis", "[", 
  RowBox[{"g", ",", 
   RowBox[{"-", "chart4"}], ",", "ASMetric"}], "]"}]], "Input",
 CellChangeTimes->{{3.57701943406391*^9, 3.577019488568809*^9}, {
  3.577885829769411*^9, 3.57788583091127*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`chart4}, {1, -$CellContext`chart4}],
       Editable->False], "\[Rule]", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`kappa,
        Editable->False], " ", 
       RowBox[{"\[Delta]", "[", 
        InterpretationBox[
         StyleBox["u",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[],
         Editable->False], "]"}], " ", 
       RowBox[{"\[CapitalPhi]", "[", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["x",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`x[],
            Editable->False], "2"], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["y",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`y[],
            Editable->False], "2"]}]], "]"}]}]}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`chart4}, {2, -$CellContext`chart4}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`chart4}, {3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`chart4}, {4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`chart4}, {1, -$CellContext`chart4}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`chart4}, {2, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`chart4}, {3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`chart4}, {4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`chart4}, {1, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`chart4}, {2, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`chart4}, {3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "1"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`chart4}, {4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{4, -$CellContext`chart4}, {1, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{4, -$CellContext`chart4}, {2, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{4, -$CellContext`chart4}, {3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{4, -$CellContext`chart4}, {4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.577019459407588*^9, 3.57701951176539*^9}, 
   3.577019547780218*^9, 3.5770197246038027`*^9, 3.577020165613624*^9, 
   3.577021897008719*^9, 3.577022956095155*^9, 3.577023798145384*^9, 
   3.5770239823152514`*^9, 3.5770285644233103`*^9, 3.577030485097396*^9, 
   3.577030543593174*^9, 3.577776930979924*^9, 3.577886033405308*^9, 
   3.577886095961698*^9}]
}, Open  ]],

Cell["\<\
Next we tell xCoba to compute the components of the Einstein tensor in chart4:\
\>", "Text",
 CellChangeTimes->{{3.577886110028894*^9, 3.577886131882688*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CalcEin", "=", 
   RowBox[{"MetricCompute", "[", 
    RowBox[{"g", ",", "chart4", ",", 
     RowBox[{"\"\<Einstein\>\"", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "]"}], ",", 
     RowBox[{"CVSimplify", "\[Rule]", "Simplify"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.577019643577511*^9, 3.5770196475396976`*^9}, {
   3.5770197711545153`*^9, 3.5770198113847427`*^9}, {3.577020144441565*^9, 
   3.577020155443173*^9}, {3.57702171999398*^9, 3.5770217208626842`*^9}, {
   3.577022825968195*^9, 3.577022837480525*^9}, 3.577023818713393*^9, 
   3.5770285830561*^9, {3.577029005491207*^9, 3.577029008240926*^9}, {
   3.577885834608692*^9, 3.577885835633263*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Metric\"\>", "[", 
    RowBox[{"1", ",", "1"}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000475`3.1282386031208422", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Metric"[1, 1], " constructed in ", 0.000475`3.1282386031208422, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136613419*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.002166`3.787203445785275", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.002166`3.787203445785275, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.57788613668666*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.000862`3.387052259320685", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "5584", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.000862`3.387052259320685, " seconds and ", 5584, " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136690551*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"DMetric\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000431`3.0860222636566994", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "DMetric"[-1, -1, -1], " constructed in ", 0.000431`3.0860222636566994, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136694255*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.00347`3.9918744682868437", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.00347`3.9918744682868437, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136697905*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.001025`3.462268858887741", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "45736", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.001025`3.462268858887741, " seconds and ", 45736, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136701603*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Christoffel\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000383`3.0347437674645916", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Christoffel"[-1, -1, -1], " constructed in ", 0.000383`3.0347437674645916,
    " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136705056*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.003005`3.929389469834729", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.003005`3.929389469834729, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136708448*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.001191`3.5274567549787434", 
   "\[InvisibleSpace]", "\<\" seconds and \"\>", "\[InvisibleSpace]", "60720",
    "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.001191`3.5274567549787434, " seconds and ", 60720, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136711791*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Christoffel\"\>", "[", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000665`3.274366638799081", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Christoffel"[1, -1, -1], " constructed in ", 0.000665`3.274366638799081, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136824087*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.002776`3.894964455278794", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.002776`3.894964455278794, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886136946672*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.001206`3.532892301300104", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "53488", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.001206`3.532892301300104, " seconds and ", 53488, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137103278*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"DDMetric\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000897`3.404337436540062", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "DDMetric"[-1, -1, -1, -1], " constructed in ", 0.000897`3.404337436540062,
    " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137157873*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.033505`4.976654615767904", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.033505`4.976654615767904, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.57788613721596*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.004368`4.091827623192646", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "262752", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.004368`4.091827623192646, " seconds and ", 262752, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.5778861372631207`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Riemann\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.00085`3.380963919210265", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Riemann"[-1, -1, -1, -1], " constructed in ", 0.00085`3.380963919210265, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.5778861372964478`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.015245`4.634672422197369", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.015245`4.634672422197369, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137338539*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.011777`4.5225796685501205", 
   "\[InvisibleSpace]", "\<\" seconds and \"\>", "\[InvisibleSpace]", 
   "246232", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.011777`4.5225796685501205, " seconds and ", 246232, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.5778861373823233`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Riemann\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.002662`3.8767530446346274", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Riemann"[-1, -1, -1, 1], " constructed in ", 0.002662`3.8767530446346274, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137423564*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.012773`4.557837905671624", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.012773`4.557837905671624, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137464245*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.011342`4.50623463644595", "\[InvisibleSpace]", "\<\" seconds and \"\>", 
   "\[InvisibleSpace]", "220864", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.011342`4.50623463644595, " seconds and ", 220864, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137512753*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Ricci\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000155`2.641876691666257", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Ricci"[-1, -1], " constructed in ", 0.000155`2.641876691666257, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.57788613757495*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.009908`4.447530991409771", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.009908`4.447530991409771, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.5778861376189823`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.000419`3.0737590164622657", 
   "\[InvisibleSpace]", "\<\" seconds and \"\>", "\[InvisibleSpace]", "9616", 
   "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.000419`3.0737590164622657, " seconds and ", 9616, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137672641*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"RicciScalar\"\>", "[", "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000076`2.3323585857767672", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "RicciScalar"[], " constructed in ", 0.000076`2.3323585857767672, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.57788613770437*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.000035`1.9956130378462478", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.000035`1.9956130378462478, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.5778861377313643`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.000088`2.39602766564614", "\[InvisibleSpace]", "\<\" seconds and \"\>", 
   "\[InvisibleSpace]", "216", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.000088`2.39602766564614, " seconds and ", 216, " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137770088*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Einstein\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.00011`2.4929376786541946", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Einstein"[-1, -1], " constructed in ", 0.00011`2.4929376786541946, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.5778861378127127`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.001187`3.5259957124505585", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.001187`3.5259957124505585, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137879327*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.000338`2.98046169377363", "\[InvisibleSpace]", "\<\" seconds and \"\>", 
   "\[InvisibleSpace]", "9616", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.000338`2.98046169377363, " seconds and ", 9616, " bytes"],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.577030545559548*^9, 3.577776935937393*^9, 
  3.577886137923039*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The xCoba TensorValues function allows us to extract a set of rules for the \
components of the Einstein tensor that was computed, which we store in a \
variable. \
\>", "Text",
 CellChangeTimes->{{3.577886149135255*^9, 3.577886231254973*^9}, {
  3.578074020821574*^9, 3.5780740211626062`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RulesG4D", "=", 
   RowBox[{"TensorValues", "[", "EinsteinCD4", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.5770287041833363`*^9, {3.5770290177567596`*^9, 3.577029085476088*^9}, 
   3.5770292241113377`*^9, {3.5770293574833117`*^9, 3.5770293579977617`*^9}}],

Cell["\<\
Finally we display the components with the indices down (\"Last\" just \
extracts the last list of rules where the rules for the tensor with indices \
down are stored. Column formats it)\
\>", "Text",
 CellChangeTimes->{{3.5778862408338137`*^9, 3.577886313548473*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Last", "@", "RulesG4D"}], "//", "Column"}]], "Input",
 CellChangeTimes->{{3.57702927553441*^9, 3.5770292865299263`*^9}, {
  3.5770293596375303`*^9, 3.5770293600965433`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{1, -$CellContext`chart4}, {
        1, -$CellContext`chart4}],
       Editable->False], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`kappa,
        Editable->False], " ", 
       RowBox[{"\[Delta]", "[", 
        InterpretationBox[
         StyleBox["u",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[],
         Editable->False], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[CapitalPhi]", "\[Prime]",
             MultilineFunction->None], "[", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["x",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`x[],
                Editable->False], "2"], "+", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["y",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`y[],
                Editable->False], "2"]}]], "]"}], 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["x",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`x[],
               Editable->False], "2"], "+", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["y",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`y[],
               Editable->False], "2"]}]]]}], "-", 
         RowBox[{
          SuperscriptBox["\[CapitalPhi]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"]}]], "]"}]}], ")"}]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{1, -$CellContext`chart4}, {
        2, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{1, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{1, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{2, -$CellContext`chart4}, {
        2, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{2, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{2, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{3, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{3, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD4[{4, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.577029287293281*^9, 3.577029363199185*^9, 
  3.577030485300783*^9, 3.577030550035986*^9, 3.577776946995162*^9, 
  3.577886316169036*^9}]
}, Open  ]],

Cell["\<\
We know how \[CapitalPhi]''(\[Rho]) relates with the Laplacian on the \
transverse plane (because of axial symmetry), so we create a rule:\
\>", "Text",
 CellChangeTimes->{{3.577886332679359*^9, 3.577886336194784*^9}, {
   3.577886366869793*^9, 3.5778864448983088`*^9}, 3.578074043826179*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RuleLaplace4D", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["x",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`x[],
         Editable->False], "2"], "+", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["y",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`y[],
         Editable->False], "2"]}]], "]"}], "\[Rule]", "  ", 
    RowBox[{"\[CapitalDelta]\[CapitalPhi]", "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[CapitalPhi]", "\[Prime]",
        MultilineFunction->None], "[", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["x",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`x[],
           Editable->False], "2"], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["y",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`y[],
           Editable->False], "2"]}]], "]"}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["x",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`x[],
          Editable->False], "2"], "+", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["y",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`y[],
          Editable->False], "2"]}]]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5770291763567953`*^9, 3.577029195274687*^9}, {
  3.5770294872786617`*^9, 3.577029507928322*^9}, {3.577029541227672*^9, 
  3.577029548781085*^9}, {3.577029606403873*^9, 3.5770296611723213`*^9}, {
  3.57702974713968*^9, 3.5770297663910027`*^9}}],

Cell["\<\
Now we replace it in the only non-zero component of the Einstein tensor, and \
we get the expected result (that the Einstein equations reduce to a Laplace \
equation on the transverse plane).\
\>", "Text",
 CellChangeTimes->{{3.577886449810975*^9, 3.5778865162894173`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G11in4D", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"EinsteinCD4", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", " ", 
          RowBox[{"-", "chart4"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", 
          RowBox[{"-", "chart4"}]}], "}"}]}], "]"}], "/.", "RulesG4D"}], 
     ")"}], "/.", "RuleLaplace4D"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.5770288505472183`*^9, 3.5770289195800123`*^9}, {
  3.577029095543112*^9, 3.577029125152829*^9}, {3.5770292028261127`*^9, 
  3.5770292150333*^9}, {3.577029365802808*^9, 3.577029367284072*^9}, {
  3.577029739476575*^9, 3.577029760040073*^9}, {3.577885842626132*^9, 
  3.577885846402549*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", 
  InterpretationBox[
   StyleBox["\[Kappa]",
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`kappa,
   Editable->False], " ", "\[CapitalDelta]\[CapitalPhi]", " ", 
  RowBox[{"\[Delta]", "[", 
   InterpretationBox[
    StyleBox["u",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`u[],
    Editable->False], "]"}]}]], "Output",
 CellChangeTimes->{{3.577028903752534*^9, 3.577028920659504*^9}, 
   3.5770290253009853`*^9, {3.577029093406294*^9, 3.577029125863483*^9}, {
   3.57702920434144*^9, 3.577029215912187*^9}, 3.57702932670857*^9, 
   3.5770293691864643`*^9, 3.577029511381171*^9, 3.577029552479895*^9, {
   3.577029618312009*^9, 3.5770296517908173`*^9}, {3.5770297402655363`*^9, 
   3.577029767783564*^9}, 3.577030485512684*^9, 3.57703055292593*^9, 
   3.5777769537211533`*^9, 3.577886481474893*^9}]
}, Open  ]],

Cell["\<\
Now we want to compute the Riemann tensor. We follow exactly the same \
strategy and get two non-zero components.\
\>", "Text",
 CellChangeTimes->{{3.577886527125155*^9, 3.577886557284852*^9}, {
  3.5778866506835403`*^9, 3.577886662978964*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RulesRiemann4D", "=", 
   RowBox[{"TensorValues", "[", "RiemannCD4", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.577029379317245*^9, 3.577029400393564*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Last", "@", "RulesRiemann4D"}], "/.", "RuleLaplace4D"}], " ", "//",
      "Simplify"}], ")"}], "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "]"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"y", "[", "]"}], "^", "2"}]}], "]"}], "\[Rule]", " ", 
     "\[Rho]"}], "}"}]}], "//", "Column"}]], "Input",
 CellChangeTimes->{{3.577029416508074*^9, 3.577029456269971*^9}, {
  3.577029564246395*^9, 3.5770295819036713`*^9}, {3.577029775885085*^9, 
  3.5770299570351954`*^9}, {3.577030348311557*^9, 3.577030359113861*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        2, -$CellContext`chart4}, {1, -$CellContext`chart4}, {
        2, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        2, -$CellContext`chart4}, {1, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        2, -$CellContext`chart4}, {1, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        2, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        2, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        2, -$CellContext`chart4}, {3, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        3, -$CellContext`chart4}, {1, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["x",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`x[],
                 Editable->False], "2"]}], "+", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["y",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`y[],
                Editable->False], "2"]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        3, -$CellContext`chart4}, {1, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["x",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`x[],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["y",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`y[],
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]"}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        3, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        3, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        3, -$CellContext`chart4}, {3, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        4, -$CellContext`chart4}, {1, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["x",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`x[],
                Editable->False], "2"], "-", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["y",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`y[],
                Editable->False], "2"]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        4, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        4, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{1, -$CellContext`chart4}, {
        4, -$CellContext`chart4}, {3, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{2, -$CellContext`chart4}, {
        3, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        3, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{2, -$CellContext`chart4}, {
        3, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{2, -$CellContext`chart4}, {
        3, -$CellContext`chart4}, {3, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{2, -$CellContext`chart4}, {
        4, -$CellContext`chart4}, {2, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{2, -$CellContext`chart4}, {
        4, -$CellContext`chart4}, {3, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD4[{3, -$CellContext`chart4}, {
        4, -$CellContext`chart4}, {3, -$CellContext`chart4}, {
        4, -$CellContext`chart4}],
       Editable->False], "\[Rule]", "0"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{
  3.57702941749524*^9, 3.5770294570057898`*^9, 3.5770295143181133`*^9, {
   3.577029555130584*^9, 3.577029565339662*^9}, {3.577029771251424*^9, 
   3.577029868498781*^9}, {3.577029901737936*^9, 3.577029957802024*^9}, {
   3.577030350646538*^9, 3.5770303602696877`*^9}, 3.5770304855939293`*^9, 
   3.577030556114532*^9, 3.577776959496357*^9, 3.577886666597629*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5D  Case", "Subsubsection",
 CellChangeTimes->{{3.57702839359064*^9, 3.577028405046021*^9}, 
   3.577030413925642*^9}],

Cell["\<\
For the 5D case we do exactly the same, except that we use new indices and we \
need one more scalar for the coordinates (z[]). Also we name CD5 the \
covariant derivative.\
\>", "Text",
 CellChangeTimes->{{3.577886682151287*^9, 3.5778867186789637`*^9}, {
  3.577886798073977*^9, 3.577886800982479*^9}, {3.578074072012753*^9, 
  3.578074075500802*^9}}],

Cell[BoxData[
 RowBox[{"DefManifold", "[", 
  RowBox[{"M5", ",", "5", ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", "n", ",", "o", ",", "p", ",", "q"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.577018134134692*^9, 3.577018136596263*^9}, {
  3.5770192532124023`*^9, 3.577019256026484*^9}, {3.5770304156960363`*^9, 
  3.577030444068985*^9}}],

Cell[BoxData[
 RowBox[{"DefMetric", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   RowBox[{"g5", "[", 
    RowBox[{
     RowBox[{"-", "m"}], ",", 
     RowBox[{"-", "n"}]}], "]"}], ",", "CD5", ",", 
   RowBox[{"SymbolOfCovD", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<|\>\"", ",", "\"\<D\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5770182398281317`*^9, 3.577018272376926*^9}, {
  3.5770285189636927`*^9, 3.577028537452413*^9}, {3.577030448121901*^9, 
  3.577030458198599*^9}}],

Cell[BoxData[
 RowBox[{"DefChart", "[", 
  RowBox[{"chart5", ",", "M5", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "]"}], ",", 
     RowBox[{"v", "[", "]"}], ",", 
     RowBox[{"x", "[", "]"}], ",", 
     RowBox[{"y", "[", "]"}], ",", 
     RowBox[{"z", "[", "]"}]}], "}"}], ",", 
   RowBox[{"BasisColor", "\[Rule]", "Green"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.57701838623041*^9, 3.577018393627659*^9}, {
   3.577019261962961*^9, 3.577019276560557*^9}, 3.577023918122942*^9, {
   3.577030563389441*^9, 3.577030578342415*^9}, {3.577886727977738*^9, 
   3.577886733790642*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"ASMetric5", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kappa", " ", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "[", "]"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"y", "[", "]"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"z", "[", "]"}], "^", "2"}]}], "]"}], "]"}], 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"u", "[", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], ",", "0", ",", "0", ",", "0", ",", 
       "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]}],
   "]"}]], "Input",
 CellChangeTimes->{{3.577019019153061*^9, 3.577019209746903*^9}, {
   3.577019284319552*^9, 3.577019373671884*^9}, 3.5770195004633512`*^9, {
   3.577023913869446*^9, 3.577023914549135*^9}, {3.57702396258523*^9, 
   3.577023977903294*^9}, {3.5770305898763247`*^9, 3.577030626898198*^9}, {
   3.577030999521276*^9, 3.5770310060979652`*^9}, {3.577031129148223*^9, 
   3.5770311341019297`*^9}, {3.577886738571899*^9, 3.5778867530076733`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`kappa,
        Editable->False], " ", 
       RowBox[{"\[Delta]", "[", 
        InterpretationBox[
         StyleBox["u",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[],
         Editable->False], "]"}], " ", 
       RowBox[{"\[CapitalPhi]", "[", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["x",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`x[],
            Editable->False], "2"], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["y",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`y[],
            Editable->False], "2"], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["z",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`z[],
            Editable->False], "2"]}]], "]"}]}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0", "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0", "0", "0", "0"},
     {"0", "0", "1", "0", "0"},
     {"0", "0", "0", "1", "0"},
     {"0", "0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.577019355330209*^9, 3.577019387016568*^9, 3.5770195110703573`*^9, 
   3.577019547723238*^9, 3.577019724500979*^9, 3.577020165511153*^9, 
   3.5770218969223537`*^9, 3.57702295600801*^9, 3.5770237980228777`*^9, 
   3.577023907652025*^9, 3.577023978684304*^9, 3.577028556013475*^9, {
   3.57703060985028*^9, 3.5770306274946833`*^9}, 3.57703100708112*^9, 
   3.57703113499787*^9, 3.57777697230019*^9, 3.577886753833996*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricInBasis", "[", 
  RowBox[{"g5", ",", 
   RowBox[{"-", "chart5"}], ",", "ASMetric5"}], "]"}]], "Input",
 CellChangeTimes->{{3.57701943406391*^9, 3.577019488568809*^9}, {
  3.577030838679248*^9, 3.577030853537161*^9}, {3.577886756729694*^9, 
  3.577886763177412*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{1, -$CellContext`chart5}, {1, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`kappa,
        Editable->False], " ", 
       RowBox[{"\[Delta]", "[", 
        InterpretationBox[
         StyleBox["u",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[],
         Editable->False], "]"}], " ", 
       RowBox[{"\[CapitalPhi]", "[", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["x",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`x[],
            Editable->False], "2"], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["y",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`y[],
            Editable->False], "2"], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["z",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`z[],
            Editable->False], "2"]}]], "]"}]}]}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{1, -$CellContext`chart5}, {2, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{1, -$CellContext`chart5}, {3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{1, -$CellContext`chart5}, {4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{1, -$CellContext`chart5}, {5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{2, -$CellContext`chart5}, {1, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{2, -$CellContext`chart5}, {2, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{2, -$CellContext`chart5}, {3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{2, -$CellContext`chart5}, {4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{2, -$CellContext`chart5}, {5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{3, -$CellContext`chart5}, {1, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{3, -$CellContext`chart5}, {2, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{3, -$CellContext`chart5}, {3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "1"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{3, -$CellContext`chart5}, {4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{3, -$CellContext`chart5}, {5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{4, -$CellContext`chart5}, {1, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{4, -$CellContext`chart5}, {2, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{4, -$CellContext`chart5}, {3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{4, -$CellContext`chart5}, {4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "1"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{4, -$CellContext`chart5}, {5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{5, -$CellContext`chart5}, {1, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{5, -$CellContext`chart5}, {2, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{5, -$CellContext`chart5}, {3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{5, -$CellContext`chart5}, {4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}], ",", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g5", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g5[{5, -$CellContext`chart5}, {5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.577019459407588*^9, 3.57701951176539*^9}, 
   3.577019547780218*^9, 3.5770197246038027`*^9, 3.577020165613624*^9, 
   3.577021897008719*^9, 3.577022956095155*^9, 3.577023798145384*^9, 
   3.5770239823152514`*^9, 3.5770285644233103`*^9, 3.577030854485166*^9, 
   3.577031012660944*^9, 3.5770311546121197`*^9, 3.577776975588533*^9, 
   3.577886764099546*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CalcEin5d", "=", 
   RowBox[{"MetricCompute", "[", 
    RowBox[{"g5", ",", "chart5", ",", 
     RowBox[{"\"\<Einstein\>\"", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "]"}], ",", 
     RowBox[{"CVSimplify", "\[Rule]", "Simplify"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.577019643577511*^9, 3.5770196475396976`*^9}, {
   3.5770197711545153`*^9, 3.5770198113847427`*^9}, {3.577020144441565*^9, 
   3.577020155443173*^9}, {3.57702171999398*^9, 3.5770217208626842`*^9}, {
   3.577022825968195*^9, 3.577022837480525*^9}, 3.577023818713393*^9, 
   3.5770285830561*^9, {3.577029005491207*^9, 3.577029008240926*^9}, {
   3.577030858902562*^9, 3.5770308635574007`*^9}, {3.577886770371674*^9, 
   3.57788678084319*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Metric\"\>", "[", 
    RowBox[{"1", ",", "1"}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000382`3.033608356407681", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Metric"[1, 1], " constructed in ", 0.000382`3.033608356407681, " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867813767014`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.001603`3.656478515850109", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.001603`3.656478515850109, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867814108973`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.000908`3.4096308420170547", 
   "\[InvisibleSpace]", "\<\" seconds and \"\>", "\[InvisibleSpace]", "8560", 
   "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.000908`3.4096308420170547, " seconds and ", 8560, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781416006*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"DMetric\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000789`3.348621996705397", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "DMetric"[-1, -1, -1], " constructed in ", 0.000789`3.348621996705397, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.57788678142115*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.005706`4.207876760817024", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.005706`4.207876760817024, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781425914*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.00192`3.7348462221995207", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "89752", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.00192`3.7348462221995207, " seconds and ", 89752, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867814306383`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Christoffel\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000649`3.263789690296338", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Christoffel"[-1, -1, -1], " constructed in ", 0.000649`3.263789690296338, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781466568*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.005029`4.1530266291169", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.005029`4.1530266291169, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867815029287`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.002233`3.8004337165674094", 
   "\[InvisibleSpace]", "\<\" seconds and \"\>", "\[InvisibleSpace]", 
   "118552", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.002233`3.8004337165674094, " seconds and ", 118552, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781539834*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Christoffel\"\>", "[", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.001174`3.521213090407567", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Christoffel"[1, -1, -1], " constructed in ", 0.001174`3.521213090407567, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781578055*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.004852`4.137465785690507", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.004852`4.137465785690507, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781611*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.002283`3.810050904986208", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "104344", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.002283`3.810050904986208, " seconds and ", 104344, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781645689*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"DDMetric\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.001763`3.697797305795296", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "DDMetric"[-1, -1, -1, -1], " constructed in ", 0.001763`3.697797305795296,
    " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781708407*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.076223`5.333631031317133", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.076223`5.333631031317133, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781744516*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.011069`4.495653380942087", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "649704", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.011069`4.495653380942087, " seconds and ", 649704, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781781414*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Riemann\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.002661`3.8765898680473643", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Riemann"[-1, -1, -1, -1], " constructed in ", 0.002661`3.8765898680473643,
    " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781832728*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.040467`5.058646002885344", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.040467`5.058646002885344, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781877816*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.030378`4.934104171266462", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "627384", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.030378`4.934104171266462, " seconds and ", 627384, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886781915288*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Riemann\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.006658`4.274888784316615", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Riemann"[-1, -1, -1, 1], " constructed in ", 0.006658`4.274888784316615, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867819823*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.035135`4.997284951369211", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.035135`4.997284951369211, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886782021051*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.028159`4.901162221302934", "\[InvisibleSpace]", "\<\" seconds and \"\>",
    "\[InvisibleSpace]", "552344", "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.028159`4.901162221302934, " seconds and ", 552344, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867820764437`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Ricci\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000227`2.807570850689092", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Ricci"[-1, -1], " constructed in ", 0.000227`2.807570850689092, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886782115959*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.013297`4.575298662251815", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.013297`4.575298662251815, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867821672773`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.000686`3.2878691092027226", 
   "\[InvisibleSpace]", "\<\" seconds and \"\>", "\[InvisibleSpace]", "14464",
    "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.000686`3.2878691092027226, " seconds and ", 14464, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886782246317*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"RicciScalar\"\>", "[", "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000102`2.4601451652578836", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "RicciScalar"[], " constructed in ", 0.000102`2.4601451652578836, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867822965403`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.000041`2.0643288502157078", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.000041`2.0643288502157078, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867823263474`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.000098`2.4427710691884634", 
   "\[InvisibleSpace]", "\<\" seconds and \"\>", "\[InvisibleSpace]", "216", 
   "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.000098`2.4427710691884634, " seconds and ", 216, " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886782355235*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Einstein\"\>", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\" constructed in \"\>", "\[InvisibleSpace]", 
   "0.000151`2.630521940789145", "\[InvisibleSpace]", "\<\" seconds\"\>"}],
  SequenceForm[
   "Einstein"[-1, -1], " constructed in ", 0.000151`2.630521940789145, 
   " seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886782404214*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Applied \"\>", "\[InvisibleSpace]", "Simplify", 
   "\[InvisibleSpace]", "\<\" in \"\>", "\[InvisibleSpace]", 
   "0.001566`3.6463367512178984", "\[InvisibleSpace]", "\<\" seconds \"\>"}],
  SequenceForm[
  "  Applied ", Simplify, " in ", 0.001566`3.6463367512178984, " seconds "],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886782440649*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Stored in \"\>", "\[InvisibleSpace]", 
   "0.000471`3.1245659006248623", 
   "\[InvisibleSpace]", "\<\" seconds and \"\>", "\[InvisibleSpace]", "14464",
    "\[InvisibleSpace]", "\<\" bytes\"\>"}],
  SequenceForm[
  "  Stored in ", 0.000471`3.1245659006248623, " seconds and ", 14464, 
   " bytes"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778867825071507`*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RulesG5D", "=", 
   RowBox[{"TensorValues", "[", "EinsteinCD5", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.5770287041833363`*^9, {3.5770290177567596`*^9, 3.577029085476088*^9}, 
   3.5770292241113377`*^9, {3.5770293574833117`*^9, 3.5770293579977617`*^9}, {
   3.577030868981558*^9, 3.5770308728701982`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Last", "@", "RulesG5D"}], "//", "Column"}]], "Input",
 CellChangeTimes->{{3.57702927553441*^9, 3.5770292865299263`*^9}, {
   3.5770293596375303`*^9, 3.5770293600965433`*^9}, 3.577030876479128*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{1, -$CellContext`chart5}, {
        1, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`kappa,
        Editable->False], " ", 
       RowBox[{"\[Delta]", "[", 
        InterpretationBox[
         StyleBox["u",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[],
         Editable->False], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["x",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`x[],
                 Editable->False], "2"], "+", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["y",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`y[],
                 Editable->False], "2"], "+", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["z",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`z[],
                 Editable->False], "2"]}]], "]"}]}], 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["x",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`x[],
               Editable->False], "2"], "+", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["y",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`y[],
               Editable->False], "2"], "+", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["z",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`z[],
               Editable->False], "2"]}]]]}], "-", 
         RowBox[{
          SuperscriptBox["\[CapitalPhi]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["z",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`z[],
              Editable->False], "2"]}]], "]"}]}], ")"}]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{2, -$CellContext`chart5}, {
        2, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{3, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{4, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"G", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`EinsteinCD5[{5, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{
  3.577029287293281*^9, 3.577029363199185*^9, 3.577030877224667*^9, 
   3.577031018340974*^9, 3.577031160988118*^9, 3.577776982864023*^9, {
   3.577886776529772*^9, 3.577886784904337*^9}, 3.577886814963641*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RuleLaplace5D", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["x",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`x[],
         Editable->False], "2"], "+", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["y",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`y[],
         Editable->False], "2"], "+", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["z",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`z[],
         Editable->False], "2"]}]], "]"}], "\[Rule]", "  ", 
    RowBox[{"\[CapitalDelta]\[CapitalPhi]", "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["\[CapitalPhi]", "\[Prime]",
         MultilineFunction->None], "[", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["x",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`x[],
            Editable->False], "2"], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["y",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`y[],
            Editable->False], "2"], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["z",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`z[],
            Editable->False], "2"]}]], "]"}]}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["x",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`x[],
          Editable->False], "2"], "+", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["y",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`y[],
          Editable->False], "2"], "+", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["z",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`z[],
          Editable->False], "2"]}]]]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5770291763567953`*^9, 3.577029195274687*^9}, {
   3.5770294872786617`*^9, 3.577029507928322*^9}, {3.577029541227672*^9, 
   3.577029548781085*^9}, {3.577029606403873*^9, 3.5770296611723213`*^9}, {
   3.57702974713968*^9, 3.5770297663910027`*^9}, 3.577030941440302*^9, 
   3.577031051786459*^9, 3.577031094295611*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G11in5D", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"EinsteinCD5", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", " ", 
          RowBox[{"-", "chart5"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", 
          RowBox[{"-", "chart5"}]}], "}"}]}], "]"}], "/.", "RulesG5D"}], 
     ")"}], "/.", "RuleLaplace5D"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.5770288505472183`*^9, 3.5770289195800123`*^9}, {
  3.577029095543112*^9, 3.577029125152829*^9}, {3.5770292028261127`*^9, 
  3.5770292150333*^9}, {3.577029365802808*^9, 3.577029367284072*^9}, {
  3.577029739476575*^9, 3.577029760040073*^9}, {3.57703094569044*^9, 
  3.577030961654088*^9}, {3.57788682085402*^9, 3.5778868247988*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", 
  InterpretationBox[
   StyleBox["\[Kappa]",
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`kappa,
   Editable->False], " ", "\[CapitalDelta]\[CapitalPhi]", " ", 
  RowBox[{"\[Delta]", "[", 
   InterpretationBox[
    StyleBox["u",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`u[],
    Editable->False], "]"}]}]], "Output",
 CellChangeTimes->{{3.577028903752534*^9, 3.577028920659504*^9}, 
   3.5770290253009853`*^9, {3.577029093406294*^9, 3.577029125863483*^9}, {
   3.57702920434144*^9, 3.577029215912187*^9}, 3.57702932670857*^9, 
   3.5770293691864643`*^9, 3.577029511381171*^9, 3.577029552479895*^9, {
   3.577029618312009*^9, 3.5770296517908173`*^9}, {3.5770297402655363`*^9, 
   3.577029767783564*^9}, 3.5770309625988817`*^9, 3.577031097896119*^9, 
   3.577031164211926*^9, 3.577776987283907*^9, {3.577886809350997*^9, 
   3.577886825675564*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RulesRiemann5D", "=", 
   RowBox[{"TensorValues", "[", "RiemannCD5", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.577029379317245*^9, 3.577029400393564*^9}, {
  3.577030968176259*^9, 3.577030969822373*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Last", "@", "RulesRiemann5D"}], "/.", "RuleLaplace5D"}], " ", "//",
      "Simplify"}], ")"}], "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "]"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"y", "[", "]"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"z", "[", "]"}], "^", "2"}]}], "]"}], "\[Rule]", " ", 
     "\[Rho]"}], "}"}]}], "//", "Column"}]], "Input",
 CellChangeTimes->{{3.577029416508074*^9, 3.577029456269971*^9}, {
  3.577029564246395*^9, 3.5770295819036713`*^9}, {3.577029775885085*^9, 
  3.5770299570351954`*^9}, {3.577030348311557*^9, 3.577030359113861*^9}, {
  3.5770309753819437`*^9, 3.577030977282733*^9}, {3.577031104624518*^9, 
  3.57703110823658*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        2, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["x",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`x[],
                 Editable->False], "2"]}], "+", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["y",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`y[],
                Editable->False], "2"], "+", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["z",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`z[],
                Editable->False], "2"]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["z",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`z[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["x",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`x[],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["y",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`y[],
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]"}], "-", 
           RowBox[{"3", " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["z",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`z[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["x",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`x[],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["z",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`z[],
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]"}], "-", 
           RowBox[{"3", " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["z",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`z[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["x",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`x[],
                Editable->False], "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["y",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`y[],
                 Editable->False], "2"]}], "+", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["z",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`z[],
                Editable->False], "2"]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["z",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`z[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["y",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`y[],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["z",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`z[],
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]"}], "-", 
           RowBox[{"3", " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["z",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`z[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`kappa,
          Editable->False], " ", 
         RowBox[{"\[Delta]", "[", 
          InterpretationBox[
           StyleBox["u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[],
           Editable->False], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalDelta]\[CapitalPhi]", " ", "\[Rho]", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["z",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`z[],
              Editable->False], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox["x",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`x[],
                Editable->False], "2"], "+", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["y",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`y[],
                Editable->False], "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["z",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`z[],
                 Editable->False], "2"]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[CapitalPhi]", "\[Prime]",
              MultilineFunction->None], "[", "\[Rho]", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["x",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`x[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["y",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`y[],
              Editable->False], "2"], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["z",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`z[],
              Editable->False], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]]}]}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{1, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        3, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{2, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{3, -$CellContext`chart5}, {
        4, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{3, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]},
    {
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " ", " ", " "},
              {
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["4",
                FontColor->RGBColor[0., 1., 0.]], 
               StyleBox["5",
                FontColor->RGBColor[0., 1., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RiemannCD5[{4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}, {4, -$CellContext`chart5}, {
        5, -$CellContext`chart5}],
       Editable->False], "\[Rule]", "0"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{
  3.57702941749524*^9, 3.5770294570057898`*^9, 3.5770295143181133`*^9, {
   3.577029555130584*^9, 3.577029565339662*^9}, {3.577029771251424*^9, 
   3.577029868498781*^9}, {3.577029901737936*^9, 3.577029957802024*^9}, {
   3.577030350646538*^9, 3.5770303602696877`*^9}, 3.577030978455125*^9, 
   3.5770311090919228`*^9, 3.57703116695151*^9, 3.5777769977649593`*^9, 
   3.577886830949898*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Perturbation theory", "Section",
 CellChangeTimes->{{3.576566447031397*^9, 3.576566452374632*^9}, 
   3.576567341262224*^9, {3.577884020276823*^9, 3.577884021330508*^9}}],

Cell["\<\
This section illustrates the usage of the xPert package to deal with \
perturbations of a given background space-time, that can be applied to the AS \
shock wave collision problem. Except for section 2.3, most results apply to a \
generic background. \
\>", "Text",
 CellChangeTimes->{{3.577886993523849*^9, 3.57788709051971*^9}}],

Cell[BoxData["Quit"], "Input",
 CellChangeTimes->{{3.577638679405217*^9, 3.577638693454619*^9}}],

Cell[CellGroupData[{

Cell["2.1. Loading packages and definitions", "Subsection",
 CellChangeTimes->{{3.577883299683073*^9, 3.5778833118427467`*^9}, {
  3.5778840240986977`*^9, 3.577884026302844*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "xAct`xPert`"}]], "Input",
 CellChangeTimes->{{3.5776336687405653`*^9, 3.57763369943961*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.5778871254804277`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.0\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2013", ",", "1", ",", "27"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.0", ", ", {2013, 1, 27}],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887125483982*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2013, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887125586493*^9}],

Cell[BoxData["\<\"Connecting to external linux executable...\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887125593132*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887125598989*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887125604855*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.5\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2013", ",", "1", ",", "30"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.0.5", ", ", {2013, 1, 30}],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887125704885*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2013, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887125797505*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.5778871259175367`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2013", ",", "1", ",", "27"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.3", ", ", {2013, 1, 27}],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.5778871260294533`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2013, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887126102091*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.57788712614959*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887126198258*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.5778871262447443`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.5778871262953987`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887126350463*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887126402286*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887126486813*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.57788712652761*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefInertHead", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"inert head \"\>", "\[InvisibleSpace]", 
   "Perturbation", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefInertHead, ": Defining ", "inert head ", 
   xAct`xPert`Perturbation, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.577886867455345*^9, 3.577887126566195*^9}]
}, Open  ]]
}, Open  ]],

Cell["Some verbosity options:", "Text",
 CellChangeTimes->{{3.577887144715929*^9, 3.577887151981407*^9}}],

Cell[BoxData[
 RowBox[{"<<", "xAct`ShowTime1`"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$ShowTimeThreshold", "=", "0.1"}], ";"}]], "Input",
 CellChangeTimes->{{3.577624097871271*^9, 3.577624098855191*^9}}],

Cell["\<\
This is a combination of simplification commands of xTensor which is very \
useful so we define it for future usage on an expression expr. Basically it \
contracts metric factors explicitely and then it organises the result in a \
canonical form.\
\>", "Text",
 CellChangeTimes->{{3.577887176628253*^9, 3.5778872756410418`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"org", "[", "expr_", "]"}], ":=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"ContractMetric", "[", "expr", "]"}], ",", 
    "$PerturbationParameter", ",", "ToCanonical"}], "]"}]}]], "Input"],

Cell["\<\
This section will be for a generic \"d\", so we define a symbol for the \
dimension, dim, of the manifold:\
\>", "Text",
 CellChangeTimes->{{3.577887284609601*^9, 3.577887315412158*^9}, {
  3.5780741290488777`*^9, 3.578074140535026*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"dim", ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<d\>\""}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.577620660784809*^9, 3.577620662979289*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "dim", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`dim, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.57778403956463*^9, 3.5777859204303503`*^9, 
  3.5777862907431507`*^9, 3.577853361971189*^9, 3.577854086726528*^9, 
  3.577887279911592*^9}]
}, Open  ]],

Cell["Here is the definition of the manifolf M and its indices:", "Text",
 CellChangeTimes->{{3.577887320683795*^9, 3.577887333913349*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefManifold", "[", 
  RowBox[{"M", ",", "dim", ",", 
   RowBox[{"{", 
    RowBox[{
    "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "n", ",", "o",
      ",", "p"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.577617860169861*^9, 3.577617868958415*^9}, {
  3.577618663852174*^9, 3.577618664159707*^9}, {3.5777858819838457`*^9, 
  3.577785908537498*^9}, {3.577887384679288*^9, 3.577887388228104*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", "manifold ", $CellContext`M,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.57771943393892*^9, 3.5777205694968653`*^9, 
  3.577720711821711*^9, 3.577783006266515*^9, 3.577784040437244*^9, 
  3.57778592160039*^9, 3.577786297852852*^9, 3.577853363028347*^9, 
  3.577854087897089*^9, 3.577887336169622*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentM", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentM, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.57771943393892*^9, 3.5777205694968653`*^9, 
  3.577720711821711*^9, 3.577783006266515*^9, 3.577784040437244*^9, 
  3.57778592160039*^9, 3.577786297852852*^9, 3.577853363028347*^9, 
  3.577854087897089*^9, 3.577887336226334*^9}]
}, Open  ]]
}, Open  ]],

Cell["Now we define a metric and its covariant derivative:", "Text",
 CellChangeTimes->{{3.5778873396544857`*^9, 3.577887363497507*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefMetric", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "CD", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<;\>\"", ",", "\"\<D\>\""}], "}"}], ",", 
   RowBox[{"WeightedWithBasis", "\[Rule]", "AIndex"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5778873813920918`*^9, 3.577887390188677*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZBew7nE3x1IAwAlhcgB
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZAucFvi7w6kASVQyAI=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   
   RowBox[{"CD", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZCOubnc3x1IAwAox8iE
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZDmUFnt7w6kASFMx38=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZC+U7zO3x1IAwAqJ8il
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZAu2bTJ3x1IAwAouMiA
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZA2+L/Z3x1IAwAouciK
  "]],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZA2XLrV3x1IAwAmV8gz
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZA+rbvd3x1IAwAn68hX
  "]],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZCOu7PD3x1IAwApUsia
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZDe922nvzuQBgAtDskV
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZD2Ld3t7w6kASYLyCU=
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZBmu77H3x1IAwAmh8hB
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZCe7rbP3x1IAwAnJMhD
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox["d",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`dim,
    Editable->False]}],
  SequenceForm[
  "** DefCovD:  Computing RiemannToWeylRules for dim ", $CellContext`dim],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZDWm7jf3x1IAwAl78gm
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox["d",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`dim,
    Editable->False]}],
  SequenceForm[
  "** DefCovD:  Computing RicciToTFRicci for dim ", $CellContext`dim],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZCOfHvQ3x1IAwAp18iv
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox["d",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`dim,
    Editable->False]}],
  SequenceForm[
  "** DefCovD:  Computing RicciToEinsteinRules for dim ", $CellContext`dim],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZD+XHzY3x1IAwArXcjR
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZB+w3zU3x1IAwAoIchc
  "]],

Cell[BoxData["0.5000309999999999`"], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIFD5yVjyx/5WjA9HY/iM6bdpbvKJA+fzNIGkSzvZBU
AtE9i99ogGi+vsgVIJopnYfpGJD+n3FDGET/EP2lC6KXbLR5CqJrF86tPQ6k
wx365oJo2dNhZ0D0/OvBj0G0WJ7wRxC9YtW/oyeAdP/y1ftPAmk5kdD/IHra
RM0Np4D0nUUPkk8DaYnOY1Ugmke2Zi6Ijqqb+fwskF62MrP+OZC+YRfSA6L7
loomvgfS38SrnD8AaaP/9rc+Aumin5ILPwFpu1ePN4DoFY/eXwXRUqLlv0D0
NMmmwK9AmvlV7X0QbXrP4iOI7v/zOVpkxStHrztmd0H0jtsJJ0SB9KFFfD9A
9P6U5dvMgHSPqJGgOZD+YHTM3x1IAwApkMiQ
  "]]
}, Open  ]]
}, Open  ]],

Cell["Some rules for how to print out various quantities:", "Text",
 CellChangeTimes->{{3.577887369256802*^9, 3.577887373809093*^9}, 
   3.577887412396141*^9, {3.5778874440852757`*^9, 3.577887450215015*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
   "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], 
  ";"}]}], "Input"],

Cell["\<\
This is where the xPert specific part starts. First we have to define a \
symbol for the metric perturbations, h, and an expansion parameter \[Epsilon] \
(which actually will never appear explicitely because we will only look at \
order by order):\
\>", "Text",
 CellChangeTimes->{{3.577887460749167*^9, 3.5778875579463787`*^9}, 
   3.57807416299681*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefMetricPerturbation", "[", 
  RowBox[{"g", ",", "h", ",", "\[Epsilon]"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.5776337534210987`*^9, 3.5776340309819593`*^9, 
  3.577638724428521*^9, 3.577691138759796*^9, 3.577691240756249*^9, 
  3.577707276632505*^9, 3.577709088199622*^9, 3.5777123419107933`*^9, 
  3.577713932637175*^9, 3.577714058594657*^9, 3.577714355345187*^9, 
  3.5777146517338343`*^9, 3.577719445430719*^9, 3.577720578443041*^9, 
  3.5777207213965893`*^9, 3.577783011008472*^9, 3.5777840468753157`*^9, 
  3.577785926497696*^9, 3.577786307684553*^9, 3.577853372928979*^9, 
  3.5778540954292593`*^9, 3.577887559934122*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`h[
    xAct`xTensor`LI["order"], -$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.5776337534210987`*^9, 3.5776340309819593`*^9, 
  3.577638724428521*^9, 3.577691138759796*^9, 3.577691240756249*^9, 
  3.577707276632505*^9, 3.577709088199622*^9, 3.5777123419107933`*^9, 
  3.577713932637175*^9, 3.577714058594657*^9, 3.577714355345187*^9, 
  3.5777146517338343`*^9, 3.577719445430719*^9, 3.577720578443041*^9, 
  3.5777207213965893`*^9, 3.577783011008472*^9, 3.5777840468753157`*^9, 
  3.577785926497696*^9, 3.577786307684553*^9, 3.577853372928979*^9, 
  3.5778540954292593`*^9, 3.577887560000651*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Just an option to colour the indices of the perturbations (LI[] refers to the \
order of expansion)\
\>", "Text",
 CellChangeTimes->{{3.577887587922777*^9, 3.577887661033421*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "IndexForm", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"IndexForm", "[", 
    RowBox[{"LI", "[", "x_", "]"}], "]"}], ":=", 
   RowBox[{"ColorString", "[", 
    RowBox[{
     RowBox[{"ToString", "[", "x", "]"}], ",", 
     RowBox[{"RGBColor", "[", 
      RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "IndexForm", "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2. Einstein Equations in de Donder gauge", "Subsection",
 CellChangeTimes->{{3.576566577630527*^9, 3.576566590749295*^9}, 
   3.5765673412622967`*^9, {3.577884040896057*^9, 3.577884045989944*^9}}],

Cell["\<\
In this section we look at the perturbative Einstein equations order by \
order, and simplify them by using the de Donder gauge condition. 
First we ask xPert to give us the perturbation of the Einstein tensor to a \
given order and ask it to expand it. You can remove the ; if you would like \
to look at the equations however they are still messy at this stage. Here we \
define only the first 3 orders\
\>", "Text",
 CellChangeTimes->{{3.577887687379759*^9, 3.577887838881612*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Gab1", "=", 
   RowBox[{
    RowBox[{"Perturbation", "[", 
     RowBox[{"EinsteinCD", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}], "]"}], "//", "ExpandPerturbation"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5776180856328793`*^9, 3.577618097207411*^9}, {
   3.577618150041703*^9, 3.577618168697587*^9}, {3.5776207267068863`*^9, 
   3.577620728667162*^9}, {3.577620772011035*^9, 3.5776207722850323`*^9}, 
   3.57762265770057*^9, 3.577622702325636*^9, 3.577713941275612*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Gab2", "=", 
   RowBox[{
    RowBox[{"Perturbation", "[", 
     RowBox[{
      RowBox[{"EinsteinCD", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], ",", "2"}], "]"}], "//", 
    "ExpandPerturbation"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5776227049955482`*^9, 3.577622706894848*^9}, 
   3.577713944167654*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Gab3", "=", 
   RowBox[{
    RowBox[{"Perturbation", "[", 
     RowBox[{
      RowBox[{"EinsteinCD", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], ",", "3"}], "]"}], "//", 
    "ExpandPerturbation"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.577633768652225*^9, 3.577633775302619*^9}, 
   3.577713946799156*^9}],

Cell["\<\
We know that the trace reversed perturbation will simplify the equations when \
we impose the de Donder gauge. So we define a trace reversed (symmetric) \
perturbation:\
\>", "Text",
 CellChangeTimes->{{3.577887847681138*^9, 3.577887903017922*^9}, {
  3.577888054004531*^9, 3.5778880567899103`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
   RowBox[{"Symmetric", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
   RowBox[{"PrintAs", "\[Rule]", " ", "\"\<h\.b9\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.577618469131608*^9, 3.5776184772768097`*^9}, {
  3.577620825787718*^9, 3.577620852865636*^9}, {3.577622832887414*^9, 
  3.5776228699060993`*^9}, {3.5776301884006453`*^9, 3.577630190013775*^9}, {
  3.5776302469110727`*^9, 3.5776302516005173`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"h1", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`h1[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.577630252709777*^9, 3.577630735655579*^9, 
  3.577632146110497*^9, 3.577633794276918*^9, 3.577634046632132*^9, 
  3.5776388423510723`*^9, 3.5776912779241333`*^9, 3.577707298424651*^9, 
  3.577709123481185*^9, 3.5777123496724*^9, 3.5777139499812107`*^9, 
  3.577714065039206*^9, 3.577714360700013*^9, 3.577714661818757*^9, 
  3.57771945544501*^9, 3.577720601407827*^9, 3.577720734247465*^9, 
  3.5777830170437527`*^9, 3.5777840515200253`*^9, 3.5777859319155207`*^9, 
  3.57778631343711*^9, 3.577854101524397*^9, 3.5778879064803123`*^9}]
}, Open  ]],

Cell["\<\
... and then define a rule to replace the linear perturbation of xPert by the \
new trace re-versed tensor (derive the relation below)\
\>", "Text",
 CellChangeTimes->{{3.577887908843553*^9, 3.5778879572304068`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{
    RowBox[{"LI", "[", "1", "]"}], ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "-", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "d", "}"}], ",", 
      RowBox[{"h1", "[", 
       RowBox[{"d", ",", 
        RowBox[{"-", "d"}]}], "]"}]}], "]"}], 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"a", ",", "b"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"dim", "-", "2"}], ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.57762104334194*^9, 3.577621044750311*^9}, {
  3.577621098060663*^9, 3.577621101733655*^9}, {3.577621165649411*^9, 
  3.577621207928754*^9}, {3.577621256887212*^9, 3.577621277628379*^9}, {
  3.5776228403181553`*^9, 3.577622841717181*^9}}],

Cell["\<\
Now the linear Einstein equation is much simpler (note that we had to trick \
xPert into simplifying the expression through an intermediate step by \
replacing d-> X+2):\
\>", "Text",
 CellChangeTimes->{{3.5778879700133963`*^9, 3.577888030146554*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gab11", "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Gab1", "//", "Simplification"}], " ", ")"}], "/.", 
      RowBox[{"dim", "\[Rule]", " ", 
       RowBox[{"X", "+", "2"}]}]}], "//", "org"}], "//", "Simplification"}], 
   ")"}]}]], "Input"],

Cell[BoxData["0.3640230000000031`"], "Print",
 CellChangeTimes->{3.577720533804984*^9, 3.577720605844462*^9, 
  3.577720742434597*^9, 3.57778302068442*^9, 3.5777840541293983`*^9, 
  3.5777859342886963`*^9, 3.5777863152301807`*^9, 3.577854105384985*^9, 
  3.577887984822652*^9, 3.577888033409294*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"h\.b9", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h1[-$CellContext`a, -$CellContext`b],
       Editable->False]}], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False]}], "+", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", "  ", "  "},
            {"b", " ", 
             RowBox[{";", "a"}], 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h1[-$CellContext`b, $CellContext`c]]],
     Editable->False], "+", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", "  ", "  "},
            {"a", " ", 
             RowBox[{";", "b"}], 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h1[-$CellContext`a, $CellContext`c]]],
     Editable->False], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}], "  "},
            {"a", "b", "  ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
     Editable->False], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b9", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h1[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"R", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
         Editable->False]}], "-", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d", "  ", "  "},
               {" ", " ", 
                RowBox[{";", "c"}], 
                RowBox[{";", "d"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`h1[$CellContext`c, $CellContext`d]]],
        Editable->False]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5777205340019608`*^9, 3.577720605991453*^9, 
  3.57772074253386*^9, 3.57778302075778*^9, 3.577784054176156*^9, 
  3.5777859343411922`*^9, 3.577786315273408*^9, 3.577854105458956*^9, 
  3.5778879848998737`*^9, 3.5778880335005283`*^9}]
}, Open  ]],

Cell[TextData[{
 "Finally we impose various versions of the de Donder gauge ",
 Cell[BoxData[
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"a", "b", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`h1[$CellContext`a, $CellContext`b]],
    Editable->False], "=", "0"}]], "Output",
  CellChangeTimes->{{3.577888121674128*^9, 3.577888133916254*^9}}],
 " with indices up and down."
}], "Text",
 CellChangeTimes->{{3.577888105708143*^9, 3.577888147095271*^9}, {
  3.577888483004423*^9, 3.5778884910678663`*^9}, {3.57788860377702*^9, 
  3.577888609209585*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "a_"}], "]"}], "@", 
    RowBox[{"h1", "[", 
     RowBox[{"a_", ",", "b_"}], "]"}]}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "a_"}], "]"}], "@", 
    RowBox[{"h1", "[", 
     RowBox[{"a_", ",", 
      RowBox[{"-", "b_"}]}], "]"}]}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "a_"}], "]"}], "@", 
    RowBox[{"h1", "[", 
     RowBox[{
      RowBox[{"-", "b_"}], ",", "a_"}], "]"}]}], "=", "0"}], ";"}]}], "Input",\

 CellChangeTimes->{{3.577719345844252*^9, 3.5777193724101763`*^9}, {
  3.577719480000252*^9, 3.5777196017262*^9}, {3.577888127111856*^9, 
  3.577888155721755*^9}, {3.577888494004189*^9, 3.577888512759219*^9}, {
  3.5778885691136303`*^9, 3.5778885792575417`*^9}}],

Cell["And simplify:", "Text",
 CellChangeTimes->{{3.577888181899783*^9, 3.5778881905447197`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gab11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Gab1", "//", "Simplification"}], " ", ")"}], "/.", 
        RowBox[{"dim", "\[Rule]", " ", 
         RowBox[{"X", "+", "2"}]}]}], "//", "org"}], "//", "Simplification"}],
      ")"}], "//", "Simplification"}], "//", "org"}]}]], "Input",
 CellChangeTimes->{{3.5776210638742027`*^9, 3.577621064803637*^9}, {
   3.5776211042508163`*^9, 3.577621107413932*^9}, {3.5776213261426563`*^9, 
   3.5776213802049723`*^9}, 3.577621417489369*^9, {3.577621523427404*^9, 
   3.57762154006614*^9}, {3.577621691419881*^9, 3.5776217393552628`*^9}, {
   3.5776217722110043`*^9, 3.577621801179162*^9}, 3.5776228446670094`*^9, {
   3.577624381340088*^9, 3.577624415034877*^9}, {3.577624462948662*^9, 
   3.5776244975573883`*^9}, {3.577624967301311*^9, 3.577624969312892*^9}, 
   3.577625182128385*^9, {3.5776256238623238`*^9, 3.577625628806988*^9}, {
   3.57763074141926*^9, 3.577630756558381*^9}, {3.577713905399185*^9, 
   3.577713909501647*^9}, {3.577719935181785*^9, 3.5777199595484324`*^9}, {
   3.577720020152368*^9, 3.5777200760454073`*^9}, {3.577720152544347*^9, 
   3.577720155001832*^9}, {3.577720269647216*^9, 3.57772027048073*^9}}],

Cell[BoxData["0.43602700000002415`"], "Print",
 CellChangeTimes->{{3.577720051356722*^9, 3.5777200779061317`*^9}, {
   3.577720145492282*^9, 3.577720156862565*^9}, 3.577720219800417*^9, 
   3.577720272474132*^9, 3.5777203416998158`*^9, 3.5777206158404293`*^9, 
   3.577720752747117*^9, 3.577783024797276*^9, 3.577784060913884*^9, 
   3.57778593837052*^9, 3.577786319236341*^9, 3.577854110090829*^9, {
   3.577888065269738*^9, 3.577888095533245*^9}, 3.577888166642717*^9, {
   3.5778885169565496`*^9, 3.577888538039824*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`a, -$CellContext`b],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"c", "d"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[$CellContext`c, $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " "},
           {"c", "d"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[-$CellContext`a, -$CellContext`b],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox["R",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciScalarCD[],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c", "  ", "  "},
           {"b", " ", 
            RowBox[{";", "c"}], 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`CD[-$CellContext`c][
      $CellContext`h1[-$CellContext`b, $CellContext`c]]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c", "  ", "  "},
           {"b", " ", 
            RowBox[{";", "a"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`b, $CellContext`c]]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c", "  ", "  "},
           {"a", " ", 
            RowBox[{";", "b"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`a, $CellContext`c]]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", 
            RowBox[{";", "c"}], "  "},
           {"a", "b", "  ", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[$CellContext`c][
      $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{{3.577720051555893*^9, 3.5777200780610523`*^9}, {
   3.577720145690195*^9, 3.577720157051964*^9}, 3.577720219925117*^9, 
   3.577720272667427*^9, 3.5777203418555393`*^9, 3.577720615943719*^9, 
   3.5777207528492947`*^9, 3.5777830248480463`*^9, 3.577784060955258*^9, 
   3.577785938408839*^9, 3.5777863192984657`*^9, 3.57785411016814*^9, {
   3.577888065343004*^9, 3.577888095614931*^9}, 3.577888166671598*^9, {
   3.577888517042367*^9, 3.577888538136352*^9}}]
}, Open  ]],

Cell["\<\
Some times xTensor does not express the final expressions in the best form. \
In the previous line we see that it would have been useful to use Riemann \
type identities to commute covariant derivatives and then the de Donder gauge \
condition would zeroe some terms. We can tell xTensor to do so explicitely. \
Here first we define the expression on the right hand side of the Riemann \
identity we need:\
\>", "Text",
 CellChangeTimes->{{3.577888199573391*^9, 3.577888308008913*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Exp1", "=", " ", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"d", ",", 
     RowBox[{"-", "c"}]}], "]"}], 
   RowBox[{"CommuteCovDs", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "d"}], "]"}], "[", 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "a"}], "]"}], "[", 
       RowBox[{"h1", "[", 
        RowBox[{
         RowBox[{"-", "b"}], ",", "c"}], "]"}], "]"}], "]"}], ",", "CD", ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "d"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.577719628281097*^9, 3.577719700403636*^9}, {
  3.577719750373335*^9, 3.57771979498862*^9}, {3.577719828079217*^9, 
  3.577719928145604*^9}, {3.577720001514263*^9, 3.577720006466161*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[-$CellContext`b, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"d", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[-$CellContext`d, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " ", " ", "d"},
           {"a", "c", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, -$CellContext`b, \
$CellContext`d],
    Editable->False]}], "+", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"h\.b9", 
       StyleBox[GridBox[{
          {" ", "c", "  ", "  "},
          {"b", " ", 
           RowBox[{";", "c"}], 
           RowBox[{";", "a"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`a][
    $CellContext`CD[-$CellContext`c][
     $CellContext`h1[-$CellContext`b, $CellContext`c]]],
   Editable->False]}]], "Output",
 CellChangeTimes->{{3.577719879631304*^9, 3.5777199322436247`*^9}, {
   3.577720003531947*^9, 3.57772000712399*^9}, 3.577720304239612*^9, 
   3.577720625431087*^9, 3.5777207583248158`*^9, 3.577783026688511*^9, 
   3.577784062729619*^9, 3.577785939863739*^9, 3.577786320875761*^9, 
   3.577854111443179*^9, 3.577888310963914*^9}]
}, Open  ]],

Cell["... and then create a rule to commute the derivatives", "Text",
 CellChangeTimes->{{3.577888313354985*^9, 3.577888325082665*^9}, {
  3.5778883605548487`*^9, 3.5778883626712217`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CD", "[", 
    RowBox[{"-", "c_"}], "]"}], "[", 
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "a_"}], "]"}], "[", 
    RowBox[{"h1", "[", 
     RowBox[{
      RowBox[{"-", "b_"}], ",", "c_"}], "]"}], "]"}], "]"}], "=", 
  "Exp1"}]], "Input",
 CellChangeTimes->{{3.5777201278918047`*^9, 3.577720140825732*^9}, {
   3.5777202039553127`*^9, 3.577720214115139*^9}, 3.5777202980170527`*^9, {
   3.577720373915474*^9, 3.577720374679082*^9}, {3.577720791275725*^9, 
   3.577720818418087*^9}, 3.577888441873123*^9, {3.577888532831897*^9, 
   3.57788854522244*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[-$CellContext`b, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"d", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[-$CellContext`d, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " ", " ", "d"},
           {"a", "c", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, -$CellContext`b, \
$CellContext`d],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{3.577888549248*^9, 3.5778885881682377`*^9}]
}, Open  ]],

Cell["...and find a simpler version", "Text",
 CellChangeTimes->{{3.577888624339199*^9, 3.577888632503439*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gab11", "//", "Simplification"}]], "Input",
 CellChangeTimes->{{3.577720387800269*^9, 3.577720398065097*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b9", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"b", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h1[-$CellContext`b, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b9", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"a", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h1[-$CellContext`a, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b9", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h1[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"c", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
      Editable->False]}], "-", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b9", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h1[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False]}], "-", 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b9", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h1[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " ", " ", " "},
             {"a", "c", "b", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, \
-$CellContext`b, -$CellContext`d],
      Editable->False]}], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}], "  "},
            {"a", "b", "  ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.577720391828856*^9, 3.5777203989971333`*^9}, 
   3.577720633949729*^9, 3.577720766277179*^9, 3.577783029801716*^9, 
   3.577784065839725*^9, 3.577785942087566*^9, 3.5777863236505413`*^9, 
   3.5778541143866796`*^9, 3.5778884493082*^9, 3.577888552067727*^9, 
   3.577888591662532*^9}]
}, Open  ]],

Cell["\<\
Now we go to the 2nd order and define again a trace-reversed tensor to work \
with:\
\>", "Text",
 CellChangeTimes->{{3.577888637654711*^9, 3.5778886543075943`*^9}, {
  3.577888729066053*^9, 3.577888735805456*^9}, {3.577888803007193*^9, 
  3.5778888161277657`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"h2", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
   RowBox[{"Symmetric", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
   RowBox[{"PrintAs", "\[Rule]", " ", "\"\<h\.b2\>\""}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"h2", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`h2[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.577783033232485*^9, 3.5777840683702927`*^9, 
  3.577785945269445*^9, 3.57778632650448*^9, 3.577854116655629*^9, 
  3.577888668108541*^9}]
}, Open  ]],

Cell["\<\
... and replace it in all expressions:\
\>", "Text",
 CellChangeTimes->{{3.577888819277411*^9, 3.577888839946789*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{
    RowBox[{"LI", "[", "2", "]"}], ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"h2", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "-", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "d", "}"}], ",", 
      RowBox[{"h2", "[", 
       RowBox[{"d", ",", 
        RowBox[{"-", "d"}]}], "]"}]}], "]"}], 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"a", ",", "b"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"dim", "-", "2"}], ")"}]}]}]}]}]], "Input"],

Cell["... simplify 2nd order equatios with this replacement", "Text",
 CellChangeTimes->{{3.577888849190194*^9, 3.577888874682002*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Gab22", "=", 
   RowBox[{
    RowBox[{"Gab2", "//", "org"}], "//", "Simplification"}]}], ";"}]], "Input",\

 CellChangeTimes->{3.5777140995607853`*^9}],

Cell[BoxData["3.536220999999955`"], "Print",
 CellChangeTimes->{3.577720803476593*^9, 3.577720840506894*^9, 
  3.577783038721889*^9, 3.5777840743740597`*^9, 3.577785953331455*^9, 
  3.577786331738131*^9, 3.577854126816984*^9, 3.5778886761752243`*^9}]
}, Open  ]],

Cell["\<\
Now we use a trick to read the left hand side of the \"wave\"-like equation. \
We zeroe the lower order perturbation for a moment...\
\>", "Text",
 CellChangeTimes->{{3.5778888800342093`*^9, 3.577888925210286*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], ":=", "0"}], ";"}]], "Input"],

Cell["... and evaluate", "Text",
 CellChangeTimes->{{3.5778889287166777`*^9, 3.5778889331174097`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gableft", "=", 
  RowBox[{"Gab22", "//", "Simplification"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"b", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`b, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"a", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`a, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"c", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
      Editable->False]}], "-", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False]}], "-", 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " ", " ", " "},
             {"a", "c", "b", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, \
-$CellContext`b, -$CellContext`d],
      Editable->False]}], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}], "  "},
            {"a", "b", "  ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`h2[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5777146867753887`*^9, 3.577720844602757*^9, 
  3.577783041652749*^9, 3.577784077253422*^9, 3.5777859557908697`*^9, 
  3.577786335243393*^9, 3.5778541307683573`*^9, 3.5778886783166656`*^9, 
  3.577888758770184*^9, 3.5778889370516577`*^9}]
}, Open  ]],

Cell["Again impose de Donder gauge through rules", "Text",
 CellChangeTimes->{{3.57788895713754*^9, 3.577888969112699*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "a_"}], "]"}], "@", 
    RowBox[{"h2", "[", 
     RowBox[{"a_", ",", "b_"}], "]"}]}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "a_"}], "]"}], "@", 
    RowBox[{"h2", "[", 
     RowBox[{"b_", ",", "a_"}], "]"}]}], ":=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.577719345844252*^9, 3.5777193724101763`*^9}, {
  3.577719480000252*^9, 3.5777196017262*^9}, {3.577721024793189*^9, 
  3.577721024890398*^9}, {3.577888744754908*^9, 3.577888744981999*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gableft", "//", "Simplification"}]], "Input",
 CellChangeTimes->{{3.5777210436765614`*^9, 3.577721047972781*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"b", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`b, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"a", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`a, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"c", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
      Editable->False]}], "-", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False]}], "-", 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " ", " ", " "},
             {"a", "c", "b", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, \
-$CellContext`b, -$CellContext`d],
      Editable->False]}], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}], "  "},
            {"a", "b", "  ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`h2[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.577720981442824*^9, {3.577721028929915*^9, 3.577721062340996*^9}, 
   3.5777830458133593`*^9, 3.577784082073266*^9, 3.577785958779314*^9, 
   3.577786338854682*^9, 3.577854134837082*^9, 3.577888691293725*^9, 
   3.57788878043075*^9, 3.577888973255846*^9}]
}, Open  ]],

Cell["... to simplify need rule to commute covariante derivatives", "Text",
 CellChangeTimes->{{3.5778889777568693`*^9, 3.577888989515245*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Exp2", "=", " ", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"d", ",", 
     RowBox[{"-", "c"}]}], "]"}], 
   RowBox[{"CommuteCovDs", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "d"}], "]"}], "[", 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "a"}], "]"}], "[", 
       RowBox[{"h2", "[", 
        RowBox[{
         RowBox[{"-", "b"}], ",", "c"}], "]"}], "]"}], "]"}], ",", "CD", ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "d"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.57772086840617*^9, 3.577720871257056*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b2", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h2[-$CellContext`b, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b2", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"d", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h2[-$CellContext`d, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " ", " ", "d"},
           {"a", "c", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, -$CellContext`b, \
$CellContext`d],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{3.577720873394925*^9, 3.577721103477388*^9, 
  3.5777830477323008`*^9, 3.5777840836436872`*^9, 3.577785960143711*^9, 
  3.577786340290888*^9, 3.5778541363133373`*^9, 3.57788870303237*^9, 
  3.577888993262892*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", 
      RowBox[{"-", "a_"}], "]"}], "[", 
     RowBox[{"h2", "[", 
      RowBox[{
       RowBox[{"-", "b_"}], ",", "c_"}], "]"}], "]"}], "]"}], "=", "Exp2"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.577721138828043*^9, 3.577721140795351*^9}, 
   3.577888698880422*^9, {3.5778887703219976`*^9, 3.577888784401346*^9}}],

Cell["\<\
Now we get exactly the same  operator acting on the trace reverse \
perturbation!!!\
\>", "Text",
 CellChangeTimes->{{3.577889007282651*^9, 3.577889027829461*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gableft", "//", "Simplification"}]], "Input",
 CellChangeTimes->{{3.577721143236755*^9, 3.57772115901928*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"b", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`b, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"a", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`a, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"c", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
      Editable->False]}], "-", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False]}], "-", 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " ", " ", " "},
             {"a", "c", "b", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, \
-$CellContext`b, -$CellContext`d],
      Editable->False]}], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}], "  "},
            {"a", "b", "  ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`h2[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.577721144988832*^9, 3.577721159931531*^9}, 
   3.577783050872514*^9, 3.5777840867014008`*^9, 3.577785962379377*^9, 
   3.5777863425983877`*^9, 3.577854139621455*^9, 3.577888711482719*^9, 
   3.577888793698159*^9, 3.577888998565836*^9}]
}, Open  ]],

Cell["\<\
Now we remove the rule which is setting the linear perturbation to zero.\
\>", "Text",
 CellChangeTimes->{{3.577889037017083*^9, 3.577889062984764*^9}, {
  3.577889107288612*^9, 3.577889110594729*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "=."}], ";"}]], "Input",
 CellChangeTimes->{{3.577714730582391*^9, 3.577714732249614*^9}}],

Cell["\<\
We can even go to higher order (3rd) to check indeed that the \"wave\"-like \
operator is always the same\
\>", "Text",
 CellChangeTimes->{{3.577889114866576*^9, 3.577889150473933*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"h3", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
   RowBox[{"Symmetric", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
   RowBox[{"PrintAs", "\[Rule]", " ", "\"\<h\.b3\>\""}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"h3", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`h3[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.577714760617241*^9, 3.577722128785201*^9, 
  3.5777830550185537`*^9, 3.57778409072244*^9, 3.5777859657196283`*^9, 
  3.577786346433504*^9, 3.577854143604108*^9, 3.5778891550527687`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{
    RowBox[{"LI", "[", "3", "]"}], ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"h3", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "-", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "d", "}"}], ",", 
      RowBox[{"h3", "[", 
       RowBox[{"d", ",", 
        RowBox[{"-", "d"}]}], "]"}]}], "]"}], 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"a", ",", "b"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"dim", "-", "2"}], ")"}]}]}]}]}]], "Input"],

Cell["... same trick as before to get right hand side!", "Text",
 CellChangeTimes->{{3.577889204686296*^9, 3.5778892134750547`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h2", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], ":=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5777148254641457`*^9, 3.577714828609968*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gableft3", "=", 
  RowBox[{
   RowBox[{"Gab3", "//", "org"}], "//", "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.5777148364165373`*^9, 3.577714840697295*^9}, {
   3.577714914838789*^9, 3.57771491632514*^9}, 3.577714972679369*^9, {
   3.577715002932104*^9, 3.577715033306099*^9}}],

Cell[BoxData["0.30801899999994475`"], "Print",
 CellChangeTimes->{{3.5777150299501343`*^9, 3.57771503437423*^9}, 
   3.577722136315816*^9, 3.57778305900062*^9, 3.577784095573896*^9, 
   3.577785969954734*^9, 3.577786351921967*^9, 3.577854148557024*^9, 
   3.577889158879879*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"h\.b3", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h3[-$CellContext`a, -$CellContext`b],
       Editable->False]}], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False]}], "+", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b3", 
         StyleBox[GridBox[{
            {" ", "c", "  ", "  "},
            {"b", " ", 
             RowBox[{";", "a"}], 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h3[-$CellContext`b, $CellContext`c]]],
     Editable->False], "+", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b3", 
         StyleBox[GridBox[{
            {" ", "c", "  ", "  "},
            {"a", " ", 
             RowBox[{";", "b"}], 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h3[-$CellContext`a, $CellContext`c]]],
     Editable->False], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b3", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}], "  "},
            {"a", "b", "  ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`h3[-$CellContext`a, -$CellContext`b]]],
     Editable->False], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b3", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h3[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"R", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
         Editable->False]}], "-", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b3", 
            StyleBox[GridBox[{
               {"c", "d", "  ", "  "},
               {" ", " ", 
                RowBox[{";", "c"}], 
                RowBox[{";", "d"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`h3[$CellContext`c, $CellContext`d]]],
        Editable->False]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.577714904301845*^9, 3.577714917749311*^9}, {
   3.577714999666172*^9, 3.577715034414168*^9}, 3.5777221363897457`*^9, 
   3.577783059074461*^9, 3.577784095618721*^9, 3.577785970017171*^9, 
   3.577786351993075*^9, 3.577854148657227*^9, 3.577889158989431*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "a_"}], "]"}], "@", 
    RowBox[{"h3", "[", 
     RowBox[{"a_", ",", "b_"}], "]"}]}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "a_"}], "]"}], "@", 
    RowBox[{"h3", "[", 
     RowBox[{"b_", ",", "a_"}], "]"}]}], ":=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.577719345844252*^9, 3.5777193724101763`*^9}, {
  3.577719480000252*^9, 3.5777196017262*^9}, {3.577721024793189*^9, 
  3.577721024890398*^9}, {3.577722265735758*^9, 3.577722265828926*^9}, {
  3.577889166492714*^9, 3.577889166919969*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gableft3", "//", "Simplification"}]], "Input",
 CellChangeTimes->{{3.577722191186401*^9, 3.5777221938713303`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b3", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h3[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"c", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
      Editable->False]}], "-", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b3", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h3[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False]}], "+", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b3", 
         StyleBox[GridBox[{
            {" ", "c", "  ", "  "},
            {"b", " ", 
             RowBox[{";", "a"}], 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h3[-$CellContext`b, $CellContext`c]]],
     Editable->False], "+", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b3", 
         StyleBox[GridBox[{
            {" ", "c", "  ", "  "},
            {"a", " ", 
             RowBox[{";", "b"}], 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h3[-$CellContext`a, $CellContext`c]]],
     Editable->False], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b3", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}], "  "},
            {"a", "b", "  ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`h3[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5777221948672123`*^9, {3.577722250287838*^9, 3.5777222730855827`*^9}, 
   3.577783062412013*^9, 3.577784099952327*^9, 3.577785974491274*^9, 
   3.577786355128811*^9, 3.577854152244499*^9, 3.577889172839302*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Exp3", "=", " ", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"d", ",", 
     RowBox[{"-", "c"}]}], "]"}], 
   RowBox[{"CommuteCovDs", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "d"}], "]"}], "[", 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "a"}], "]"}], "[", 
       RowBox[{"h3", "[", 
        RowBox[{
         RowBox[{"-", "b"}], ",", "c"}], "]"}], "]"}], "]"}], ",", "CD", ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "d"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.57772086840617*^9, 3.577720871257056*^9}, {
  3.5777222270431023`*^9, 3.5777222310396757`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b3", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h3[-$CellContext`b, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b3", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"d", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h3[-$CellContext`d, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"R", 
        StyleBox[GridBox[{
           {" ", " ", " ", "d"},
           {"a", "c", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, -$CellContext`b, \
$CellContext`d],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{
  3.577720873394925*^9, 3.577721103477388*^9, {3.577722232555779*^9, 
   3.577722277106168*^9}, 3.577783063852762*^9, 3.577784101471118*^9, 
   3.577785975884001*^9, 3.5777863570706673`*^9, 3.577854153899968*^9, 
   3.57788917511408*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", 
      RowBox[{"-", "a_"}], "]"}], "[", 
     RowBox[{"h3", "[", 
      RowBox[{
       RowBox[{"-", "b_"}], ",", "c_"}], "]"}], "]"}], "]"}], "=", "Exp3"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.577721138828043*^9, 3.577721140795351*^9}, {
   3.577722280916876*^9, 3.577722301552496*^9}, 3.577889178136271*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gableft3", "//", "Simplification"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b3", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"b", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h3[-$CellContext`b, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`a, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b3", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"a", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h3[-$CellContext`a, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b3", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h3[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " "},
             {"c", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciCD[-$CellContext`c, -$CellContext`d],
      Editable->False]}], "-", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b3", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h3[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False]}], "-", 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b3", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h3[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"R", 
          StyleBox[GridBox[{
             {" ", " ", " ", " "},
             {"a", "c", "b", "d"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RiemannCD[-$CellContext`a, -$CellContext`c, \
-$CellContext`b, -$CellContext`d],
      Editable->False]}], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b3", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}], "  "},
            {"a", "b", "  ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`h3[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.57772229221712*^9, 3.57772230428328*^9}, 
   3.577783067225418*^9, 3.5777841045412273`*^9, 3.577785978654767*^9, 
   3.577786360371769*^9, 3.577854157290077*^9, 3.5778891858702183`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h2", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "=."}], ";"}]}], "Input",
 CellChangeTimes->{{3.577714953757489*^9, 3.5777149573543663`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3. Wave equations in flat space", "Subsection",
 CellChangeTimes->{{3.57788418715592*^9, 3.577884203861093*^9}}],

Cell["In this section we specialise to flat space. ", "Text",
 CellChangeTimes->{{3.577889234741602*^9, 3.577889248154624*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"RiemannCD", "[", 
    RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RicciCD", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RicciScalarCD", "[", "]"}], "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.577889327608232*^9, 3.577889340094426*^9}}],

Cell["\<\
... de Donder gauge conditions when covariant derivatives are the same as \
partial derivatives!\
\>", "Text",
 CellChangeTimes->{{3.577889275397735*^9, 3.5778893021558323`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{"h1", "[", 
     RowBox[{"c_", ",", "a_"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{"h1", "[", 
     RowBox[{"a_", ",", "c_"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "d_", "]"}], "[", 
     RowBox[{"h1", "[", 
      RowBox[{"c_", ",", "a_"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "d_", "]"}], "[", 
     RowBox[{"h1", "[", 
      RowBox[{"a_", ",", "c_"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.577625335373493*^9, 3.5776253972530622`*^9}, {
  3.5776254383245773`*^9, 3.577625518462504*^9}, {3.577625703841383*^9, 
  3.577625812185586*^9}, {3.5776302746570797`*^9, 3.577630314734755*^9}, {
  3.577709013286675*^9, 3.577709054053299*^9}, {3.5777091533578444`*^9, 
  3.577709173415511*^9}, {3.577711372717462*^9, 3.577711392658362*^9}, {
  3.577715082591063*^9, 3.577715091452221*^9}}],

Cell["We get the wave operator as expected:", "Text",
 CellChangeTimes->{{3.577889386100171*^9, 3.5778893924987707`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gab11", "//", "Simplification"}]], "Input",
 CellChangeTimes->{
  3.577625631623608*^9, {3.5777091760761423`*^9, 3.577709197736516*^9}, {
   3.577709449935059*^9, 3.577709477484557*^9}, {3.577709617163176*^9, 
   3.577709701935266*^9}, {3.5777097589996443`*^9, 3.577709766270883*^9}, {
   3.577709966918178*^9, 3.577709967451894*^9}, 3.577710007073481*^9, {
   3.577710179223357*^9, 3.577710193945962*^9}, {3.577710248155548*^9, 
   3.577710254303171*^9}, {3.5777106219867363`*^9, 3.577710639953803*^9}, {
   3.5777106792042427`*^9, 3.5777106795409317`*^9}, {3.577710711549404*^9, 
   3.57771072005387*^9}, {3.577710805213786*^9, 3.577710826101314*^9}, {
   3.5777108599356403`*^9, 3.577710883267294*^9}, {3.577711205386477*^9, 
   3.577711236922718*^9}, {3.57771146269765*^9, 3.57771147666329*^9}, {
   3.577711519143322*^9, 3.577711523476721*^9}, {3.577711569923712*^9, 
   3.577711705553608*^9}, 3.5777122245600243`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"h\.b9", 
       StyleBox[GridBox[{
          {" ", " ", 
           RowBox[{";", "c"}], "  "},
          {"a", "b", "  ", 
           RowBox[{";", "c"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`c][
    $CellContext`CD[$CellContext`c][
     $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
   Editable->False]}]], "Output",
 CellChangeTimes->{
  3.5777100080798407`*^9, 3.577710194835*^9, 3.5777102508281384`*^9, 
   3.577710640901123*^9, {3.5777106756833076`*^9, 3.577710680391238*^9}, {
   3.577710716117888*^9, 3.577710720467945*^9}, {3.577710814816326*^9, 
   3.577710826953*^9}, 3.577710884123981*^9, {3.577711206419087*^9, 
   3.57771123796206*^9}, {3.577711386256852*^9, 3.577711395087496*^9}, {
   3.5777115738737717`*^9, 3.577711612912476*^9}, {3.577711659567484*^9, 
   3.577711706678268*^9}, 3.5777122253817167`*^9, 3.577712361771749*^9, 
   3.5777151018017063`*^9, 3.577722333619076*^9, 3.577783086952197*^9, 
   3.57778411336952*^9, 3.577785985037422*^9, 3.577786368785981*^9, 
   3.577854165272678*^9, 3.5778893067939034`*^9, 3.577889344529359*^9}]
}, Open  ]],

Cell["same for second order:", "Text",
 CellChangeTimes->{{3.57788935407904*^9, 3.577889359511949*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{"h2", "[", 
     RowBox[{"c_", ",", "a_"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{"h2", "[", 
     RowBox[{"a_", ",", "c_"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "d_", "]"}], "[", 
     RowBox[{"h2", "[", 
      RowBox[{"c_", ",", "a_"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "d_", "]"}], "[", 
     RowBox[{"h2", "[", 
      RowBox[{"a_", ",", "c_"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.577715134196528*^9, 3.5777151385557623`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Gab22", "=", 
   RowBox[{
    RowBox[{"Gab2", "//", "org"}], "//", "Simplification"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.5776230105954857`*^9, 3.57762301075042*^9}, 
   3.577623048588769*^9, {3.577623078689952*^9, 3.577623081155266*^9}, {
   3.577624521650243*^9, 3.577624629096365*^9}, {3.577625665310371*^9, 
   3.577625666832264*^9}, 3.577714121310816*^9, {3.5777151238091927`*^9, 
   3.5777151721246443`*^9}}],

Cell[BoxData["2.216138000000001`"], "Print",
 CellChangeTimes->{{3.577624541382053*^9, 3.577624631993393*^9}, {
   3.5776256499745197`*^9, 3.57762567056763*^9}, 3.577625868640719*^9, 
   3.577626240045082*^9, 3.577626431022299*^9, 3.577626541061241*^9, 
   3.577628237317927*^9, 3.5776303298646517`*^9, 3.5776307728926487`*^9, 
   3.577632161857312*^9, 3.577633809583385*^9, 3.5776340601479197`*^9, 
   3.5776389252445183`*^9, 3.577691318380769*^9, 3.577708273599416*^9, 
   3.577712371929288*^9, 3.577714125085416*^9, {3.577715114652255*^9, 
   3.577715174773546*^9}, 3.57772235287436*^9, 3.577783091529118*^9, 
   3.577784118073995*^9, 3.577785989286869*^9, 3.5777863751183043`*^9, 
   3.577854173546772*^9, 3.5778893645877523`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], ":=", "0"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gableft", "=", 
  RowBox[{"Gab22", "//", "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.5777141536285458`*^9, 3.577714172656193*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"h\.b2", 
       StyleBox[GridBox[{
          {" ", " ", 
           RowBox[{";", "c"}], "  "},
          {"a", "b", "  ", 
           RowBox[{";", "c"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`c][
    $CellContext`CD[$CellContext`c][
     $CellContext`h2[-$CellContext`a, -$CellContext`b]]],
   Editable->False]}]], "Output",
 CellChangeTimes->{{3.577714145274754*^9, 3.5777141734107447`*^9}, 
   3.577715181601636*^9, 3.5777223539567204`*^9, 3.5777830942866993`*^9, 
   3.577784120846724*^9, 3.577785990786049*^9, 3.577786375534472*^9, 
   3.577854175944862*^9, 3.5778893691463013`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "=."}], ";"}]], "Input",
 CellChangeTimes->{{3.577714201108513*^9, 3.577714202443177*^9}}],

Cell["\<\
Now for the right hand side (which gives the source energy momentum tensor) \
we can use the fact that in the AS shocks case the trace of the linear \
perturbation is zero\
\>", "Text",
 CellChangeTimes->{{3.577889404371565*^9, 3.577889439137229*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", 
     RowBox[{"-", "a_"}]}], "]"}], "=", "0"}], ";"}]], "Input"],

Cell["\<\
Also we impose the wave equation for the linear order perturbation\
\>", "Text",
 CellChangeTimes->{{3.577889446260517*^9, 3.5778894628534184`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   TagBox[
    StyleBox[
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "c_"}], "]"}], "[", 
      RowBox[{
       RowBox[{"CD", "[", "c_", "]"}], "[", 
       RowBox[{"h1", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "]"}],
     ShowSpecialCharacters->False,
     ShowStringCharacters->True,
     NumberMarks->True],
    FullForm], ":=", "0"}], ";"}]], "Input"],

Cell["And finally get the expression for the source!", "Text",
 CellChangeTimes->{{3.5778894850610237`*^9, 3.577889493371381*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GabRight", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Gab22", "-", "Gableft"}], ")"}], "//", "org"}], "//", 
         "Simplification"}], ")"}], "/.", 
       RowBox[{"dim", "\[Rule]", " ", 
        RowBox[{"X", "+", "2"}]}]}], "//", "org"}], "//", "ToCanonical"}], 
    ",", 
    RowBox[{"g", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData["0.5280330000000504`"], "Print",
 CellChangeTimes->{
  3.577714216807599*^9, {3.577715206124538*^9, 3.5777152342790327`*^9}, 
   3.577716111527676*^9, 3.577722369182102*^9, 3.577783100114238*^9, 
   3.577784126960845*^9, 3.577785995227083*^9, 3.577786383328158*^9, 
   3.5778541825832233`*^9, 3.577889470476824*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"c", "d"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[$CellContext`c, $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  ", "  "},
           {"c", "d", 
            RowBox[{";", "b"}], 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`c, -$CellContext`d]]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"c", "d", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`h1[$CellContext`c, $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"c", "d", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`h1[-$CellContext`c, -$CellContext`d]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"c", "d"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[$CellContext`c, $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  ", "  "},
           {"b", "c", 
            RowBox[{";", "a"}], 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`b, -$CellContext`c]]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"c", "d"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[$CellContext`c, $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  ", "  "},
           {"a", "c", 
            RowBox[{";", "b"}], 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`a, -$CellContext`c]]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"c", "d"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h1[$CellContext`c, $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  ", "  "},
           {"a", "b", 
            RowBox[{";", "c"}], 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`c][
      $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"b", "d", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`h1[-$CellContext`b, -$CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c", 
            RowBox[{";", "d"}]},
           {"a", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`d][
     $CellContext`h1[-$CellContext`a, $CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"b", "c", 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`h1[-$CellContext`b, -$CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", "c", 
            RowBox[{";", "d"}]},
           {"a", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`d][
     $CellContext`h1[-$CellContext`a, $CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`a, -$CellContext`b],
    Editable->False], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"h\.b9", 
           StyleBox[GridBox[{
              {" ", " ", "  "},
              {"c", "e", 
               RowBox[{";", "d"}]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`d][
        $CellContext`h1[-$CellContext`c, -$CellContext`e]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"h\.b9", 
           StyleBox[GridBox[{
              {"c", "d", 
               RowBox[{";", "e"}]},
              {" ", " ", "  "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`e][
        $CellContext`h1[$CellContext`c, $CellContext`d]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["3", "4"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"h\.b9", 
           StyleBox[GridBox[{
              {" ", " ", "  "},
              {"c", "d", 
               RowBox[{";", "e"}]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`e][
        $CellContext`h1[-$CellContext`c, -$CellContext`d]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"h\.b9", 
           StyleBox[GridBox[{
              {"c", "d", 
               RowBox[{";", "e"}]},
              {" ", " ", "  "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`e][
        $CellContext`h1[$CellContext`c, $CellContext`d]],
       Editable->False]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.57771421688929*^9, {3.577715206170451*^9, 3.577715234324059*^9}, 
   3.577716111568879*^9, 3.577722369314785*^9, 3.5777831001544867`*^9, 
   3.577784127009618*^9, 3.577785995295657*^9, 3.5777863834002943`*^9, 
   3.577854182692154*^9, 3.577889470574732*^9}]
}, Open  ]],

Cell["Now we can check conservation.", "Text",
 CellChangeTimes->{{3.5778895010090227`*^9, 3.577889508287714*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"X", ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<X\>\""}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.577716276443306*^9, 3.57771629254111*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", "X", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`X, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.577716293411932*^9, 3.577722380608714*^9, 
  3.5777831025691977`*^9, 3.577784129631312*^9, 3.577785996304103*^9, 
  3.5777863850606613`*^9, 3.577854184004384*^9}]
}, Open  ]],

Cell["Since we are in flat space we impose the connection is zero", "Text",
 CellChangeTimes->{{3.5778895122368*^9, 3.577889524690551*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], ":=", "0"}], ";"}]], "Input",\

 CellChangeTimes->{{3.577715477648963*^9, 3.577715490688693*^9}}],

Cell["\<\
Apply the covariante derivative and convert to partial derivatives. The \
result are terms which vanish under the de Donder gauge condition, so \
conservation is checked.\
\>", "Text",
 CellChangeTimes->{{3.577889535826892*^9, 3.577889599805599*^9}, 
   3.5780743461908283`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", "a", "]"}], "@", "GabRight"}], "//", 
     "Simplification"}], "//", "org"}], "//", "ChangeCovD"}], "//", 
  "Simplification"}]], "Input",
 CellChangeTimes->{{3.577631205004023*^9, 3.5776312826807404`*^9}, {
   3.577632088595965*^9, 3.5776320973304253`*^9}, {3.577632188942252*^9, 
   3.5776322367175198`*^9}, 3.577708727712677*^9, {3.5777152992560062`*^9, 
   3.577715315228188*^9}, {3.57771536211059*^9, 3.577715382783099*^9}, {
   3.57771543201145*^9, 3.577715448292349*^9}, {3.5777154961201057`*^9, 
   3.5777155255457497`*^9}, 3.577715582524145*^9, 3.57771578249174*^9, {
   3.577715982450633*^9, 3.577716000410184*^9}, {3.577716187501109*^9, 
   3.5777162043685417`*^9}, {3.5777224163329563`*^9, 3.577722419953595*^9}}],

Cell[BoxData["0.3240200000000186`"], "Print",
 CellChangeTimes->{{3.5776312340710583`*^9, 3.5776312837154083`*^9}, {
   3.577632094354432*^9, 3.5776321042470627`*^9}, {3.577632179928481*^9, 
   3.577632237747608*^9}, 3.5776338244840508`*^9, 3.577634089896594*^9, 
   3.577638950707336*^9, {3.5777087157999573`*^9, 3.577708729134371*^9}, 
   3.577712493408772*^9, 3.577715268940268*^9, {3.577715365893882*^9, 
   3.577715383506892*^9}, 3.577715442920607*^9, {3.5777154931889563`*^9, 
   3.5777155267603693`*^9}, 3.577715583631729*^9, 3.5777157833366947`*^9, 
   3.5777159830039263`*^9, 3.577716116971493*^9, {3.577716192744925*^9, 
   3.577716205486805*^9}, {3.577722393998826*^9, 3.577722430476267*^9}, 
   3.577783108824976*^9, 3.5777841338136272`*^9, 3.577786001358882*^9, 
   3.577786389410777*^9, 3.577854205725271*^9, 3.577889531660074*^9, 
   3.577889602245967*^9}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"h\.b9", 
       StyleBox[GridBox[{
          {"a", "c"},
          {" ", " "}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h1[$CellContext`a, $CellContext`c],
   Editable->False], " ", 
  RowBox[{"(", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "d", "  ", "  ", "  "},
            {"b", " ", 
             RowBox[{",", "a"}], 
             RowBox[{",", "c"}], 
             RowBox[{",", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`PD[-$CellContext`d][
      xAct`xTensor`PD[-$CellContext`c][
       xAct`xTensor`PD[-$CellContext`a][
        $CellContext`h1[-$CellContext`b, $CellContext`d]]]],
     Editable->False], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "d", "  ", "  ", "  "},
            {"a", " ", 
             RowBox[{",", "b"}], 
             RowBox[{",", "c"}], 
             RowBox[{",", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`PD[-$CellContext`d][
      xAct`xTensor`PD[-$CellContext`c][
       xAct`xTensor`PD[-$CellContext`b][
        $CellContext`h1[-$CellContext`a, $CellContext`d]]]],
     Editable->False], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{",", "d"}], "  ", "  "},
            {"b", "a", "  ", 
             RowBox[{",", "c"}], 
             RowBox[{",", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`PD[-$CellContext`d][
      xAct`xTensor`PD[-$CellContext`c][
       xAct`xTensor`PD[$CellContext`d][
        $CellContext`h1[-$CellContext`b, -$CellContext`a]]]],
     Editable->False], "+", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", 
             RowBox[{",", "d"}], "  "},
            {"a", "c", 
             RowBox[{",", "b"}], "  ", 
             RowBox[{",", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`PD[-$CellContext`d][
      xAct`xTensor`PD[$CellContext`d][
       xAct`xTensor`PD[-$CellContext`b][
        $CellContext`h1[-$CellContext`a, -$CellContext`c]]]],
     Editable->False]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5777154968934727`*^9, 3.5777155267992163`*^9}, 
   3.577715583673238*^9, 3.577715783392151*^9, 3.5777159830488167`*^9, 
   3.577716117015389*^9, {3.5777161927760878`*^9, 3.5777162055336943`*^9}, {
   3.577722394053377*^9, 3.577722430530211*^9}, 3.577783108895637*^9, 
   3.5777841338428*^9, 3.577786001418277*^9, 3.577786389470071*^9, 
   3.577854205781191*^9, 3.5778895317375193`*^9, 3.577889602308919*^9}]
}, Open  ]],

Cell["We can even do something similar at 3rd order!", "Text",
 CellChangeTimes->{{3.577889613104658*^9, 3.577889625161058*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{"h3", "[", 
     RowBox[{"c_", ",", "a_"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{"h3", "[", 
     RowBox[{"a_", ",", "c_"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "d_", "]"}], "[", 
     RowBox[{"h3", "[", 
      RowBox[{"c_", ",", "a_"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "d_", "]"}], "[", 
     RowBox[{"h3", "[", 
      RowBox[{"a_", ",", "c_"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.577715134196528*^9, 3.5777151385557623`*^9}, {
  3.577783158812664*^9, 3.5777831631782618`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Gab33", "=", 
   RowBox[{
    RowBox[{"Gab3", "//", "org"}], "//", "Simplification"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.5776230105954857`*^9, 3.57762301075042*^9}, 
   3.577623048588769*^9, {3.577623078689952*^9, 3.577623081155266*^9}, {
   3.577624521650243*^9, 3.577624629096365*^9}, {3.577625665310371*^9, 
   3.577625666832264*^9}, 3.577714121310816*^9, {3.5777151238091927`*^9, 
   3.5777151721246443`*^9}, {3.5777831713339663`*^9, 3.577783172577636*^9}}],

Cell[BoxData["4.460279000000014`"], "Print",
 CellChangeTimes->{{3.577624541382053*^9, 3.577624631993393*^9}, {
   3.5776256499745197`*^9, 3.57762567056763*^9}, 3.577625868640719*^9, 
   3.577626240045082*^9, 3.577626431022299*^9, 3.577626541061241*^9, 
   3.577628237317927*^9, 3.5776303298646517`*^9, 3.5776307728926487`*^9, 
   3.577632161857312*^9, 3.577633809583385*^9, 3.5776340601479197`*^9, 
   3.5776389252445183`*^9, 3.577691318380769*^9, 3.577708273599416*^9, 
   3.577712371929288*^9, 3.577714125085416*^9, {3.577715114652255*^9, 
   3.577715174773546*^9}, 3.57772235287436*^9, 3.577783091529118*^9, 
   3.5777831778052597`*^9, 3.577784142935759*^9, 3.5777860091665916`*^9, 
   3.5777864001806173`*^9, 3.577854221241275*^9, 3.5778896342811117`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h2", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], ":=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5777831814256487`*^9, 3.577783184837924*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Gableft3", "=", 
  RowBox[{"Gab33", "//", "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.5777141536285458`*^9, 3.577714172656193*^9}, {
  3.577783188695406*^9, 3.577783191213217*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"h\.b3", 
       StyleBox[GridBox[{
          {" ", " ", 
           RowBox[{";", "c"}], "  "},
          {"a", "b", "  ", 
           RowBox[{";", "c"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`c][
    $CellContext`CD[$CellContext`c][
     $CellContext`h3[-$CellContext`a, -$CellContext`b]]],
   Editable->False]}]], "Output",
 CellChangeTimes->{{3.577714145274754*^9, 3.5777141734107447`*^9}, 
   3.577715181601636*^9, 3.5777223539567204`*^9, 3.5777830942866993`*^9, 
   3.577783192249804*^9, 3.5777841459558487`*^9, 3.577786011372306*^9, 
   3.577786403166793*^9, 3.5778542242520533`*^9, 3.577889637747676*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h2", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"a_", ",", 
     RowBox[{"-", "a_"}]}], "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   TagBox[
    StyleBox[
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "c_"}], "]"}], "[", 
      RowBox[{
       RowBox[{"CD", "[", "c_", "]"}], "[", 
       RowBox[{"h1", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "]"}],
     ShowSpecialCharacters->False,
     ShowStringCharacters->True,
     NumberMarks->True],
    FullForm], ":=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.577714201108513*^9, 3.577714202443177*^9}, {
  3.577783576324746*^9, 3.577783589686574*^9}, {3.577783795677458*^9, 
  3.577783802888*^9}, {3.5777838395043917`*^9, 3.577783902480322*^9}, {
  3.5777841760043297`*^9, 3.577784218341351*^9}, {3.57778426296449*^9, 
  3.577784304545545*^9}, {3.577784351709511*^9, 3.577784357851276*^9}}],

Cell["\<\
But now we have to input the restriction that the wave equation is obeyed in \
many forms (you can check you need all of these by looking at the output you \
would get with these deleted)\
\>", "Text",
 CellChangeTimes->{{3.577889669974844*^9, 3.577889725975915*^9}, {
  3.578074364590723*^9, 3.578074369840695*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "c_", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", "e_", "]"}], "[", 
      RowBox[{"h1", "[", 
       RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "e_", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", "c_", "]"}], "[", 
      RowBox[{"h1", "[", 
       RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "c_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "e_", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", "f_", "]"}], "[", 
      RowBox[{"h1", "[", 
       RowBox[{"a_", ",", "c_"}], "]"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", "e_", "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", 
      RowBox[{"-", "c_"}], "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", "f_", "]"}], "[", 
      RowBox[{"h1", "[", 
       RowBox[{"a_", ",", "c_"}], "]"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", "e_", "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "f_", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "c_"}], "]"}], "[", 
      RowBox[{"h1", "[", 
       RowBox[{"a_", ",", "c_"}], "]"}], "]"}], "]"}], "]"}], ":=", "0"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.577784360708102*^9, 3.57778439433044*^9}, {
  3.577889657866083*^9, 3.577889662255468*^9}}],

Cell["\<\
For the second order perturbation, we also have to impose the wave equation \
with a source in many forms. In particular we need to provide the wave \
equation for the trace. So we define the trace first:\
\>", "Text",
 CellChangeTimes->{{3.577889736016759*^9, 3.577889813165348*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GabTrace", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"a", ",", "b"}], "]"}], "GabRight"}], "//", "Simplification"}], 
   "//", "org"}]}]], "Input",
 CellChangeTimes->{{3.577787109064719*^9, 3.577787149382885*^9}, {
  3.577788631911951*^9, 3.577788691740884*^9}, {3.577788769792831*^9, 
  3.57778879514157*^9}, {3.577789008508602*^9, 3.577789016880517*^9}}],

Cell[BoxData["0.1600100000000566`"], "Print",
 CellChangeTimes->{{3.577788779435239*^9, 3.577788795909038*^9}, {
   3.5777890130022593`*^9, 3.577789017746744*^9}, 3.577789063228594*^9, 
   3.5778542323692303`*^9, 3.577889884707835*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"a", "c", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`a, -$CellContext`c]],
     Editable->False]}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"a", "b", 
            RowBox[{";", "c"}]},
           {" ", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`h1[$CellContext`a, $CellContext`b]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["d",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`dim,
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"a", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`h1[-$CellContext`a, -$CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"a", "b", 
            RowBox[{";", "c"}]},
           {" ", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`h1[$CellContext`a, $CellContext`b]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"a", "b", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`h1[-$CellContext`a, -$CellContext`b]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"a", "b", 
            RowBox[{";", "c"}]},
           {" ", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`h1[$CellContext`a, $CellContext`b]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   InterpretationBox[
    StyleBox["d",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`dim,
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"a", "b", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`h1[-$CellContext`a, -$CellContext`b]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"a", "b", 
            RowBox[{";", "c"}]},
           {" ", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`h1[$CellContext`a, $CellContext`b]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{{3.577787106973044*^9, 3.577787150643441*^9}, {
   3.5777886382326517`*^9, 3.577788692212734*^9}, {3.577788779558552*^9, 
   3.577788795954287*^9}, {3.577789013050805*^9, 3.5777890178080473`*^9}, 
   3.5777890632893677`*^9, 3.577854232473393*^9, 3.577889884800065*^9}]
}, Open  ]],

Cell["\<\
But we have to be very careful with dummy indices (because abc are already in \
heavy use in previous expressions). So we use the following function to \
specify what we need to use for dummies:\
\>", "Text",
 CellChangeTimes->{{3.5778898885480337`*^9, 3.577889947308374*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReplaceDummies", "[", 
  RowBox[{"GabTrace", ",", 
   RowBox[{"IndexList", "[", 
    RowBox[{"n", ",", "o", ",", "p"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.577788128170974*^9, 3.577788152176223*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"n", "p", 
             RowBox[{";", "o"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`o][
      $CellContext`h1[-$CellContext`n, -$CellContext`p]],
     Editable->False]}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"n", "o", 
            RowBox[{";", "p"}]},
           {" ", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`p][
     $CellContext`h1[$CellContext`n, $CellContext`o]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox["d",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`dim,
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"n", "p", 
            RowBox[{";", "o"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`o][
     $CellContext`h1[-$CellContext`n, -$CellContext`p]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"n", "o", 
            RowBox[{";", "p"}]},
           {" ", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`p][
     $CellContext`h1[$CellContext`n, $CellContext`o]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"n", "o", 
            RowBox[{";", "p"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`p][
     $CellContext`h1[-$CellContext`n, -$CellContext`o]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"n", "o", 
            RowBox[{";", "p"}]},
           {" ", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`p][
     $CellContext`h1[$CellContext`n, $CellContext`o]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   InterpretationBox[
    StyleBox["d",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`dim,
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {" ", " ", "  "},
           {"n", "o", 
            RowBox[{";", "p"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`p][
     $CellContext`h1[-$CellContext`n, -$CellContext`o]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h\.b9", 
        StyleBox[GridBox[{
           {"n", "o", 
            RowBox[{";", "p"}]},
           {" ", " ", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`p][
     $CellContext`h1[$CellContext`n, $CellContext`o]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{
  3.577788043796071*^9, {3.577788132004326*^9, 3.577788152881805*^9}, 
   3.577854234216525*^9}]
}, Open  ]],

Cell["\<\
Now we are ready to write the rules related to the 2nd order wave equation \
being obeyed, as well as the trace\
\>", "Text",
 CellChangeTimes->{{3.577889949907895*^9, 3.577889988313128*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "p_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "p_", "]"}], "[", 
     RowBox[{"h2", "[", 
      RowBox[{
       RowBox[{"-", "a_"}], ",", 
       RowBox[{"-", "b_"}]}], "]"}], "]"}], "]"}], "=", 
   RowBox[{"2", 
    RowBox[{"ReplaceDummies", "[", 
     RowBox[{"GabRight", ",", 
      RowBox[{"IndexList", "[", 
       RowBox[{"n", ",", "o", ",", "p"}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "p_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "p_", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", "f_", "]"}], "[", 
      RowBox[{"h2", "[", 
       RowBox[{
        RowBox[{"-", "a_"}], ",", 
        RowBox[{"-", "b_"}]}], "]"}], "]"}], "]"}], "]"}], "=", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"CD", "[", "f", "]"}], "@", 
     RowBox[{"ReplaceDummies", "[", 
      RowBox[{"GabRight", ",", 
       RowBox[{"IndexList", "[", 
        RowBox[{"n", ",", "o", ",", "p"}], "]"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "p_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "f_", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", "p_", "]"}], "[", 
      RowBox[{"h2", "[", 
       RowBox[{
        RowBox[{"-", "a_"}], ",", 
        RowBox[{"-", "b_"}]}], "]"}], "]"}], "]"}], "]"}], "=", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"CD", "[", "f", "]"}], "@", 
     RowBox[{"ReplaceDummies", "[", 
      RowBox[{"GabRight", ",", 
       RowBox[{"IndexList", "[", 
        RowBox[{"n", ",", "o", ",", "p"}], "]"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "p_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "p_", "]"}], "[", 
     RowBox[{"h2", "[", 
      RowBox[{"n_", ",", 
       RowBox[{"-", "n_"}]}], "]"}], "]"}], "]"}], "=", 
   RowBox[{"2", 
    RowBox[{"ReplaceDummies", "[", 
     RowBox[{"GabTrace", ",", 
      RowBox[{"IndexList", "[", 
       RowBox[{"n", ",", "o", ",", "p"}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "p_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "p_", "]"}], "[", 
     RowBox[{"h2", "[", 
      RowBox[{
       RowBox[{"-", "n_"}], ",", "n_"}], "]"}], "]"}], "]"}], "=", 
   RowBox[{"2", 
    RowBox[{"ReplaceDummies", "[", 
     RowBox[{"GabTrace", ",", 
      RowBox[{"IndexList", "[", 
       RowBox[{"n", ",", "o", ",", "p"}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "p_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "p_", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", "a_", "]"}], "[", 
      RowBox[{"h2", "[", 
       RowBox[{
        RowBox[{"-", "n_"}], ",", "n_"}], "]"}], "]"}], "]"}], "]"}], "=", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"CD", "[", "a", "]"}], "[", 
     RowBox[{"ReplaceDummies", "[", 
      RowBox[{"GabTrace", ",", 
       RowBox[{"IndexList", "[", 
        RowBox[{"n", ",", "o", ",", "p"}], "]"}]}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "p_"}], "]"}], "[", 
    RowBox[{
     RowBox[{"CD", "[", "p_", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", "a_", "]"}], "[", 
      RowBox[{"h2", "[", 
       RowBox[{"n_", ",", 
        RowBox[{"-", "n_"}]}], "]"}], "]"}], "]"}], "]"}], "=", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"CD", "[", "a", "]"}], "[", 
     RowBox[{"ReplaceDummies", "[", 
      RowBox[{"GabTrace", ",", 
       RowBox[{"IndexList", "[", 
        RowBox[{"n", ",", "o", ",", "p"}], "]"}]}], "]"}], "]"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwd0Wkow3EYB/B/e8FE7AVWlLDJkRfywsx9JZS5Eos0KyYxGk1hYsnW0mK8
YjlH7sia5QXKUTRHGuVoc+QIae5Sjn1/L54+PU/PU0/P4yesyS2jURTFsgc8
p5LDPCYeEm2K6Ai4+87LglUZXzlQEicohKpuGh8+z+8I4IN4UwTTu4JqobHA
oQG+7YiaoWV1SAbZ2T/t8N46qoIFjdVqSPdh9UD5x0g/fNdV6KBwOn4O+nsW
EcVr2kUYRRMb4PjkthmGyr2P4FJT5wn8pNtOSV/0goXMeQkvYN3HjKOn3eFT
uhO8VEW4Q7PG7A3Tqtc4UK3448LKQHUS7LOGp8AO2VsW5MqK+VBpKhVCW2Zf
OeQlmSphb2ywBDLWZ6Vw4/COeMLUNsOxntYW6BQU2gFTswMVpL4qVcOU8EcN
vLnU6Umel2+AvzH1W2Q/Nm8fXqQlHEOpi+IM7rm+WmHn1A9xpe36FoZcFT9B
owf1AiMtg9+k3j/4C5dvmX/kLr7fjky7Ay8cZyhRHrjBEq2eAYP9R9kc/FNj
CoD/VVwXxw==
  "]],

Cell["\<\
Finally the right hand side, i.e. the source at 3rd order, simplifies \"a bit\
\" and below we check conservation \
\>", "Text",
 CellChangeTimes->{{3.577890018196765*^9, 3.5778900823713093`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GabRight3", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Gab33", "-", "Gableft3"}], ")"}], "//", "org"}], "//", 
        "Simplification"}], ")"}], "//", "org"}], "//", "ToCanonical"}], ",", 
    
    RowBox[{"g", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5777832329366493`*^9, 3.577783238428606*^9}, 
   3.577788801846241*^9, {3.577788966984193*^9, 3.5777889699330397`*^9}, 
   3.577789040467606*^9}],

Cell[BoxData["3.368210999999974`"], "Print",
 CellChangeTimes->{
  3.5777881669254217`*^9, 3.577788229107348*^9, 3.577788267854389*^9, 
   3.5777883834930897`*^9, 3.577788415242346*^9, 3.577788511599749*^9, 
   3.57778855538756*^9, 3.577788808715933*^9, 3.577788972269986*^9, {
   3.5777890457777853`*^9, 3.577789070427783*^9}, 3.577854264479643*^9, 
   3.5778543001055927`*^9, 3.577889999120248*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b2", 
          StyleBox[GridBox[{
             {"c", "d"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h2[$CellContext`c, $CellContext`d],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h\.b9", 
          StyleBox[GridBox[{
             {" ", " ", "  ", "  "},
             {"c", "d", 
              RowBox[{";", "b"}], 
              RowBox[{";", "a"}]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`a][
       $CellContext`CD[-$CellContext`b][
        $CellContext`h1[-$CellContext`c, -$CellContext`d]]],
      Editable->False]}], 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     InterpretationBox[
      StyleBox["d",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`dim,
      Editable->False]}]]}], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h2[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"c", "d", 
             RowBox[{";", "b"}], 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h1[-$CellContext`c, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`c, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"d", "e", 
             RowBox[{";", "b"}], 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h1[-$CellContext`d, -$CellContext`e]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`c, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"d", "e", 
             RowBox[{";", "b"}], 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h1[-$CellContext`d, -$CellContext`e]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"c", "d", 
             RowBox[{";", "b"}], 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h2[-$CellContext`c, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"c", "d", 
             RowBox[{";", "b"}], 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h2[-$CellContext`c, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h2[-$CellContext`c, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d", "  "},
            {" ", " ", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[$CellContext`c, $CellContext`d]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h2[-$CellContext`c, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d", "  "},
            {" ", " ", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[$CellContext`c, $CellContext`d]],
     Editable->False]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"c", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`c, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"d", "e", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`d, -$CellContext`e]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"c", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`c, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"d", "e", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`d, -$CellContext`e]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d", "  "},
            {" ", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[$CellContext`c, $CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h2[-$CellContext`c, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d", "  "},
            {" ", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[$CellContext`c, $CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h2[-$CellContext`c, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", "  "},
            {"b", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`b, $CellContext`c]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"d", " ", "  "},
            {" ", "d", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h2[$CellContext`d, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", "  "},
            {"a", " ", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`a, $CellContext`c]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"d", " ", "  "},
            {" ", "d", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h2[$CellContext`d, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c"},
            {"b", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`b, $CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"d", " ", "  ", "  "},
            {" ", "d", 
             RowBox[{";", "a"}], 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h2[$CellContext`d, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c"},
            {"a", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`a, $CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"d", " ", "  ", "  "},
            {" ", "d", 
             RowBox[{";", "b"}], 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h2[$CellContext`d, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"d", " ", "  "},
            {" ", "d", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h2[$CellContext`d, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "c"}]},
            {"a", "b", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`h1[-$CellContext`a, -$CellContext`b]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"a", " ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h1[-$CellContext`a, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`b, -$CellContext`e]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"a", " ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h1[-$CellContext`a, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`b, -$CellContext`e]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"b", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`b, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`c, -$CellContext`e]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"b", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`b, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`c, -$CellContext`e]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"a", " ", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`a, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`c, -$CellContext`e]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"a", " ", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`a, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`c, -$CellContext`e]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h2[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"b", "c", 
             RowBox[{";", "a"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h1[-$CellContext`b, -$CellContext`c]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h2[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"b", "c", 
             RowBox[{";", "a"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h1[-$CellContext`b, -$CellContext`c]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"b", "c", 
             RowBox[{";", "a"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h2[-$CellContext`b, -$CellContext`c]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"b", "c", 
             RowBox[{";", "a"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h2[-$CellContext`b, -$CellContext`c]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h2[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "c", 
             RowBox[{";", "b"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h1[-$CellContext`a, -$CellContext`c]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h2[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "c", 
             RowBox[{";", "b"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h1[-$CellContext`a, -$CellContext`c]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "c", 
             RowBox[{";", "b"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h2[-$CellContext`a, -$CellContext`c]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "c", 
             RowBox[{";", "b"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h2[-$CellContext`a, -$CellContext`c]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h2[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "b", 
             RowBox[{";", "c"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h2[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "b", 
             RowBox[{";", "c"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "b", 
             RowBox[{";", "c"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`h2[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "b", 
             RowBox[{";", "c"}], 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`h2[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "d", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h2[-$CellContext`b, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", 
             RowBox[{";", "d"}]},
            {"a", " ", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`h1[-$CellContext`a, $CellContext`c]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "d", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h2[-$CellContext`b, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", 
             RowBox[{";", "d"}]},
            {"a", " ", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`h1[-$CellContext`a, $CellContext`c]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "c", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h2[-$CellContext`b, -$CellContext`c]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", 
             RowBox[{";", "d"}]},
            {"a", " ", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`h1[-$CellContext`a, $CellContext`c]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "c", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h2[-$CellContext`b, -$CellContext`c]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", 
             RowBox[{";", "d"}]},
            {"a", " ", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`h1[-$CellContext`a, $CellContext`c]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"a", "d", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h2[-$CellContext`a, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", 
             RowBox[{";", "d"}]},
            {"b", " ", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`h1[-$CellContext`b, $CellContext`c]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"a", "d", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h2[-$CellContext`a, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", 
             RowBox[{";", "d"}]},
            {"b", " ", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`h1[-$CellContext`b, $CellContext`c]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"a", "c", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h2[-$CellContext`a, -$CellContext`c]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", 
             RowBox[{";", "d"}]},
            {"b", " ", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`h1[-$CellContext`b, $CellContext`c]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"a", "c", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h2[-$CellContext`a, -$CellContext`c]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "c", 
             RowBox[{";", "d"}]},
            {"b", " ", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`h1[-$CellContext`b, $CellContext`c]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"a", " ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h1[-$CellContext`a, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`b, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"a", " ", 
             RowBox[{";", "c"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`h1[-$CellContext`a, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`b, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"b", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`b, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`c, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"b", " ", 
             RowBox[{";", "a"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`a][
      $CellContext`h1[-$CellContext`b, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`c, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"a", " ", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`a, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`c, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e", "  "},
            {"a", " ", 
             RowBox[{";", "b"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`h1[-$CellContext`a, $CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`c, -$CellContext`d]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`c, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"b", "d", 
             RowBox[{";", "a"}], 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h1[-$CellContext`b, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`c, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"b", "d", 
             RowBox[{";", "a"}], 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`a][
       $CellContext`h1[-$CellContext`b, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`c, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "d", 
             RowBox[{";", "b"}], 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h1[-$CellContext`a, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`c, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "d", 
             RowBox[{";", "b"}], 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`b][
       $CellContext`h1[-$CellContext`a, -$CellContext`d]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`c, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "b", 
             RowBox[{";", "d"}], 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`d][
       $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", "e"},
            {"c", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[-$CellContext`c, $CellContext`e],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  ", "  "},
            {"a", "b", 
             RowBox[{";", "d"}], 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`d][
       $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`c, -$CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "e"}]},
            {"a", "b", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`h1[-$CellContext`a, -$CellContext`b]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`c, -$CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "e"}]},
            {"a", "b", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`h1[-$CellContext`a, -$CellContext`b]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`c, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "e"}]},
            {"a", "b", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`h1[-$CellContext`a, -$CellContext`b]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"c", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`c, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "e"}]},
            {"a", "b", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`h1[-$CellContext`a, -$CellContext`b]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      InterpretationBox[
       StyleBox["d",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`dim,
       Editable->False]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`b, -$CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "e"}]},
            {"a", "c", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`h1[-$CellContext`a, -$CellContext`c]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "e", 
             RowBox[{";", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`h1[-$CellContext`b, -$CellContext`e]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "e"}]},
            {"a", "c", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`h1[-$CellContext`a, -$CellContext`c]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`b, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "e"}]},
            {"a", "c", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`h1[-$CellContext`a, -$CellContext`c]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {"c", "d"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h1[$CellContext`c, $CellContext`d],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", "  "},
            {"b", "d", 
             RowBox[{";", "e"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`h1[-$CellContext`b, -$CellContext`d]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b9", 
         StyleBox[GridBox[{
            {" ", " ", 
             RowBox[{";", "e"}]},
            {"a", "c", "  "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`h1[-$CellContext`a, -$CellContext`c]],
     Editable->False]}], 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    InterpretationBox[
     StyleBox["d",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dim,
     Editable->False]}]], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`a, -$CellContext`b],
    Editable->False], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b9", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h1[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b9", 
             StyleBox[GridBox[{
                {"e", "f", "  "},
                {" ", " ", 
                 RowBox[{";", "c"}]}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`h1[$CellContext`e, $CellContext`f]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b9", 
             StyleBox[GridBox[{
                {" ", " ", "  "},
                {"e", "f", 
                 RowBox[{";", "d"}]}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`d][
          $CellContext`h1[-$CellContext`e, -$CellContext`f]],
         Editable->False]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          InterpretationBox[
           StyleBox["d",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`dim,
           Editable->False]}], ")"}]}]]}], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"e", "f", "  "},
               {" ", " ", 
                RowBox[{";", "c"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`h1[$CellContext`e, $CellContext`f]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"e", "f", 
                RowBox[{";", "d"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`h1[-$CellContext`e, -$CellContext`f]],
        Editable->False]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         InterpretationBox[
          StyleBox["d",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`dim,
          Editable->False]}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b2", 
            StyleBox[GridBox[{
               {"e", " ", "  ", "  "},
               {" ", "e", 
                RowBox[{";", "c"}], 
                RowBox[{";", "d"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`h2[$CellContext`e, -$CellContext`e]]],
        Editable->False]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         InterpretationBox[
          StyleBox["d",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`dim,
          Editable->False]}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b2", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"c", "e", 
                RowBox[{";", "d"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`h2[-$CellContext`c, -$CellContext`e]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d", 
                RowBox[{";", "e"}]},
               {" ", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`h1[$CellContext`c, $CellContext`d]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b2", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"c", "e", 
                RowBox[{";", "d"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`h2[-$CellContext`c, -$CellContext`e]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d", 
                RowBox[{";", "e"}]},
               {" ", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`h1[$CellContext`c, $CellContext`d]],
        Editable->False]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         InterpretationBox[
          StyleBox["d",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`dim,
          Editable->False]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"9", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b2", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"c", "d", 
                RowBox[{";", "e"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`h2[-$CellContext`c, -$CellContext`d]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d", 
                RowBox[{";", "e"}]},
               {" ", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`h1[$CellContext`c, $CellContext`d]],
        Editable->False]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         InterpretationBox[
          StyleBox["d",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`dim,
          Editable->False]}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{"9", " ", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b2", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"c", "d", 
                RowBox[{";", "e"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`h2[-$CellContext`c, -$CellContext`d]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d", 
                RowBox[{";", "e"}]},
               {" ", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`h1[$CellContext`c, $CellContext`d]],
        Editable->False]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         InterpretationBox[
          StyleBox["d",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`dim,
          Editable->False]}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"e", "f"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`e, $CellContext`f],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  ", "  "},
               {"c", "e", 
                RowBox[{";", "d"}], 
                RowBox[{";", "f"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`f][
         $CellContext`CD[-$CellContext`d][
          $CellContext`h1[-$CellContext`c, -$CellContext`e]]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"e", "f"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`e, $CellContext`f],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  ", "  "},
               {"c", "e", 
                RowBox[{";", "d"}], 
                RowBox[{";", "f"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`f][
         $CellContext`CD[-$CellContext`d][
          $CellContext`h1[-$CellContext`c, -$CellContext`e]]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"e", "f"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`e, $CellContext`f],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  ", "  "},
               {"c", "d", 
                RowBox[{";", "e"}], 
                RowBox[{";", "f"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`f][
         $CellContext`CD[-$CellContext`e][
          $CellContext`h1[-$CellContext`c, -$CellContext`d]]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"e", "f"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`e, $CellContext`f],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  ", "  "},
               {"c", "d", 
                RowBox[{";", "e"}], 
                RowBox[{";", "f"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`f][
         $CellContext`CD[-$CellContext`e][
          $CellContext`h1[-$CellContext`c, -$CellContext`d]]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"e", "f", 
                RowBox[{";", "d"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`h1[-$CellContext`e, -$CellContext`f]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", "e", 
                RowBox[{";", "f"}]},
               {"c", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`f][
         $CellContext`h1[-$CellContext`c, $CellContext`e]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"e", "f", 
                RowBox[{";", "d"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`h1[-$CellContext`e, -$CellContext`f]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", "e", 
                RowBox[{";", "f"}]},
               {"c", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`f][
         $CellContext`h1[-$CellContext`c, $CellContext`e]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"d", "f", 
                RowBox[{";", "e"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`h1[-$CellContext`d, -$CellContext`f]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", "e", 
                RowBox[{";", "f"}]},
               {"c", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`f][
         $CellContext`h1[-$CellContext`c, $CellContext`e]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"d", "f", 
                RowBox[{";", "e"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`h1[-$CellContext`d, -$CellContext`f]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", "e", 
                RowBox[{";", "f"}]},
               {"c", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`f][
         $CellContext`h1[-$CellContext`c, $CellContext`e]],
        Editable->False]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         InterpretationBox[
          StyleBox["d",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`dim,
          Editable->False]}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"d", "e", 
                RowBox[{";", "f"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`f][
         $CellContext`h1[-$CellContext`d, -$CellContext`e]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", "e", 
                RowBox[{";", "f"}]},
               {"c", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`f][
         $CellContext`h1[-$CellContext`c, $CellContext`e]],
        Editable->False]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["d",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h1[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", " ", "  "},
               {"d", "e", 
                RowBox[{";", "f"}]}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`f][
         $CellContext`h1[-$CellContext`d, -$CellContext`e]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h\.b9", 
            StyleBox[GridBox[{
               {" ", "e", 
                RowBox[{";", "f"}]},
               {"c", " ", "  "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`f][
         $CellContext`h1[-$CellContext`c, $CellContext`e]],
        Editable->False]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         InterpretationBox[
          StyleBox["d",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`dim,
          Editable->False]}], ")"}]}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.57771421688929*^9, {3.577715206170451*^9, 3.577715234324059*^9}, 
   3.577716111568879*^9, 3.577722369314785*^9, 3.5777831001544867`*^9, 
   3.5777832518001833`*^9, 3.577783808692773*^9, 3.577783844765329*^9, 
   3.577783905824418*^9, 3.577784156100712*^9, {3.577784197760871*^9, 
   3.577784224824066*^9}, 3.577784402082138*^9, 3.577784433728929*^9, 
   3.577784494798892*^9, 3.57778475991791*^9, 3.577785066180359*^9, 
   3.57778515839834*^9, 3.577785264113358*^9, 3.577785328832457*^9, {
   3.577785380081066*^9, 3.577785389104203*^9}, {3.577785437914255*^9, 
   3.5777854829565153`*^9}, 3.5777856419085693`*^9, 3.577785786043124*^9, 
   3.5777860376815243`*^9, 3.577786083833798*^9, 3.577786130607305*^9, 
   3.5777862117966003`*^9, 3.577786457333962*^9, 3.57778656803004*^9, 
   3.5777866076791687`*^9, 3.577786840471026*^9, {3.577786906037633*^9, 
   3.5777869197520227`*^9}, 3.577787040283065*^9, 3.577787091974074*^9, {
   3.577787180600597*^9, 3.577787253033619*^9}, 3.5777872867125063`*^9, {
   3.57778736981846*^9, 3.577787393820795*^9}, 3.5777874462651377`*^9, 
   3.577787546769251*^9, 3.577787845722088*^9, 3.577788167012127*^9, 
   3.577788229186575*^9, 3.577788267925336*^9, 3.577788383577837*^9, 
   3.577788415326231*^9, 3.577788511684148*^9, 3.577788555472789*^9, 
   3.577788808876177*^9, 3.577788972347417*^9, {3.5777890459357147`*^9, 
   3.57778907058289*^9}, 3.5778542646304903`*^9, 3.577854300265211*^9, 
   3.57788999928986*^9}]
}, Open  ]],

Cell["Conservation is verified!", "Text",
 CellChangeTimes->{{3.5778900883613243`*^9, 3.577890094416535*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", "a", "]"}], "@", "GabRight3"}], "//", 
     "Simplification"}], "//", "org"}], "//", "ChangeCovD"}], "//", 
  "Simplification"}]], "Input",
 CellChangeTimes->{{3.577783282746154*^9, 3.577783324226399*^9}, {
  3.577783384207095*^9, 3.5777833873881817`*^9}, {3.5777834251794157`*^9, 
  3.5777834893257647`*^9}, {3.577786612219769*^9, 3.5777866416229486`*^9}, {
  3.57778857496332*^9, 3.577788605612254*^9}}],

Cell[BoxData["9.760610000000042`"], "Print",
 CellChangeTimes->{
  3.577788233686862*^9, 3.577788271983212*^9, 3.577788389006586*^9, 
   3.577788419660626*^9, 3.577788516793301*^9, {3.577788561102174*^9, 
   3.577788609187996*^9}, 3.577788819221368*^9, 3.5777889778681498`*^9, 
   3.57778909310642*^9, 3.577854274905785*^9, 3.577854311498418*^9, 
   3.577890011794277*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["3", "2"], " ", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"h\.b9", 
       StyleBox[GridBox[{
          {"a", "c"},
          {" ", " "}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h1[$CellContext`a, $CellContext`c],
   Editable->False], " ", 
  RowBox[{"(", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", "d", "  ", "  ", "  "},
            {"b", " ", 
             RowBox[{",", "a"}], 
             RowBox[{",", "c"}], 
             RowBox[{",", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`PD[-$CellContext`d][
      xAct`xTensor`PD[-$CellContext`c][
       xAct`xTensor`PD[-$CellContext`a][
        $CellContext`h2[-$CellContext`b, $CellContext`d]]]],
     Editable->False], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h\.b2", 
         StyleBox[GridBox[{
            {" ", "d", "  ", "  ", "  "},
            {"a", " ", 
             RowBox[{",", "b"}], 
             RowBox[{",", "c"}], 
             RowBox[{",", "d"}]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`PD[-$CellContext`d][
      xAct`xTensor`PD[-$CellContext`c][
       xAct`xTensor`PD[-$CellContext`b][
        $CellContext`h2[-$CellContext`a, $CellContext`d]]]],
     Editable->False]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.577783289150792*^9, 3.577783328269289*^9}, 
   3.577783390588025*^9, {3.577783431485106*^9, 3.577783461086444*^9}, 
   3.577783492792512*^9, 3.577784231604434*^9, 3.5777844078602533`*^9, 
   3.577784438911511*^9, 3.577784499646914*^9, 3.5777855123787193`*^9, 
   3.577785647254925*^9, 3.577785791413673*^9, 3.5777860416550817`*^9, 
   3.577786087727654*^9, 3.577786133299014*^9, 3.5777862156431093`*^9, 
   3.577786461303028*^9, 3.577786571092669*^9, 3.577786614584428*^9, 
   3.577786846348206*^9, 3.57778817861677*^9, 3.577788233769188*^9, 
   3.577788272033564*^9, 3.5777883890462418`*^9, 3.577788419739052*^9, 
   3.577788516871464*^9, {3.5777885611460533`*^9, 3.577788609213299*^9}, 
   3.577788819326002*^9, 3.577788977902946*^9, 3.5777890931566353`*^9, 
   3.577854274933324*^9, 3.5778543116208*^9, 3.577890011840637*^9}]
}, Open  ]],

Cell["\<\
Ansd actually replacing by partial derivatives we get the simpler expression \
(Note: xTensor complains because we are not using tensorial equations anymore \
but the result is fine because the connection is zero)\
\>", "Text",
 CellChangeTimes->{{3.577890105721902*^9, 3.577890181117406*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GabRight3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Gab33", "-", "Gableft3"}], ")"}], "//", "org"}], "//", 
           "Simplification"}], ")"}], "/.", 
         RowBox[{"dim", "\[Rule]", " ", 
          RowBox[{"2", "+", "X"}]}]}], "//", "org"}], "//", "ToCanonical"}], 
      ",", 
      RowBox[{"g", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}]}], "]"}], "//", "ChangeCovD"}], "//", 
   "Simplification"}]}]], "Input",
 CellChangeTimes->{3.5777891246579847`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ToCanonical", "::", "\<\"cmods\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Detected metric-incompatible \
derivatives \\\\\\\"\\\", \
\\\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\!\\({PD}\\), \\\"MT\\\"]\\)\
\[NoBreak]\\!\\(\\*StyleBox[\\\"\\\\\\\".\\\\\\\"\\\", \
\\\"MT\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.577789127560732*^9, 3.577854278916897*^9, 
  3.577890101713479*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ToCanonical", "::", "\<\"cmods\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Detected metric-incompatible \
derivatives \\\\\\\"\\\", \
\\\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\!\\({PD}\\), \\\"MT\\\"]\\)\
\[NoBreak]\\!\\(\\*StyleBox[\\\"\\\\\\\".\\\\\\\"\\\", \
\\\"MT\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.577789127560732*^9, 3.577854278916897*^9, 
  3.577890101748864*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ToCanonical", "::", "\<\"cmods\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Detected metric-incompatible \
derivatives \\\\\\\"\\\", \
\\\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\!\\({PD}\\), \\\"MT\\\"]\\)\
\[NoBreak]\\!\\(\\*StyleBox[\\\"\\\\\\\".\\\\\\\"\\\", \
\\\"MT\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.577789127560732*^9, 3.577854278916897*^9, 
  3.5778901017903833`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"stop\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Further output of \\\\\\\"\\\
\", \\\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\!\\(ToCanonical :: \
\\\"cmods\\\"\\), \\\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\\"\\\\\\\" will \
be suppressed during this calculation.\\\\\\\"\\\", \\\"MT\\\"]\\) \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.577789127560732*^9, 3.577854278916897*^9, 
  3.5778901018235617`*^9}],

Cell[BoxData["3.376211000000012`"], "Print",
 CellChangeTimes->{3.577789127943375*^9, 3.577854279690497*^9, 
  3.577890102744628*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       StyleBox["(",
        FontColor->RGBColor[1, 0, 0]], "X", 
       StyleBox[")",
        FontColor->RGBColor[1, 0, 0]]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`Scalar[$CellContext`X],
     Editable->False]}]], 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", "c", "  "},
                 {"b", " ", 
                  RowBox[{",", "a"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`a][
           $CellContext`h1[-$CellContext`b, $CellContext`c]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"d", " ", "  "},
                 {" ", "d", 
                  RowBox[{",", "c"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`c][
           $CellContext`h2[$CellContext`d, -$CellContext`d]],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", "c", "  "},
                 {"a", " ", 
                  RowBox[{",", "b"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`b][
           $CellContext`h1[-$CellContext`a, $CellContext`c]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"d", " ", "  "},
                 {" ", "d", 
                  RowBox[{",", "c"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`c][
           $CellContext`h2[$CellContext`d, -$CellContext`d]],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", "c"},
                 {"b", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1[-$CellContext`b, $CellContext`c],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"d", " ", "  ", "  "},
                 {" ", "d", 
                  RowBox[{",", "a"}], 
                  RowBox[{",", "c"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`c][
           xAct`xTensor`PD[-$CellContext`a][
            $CellContext`h2[$CellContext`d, -$CellContext`d]]],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", "c"},
                 {"a", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1[-$CellContext`a, $CellContext`c],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"d", " ", "  ", "  "},
                 {" ", "d", 
                  RowBox[{",", "b"}], 
                  RowBox[{",", "c"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`c][
           xAct`xTensor`PD[-$CellContext`b][
            $CellContext`h2[$CellContext`d, -$CellContext`d]]],
          Editable->False]}], "-", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"d", " ", "  "},
                 {" ", "d", 
                  RowBox[{",", "c"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`c][
           $CellContext`h2[$CellContext`d, -$CellContext`d]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", " ", 
                  RowBox[{",", "c"}]},
                 {"a", "b", "  "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[$CellContext`c][
           $CellContext`h1[-$CellContext`a, -$CellContext`b]],
          Editable->False]}], "-", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"g", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"a", "b"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`g[-$CellContext`a, -$CellContext`b],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {"c", "d"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1[$CellContext`c, $CellContext`d],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"e", " ", "  ", "  "},
                 {" ", "e", 
                  RowBox[{",", "c"}], 
                  RowBox[{",", "d"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`d][
           xAct`xTensor`PD[-$CellContext`c][
            $CellContext`h2[$CellContext`e, -$CellContext`e]]],
          Editable->False]}]}], ")"}]}], "-", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"h\.b9", 
           StyleBox[GridBox[{
              {" ", "e"},
              {"c", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h1[-$CellContext`c, $CellContext`e],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"h\.b9", 
           StyleBox[GridBox[{
              {"c", "d"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h1[$CellContext`c, $CellContext`d],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], "X", 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`X],
       Editable->False], " ", 
      RowBox[{"(", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b9", 
             StyleBox[GridBox[{
                {" ", " ", "  ", "  "},
                {"d", "e", 
                 RowBox[{",", "b"}], 
                 RowBox[{",", "a"}]}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`PD[-$CellContext`a][
          xAct`xTensor`PD[-$CellContext`b][
           $CellContext`h1[-$CellContext`d, -$CellContext`e]]],
         Editable->False], "-", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b9", 
             StyleBox[GridBox[{
                {" ", " ", "  ", "  "},
                {"b", "d", 
                 RowBox[{",", "a"}], 
                 RowBox[{",", "e"}]}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`PD[-$CellContext`e][
          xAct`xTensor`PD[-$CellContext`a][
           $CellContext`h1[-$CellContext`b, -$CellContext`d]]],
         Editable->False], "-", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b9", 
             StyleBox[GridBox[{
                {" ", " ", "  ", "  "},
                {"a", "d", 
                 RowBox[{",", "b"}], 
                 RowBox[{",", "e"}]}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`PD[-$CellContext`e][
          xAct`xTensor`PD[-$CellContext`b][
           $CellContext`h1[-$CellContext`a, -$CellContext`d]]],
         Editable->False], "+", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h\.b9", 
             StyleBox[GridBox[{
                {" ", " ", "  ", "  "},
                {"a", "b", 
                 RowBox[{",", "d"}], 
                 RowBox[{",", "e"}]}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`PD[-$CellContext`e][
          xAct`xTensor`PD[-$CellContext`d][
           $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
         Editable->False]}], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], "X", 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`X],
       Editable->False], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {" ", " ", "  "},
                 {"c", "d", 
                  RowBox[{",", "a"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`a][
           $CellContext`h2[-$CellContext`c, -$CellContext`d]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {"c", "d", "  "},
                 {" ", " ", 
                  RowBox[{",", "b"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`b][
           $CellContext`h1[$CellContext`c, $CellContext`d]],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {"c", "d", "  "},
                 {" ", " ", 
                  RowBox[{",", "a"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`a][
           $CellContext`h1[$CellContext`c, $CellContext`d]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {" ", " ", "  "},
                 {"c", "d", 
                  RowBox[{",", "b"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`b][
           $CellContext`h2[-$CellContext`c, -$CellContext`d]],
          Editable->False]}], "+", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"c", "d"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h2[$CellContext`c, $CellContext`d],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", " ", "  ", "  "},
                 {"c", "d", 
                  RowBox[{",", "a"}], 
                  RowBox[{",", "b"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`b][
           xAct`xTensor`PD[-$CellContext`a][
            $CellContext`h1[-$CellContext`c, -$CellContext`d]]],
          Editable->False]}], "-", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"c", "d"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h2[$CellContext`c, $CellContext`d],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", " ", "  ", "  "},
                 {"b", "c", 
                  RowBox[{",", "a"}], 
                  RowBox[{",", "d"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`d][
           xAct`xTensor`PD[-$CellContext`a][
            $CellContext`h1[-$CellContext`b, -$CellContext`c]]],
          Editable->False]}], "-", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"c", "d"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h2[$CellContext`c, $CellContext`d],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", " ", "  ", "  "},
                 {"a", "c", 
                  RowBox[{",", "b"}], 
                  RowBox[{",", "d"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`d][
           xAct`xTensor`PD[-$CellContext`b][
            $CellContext`h1[-$CellContext`a, -$CellContext`c]]],
          Editable->False]}], "+", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {"c", "d"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h2[$CellContext`c, $CellContext`d],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", " ", "  ", "  "},
                 {"a", "b", 
                  RowBox[{",", "c"}], 
                  RowBox[{",", "d"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`d][
           xAct`xTensor`PD[-$CellContext`c][
            $CellContext`h1[-$CellContext`a, -$CellContext`b]]],
          Editable->False]}], "-", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {" ", " ", "  "},
                 {"b", "d", 
                  RowBox[{",", "c"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`c][
           $CellContext`h2[-$CellContext`b, -$CellContext`d]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", "c", 
                  RowBox[{",", "d"}]},
                 {"a", " ", "  "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[$CellContext`d][
           $CellContext`h1[-$CellContext`a, $CellContext`c]],
          Editable->False]}], "+", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {" ", " ", "  "},
                 {"b", "c", 
                  RowBox[{",", "d"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`d][
           $CellContext`h2[-$CellContext`b, -$CellContext`c]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", "c", 
                  RowBox[{",", "d"}]},
                 {"a", " ", "  "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[$CellContext`d][
           $CellContext`h1[-$CellContext`a, $CellContext`c]],
          Editable->False]}], "-", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {" ", " ", "  "},
                 {"a", "d", 
                  RowBox[{",", "c"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`c][
           $CellContext`h2[-$CellContext`a, -$CellContext`d]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", "c", 
                  RowBox[{",", "d"}]},
                 {"b", " ", "  "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[$CellContext`d][
           $CellContext`h1[-$CellContext`b, $CellContext`c]],
          Editable->False]}], "+", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {" ", " ", "  "},
                 {"a", "c", 
                  RowBox[{",", "d"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`d][
           $CellContext`h2[-$CellContext`a, -$CellContext`c]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {" ", "c", 
                  RowBox[{",", "d"}]},
                 {"b", " ", "  "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[$CellContext`d][
           $CellContext`h1[-$CellContext`b, $CellContext`c]],
          Editable->False]}], "+", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"g", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"a", "b"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`g[-$CellContext`a, -$CellContext`b],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {" ", " ", "  "},
                 {"c", "e", 
                  RowBox[{",", "d"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`d][
           $CellContext`h2[-$CellContext`c, -$CellContext`e]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {"c", "d", 
                  RowBox[{",", "e"}]},
                 {" ", " ", "  "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[$CellContext`e][
           $CellContext`h1[$CellContext`c, $CellContext`d]],
          Editable->False]}], "-", 
        RowBox[{"3", " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"g", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"a", "b"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`g[-$CellContext`a, -$CellContext`b],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b2", 
              StyleBox[GridBox[{
                 {" ", " ", "  "},
                 {"c", "d", 
                  RowBox[{",", "e"}]}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[-$CellContext`e][
           $CellContext`h2[-$CellContext`c, -$CellContext`d]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {"c", "d", 
                  RowBox[{",", "e"}]},
                 {" ", " ", "  "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`PD[$CellContext`e][
           $CellContext`h1[$CellContext`c, $CellContext`d]],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"h\.b9", 
              StyleBox[GridBox[{
                 {"c", "d"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h1[$CellContext`c, $CellContext`d],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", "  "},
                    {"c", " ", 
                    RowBox[{",", "a"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`a][
              $CellContext`h1[-$CellContext`c, $CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"d", "e", 
                    RowBox[{",", "b"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`b][
              $CellContext`h1[-$CellContext`d, -$CellContext`e]],
             Editable->False]}], "+", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b2", 
                 StyleBox[GridBox[{
                    {" ", " ", "  ", "  "},
                    {"c", "d", 
                    RowBox[{",", "a"}], 
                    RowBox[{",", "b"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`b][
              xAct`xTensor`PD[-$CellContext`a][
               $CellContext`h2[-$CellContext`c, -$CellContext`d]]],
             Editable->False]}], "-", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", "  "},
                    {"a", " ", 
                    RowBox[{",", "c"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`c][
              $CellContext`h1[-$CellContext`a, $CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"b", "e", 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              $CellContext`h1[-$CellContext`b, -$CellContext`e]],
             Editable->False]}], "+", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", "  "},
                    {"b", " ", 
                    RowBox[{",", "a"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`a][
              $CellContext`h1[-$CellContext`b, $CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"c", "e", 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              $CellContext`h1[-$CellContext`c, -$CellContext`e]],
             Editable->False]}], "+", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", "  "},
                    {"a", " ", 
                    RowBox[{",", "b"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`b][
              $CellContext`h1[-$CellContext`a, $CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"c", "e", 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              $CellContext`h1[-$CellContext`c, -$CellContext`e]],
             Editable->False]}], "+", 
           RowBox[{
            InterpretationBox[
             StyleBox[GridBox[{
                {"g", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"a", "b"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`g[-$CellContext`a, -$CellContext`b],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {"e", "f", "  "},
                    {" ", " ", 
                    RowBox[{",", "c"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`c][
              $CellContext`h1[$CellContext`e, $CellContext`f]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"e", "f", 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              $CellContext`h1[-$CellContext`e, -$CellContext`f]],
             Editable->False]}], "-", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b2", 
                 StyleBox[GridBox[{
                    {" ", " ", "  ", "  "},
                    {"b", "c", 
                    RowBox[{",", "a"}], 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              xAct`xTensor`PD[-$CellContext`a][
               $CellContext`h2[-$CellContext`b, -$CellContext`c]]],
             Editable->False]}], "-", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b2", 
                 StyleBox[GridBox[{
                    {" ", " ", "  ", "  "},
                    {"a", "c", 
                    RowBox[{",", "b"}], 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              xAct`xTensor`PD[-$CellContext`b][
               $CellContext`h2[-$CellContext`a, -$CellContext`c]]],
             Editable->False]}], "+", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b2", 
                 StyleBox[GridBox[{
                    {" ", " ", "  ", "  "},
                    {"a", "b", 
                    RowBox[{",", "c"}], 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              xAct`xTensor`PD[-$CellContext`c][
               $CellContext`h2[-$CellContext`a, -$CellContext`b]]],
             Editable->False]}], "+", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", "  "},
                    {"a", " ", 
                    RowBox[{",", "c"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`c][
              $CellContext`h1[-$CellContext`a, $CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"b", "d", 
                    RowBox[{",", "e"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`e][
              $CellContext`h1[-$CellContext`b, -$CellContext`d]],
             Editable->False]}], "-", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", "  "},
                    {"b", " ", 
                    RowBox[{",", "a"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`a][
              $CellContext`h1[-$CellContext`b, $CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"c", "d", 
                    RowBox[{",", "e"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`e][
              $CellContext`h1[-$CellContext`c, -$CellContext`d]],
             Editable->False]}], "-", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", "  "},
                    {"a", " ", 
                    RowBox[{",", "b"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`b][
              $CellContext`h1[-$CellContext`a, $CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"c", "d", 
                    RowBox[{",", "e"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`e][
              $CellContext`h1[-$CellContext`c, -$CellContext`d]],
             Editable->False]}], "-", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"c", "e", 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              $CellContext`h1[-$CellContext`c, -$CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", 
                    RowBox[{",", "e"}]},
                    {"a", "b", "  "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[$CellContext`e][
              $CellContext`h1[-$CellContext`a, -$CellContext`b]],
             Editable->False]}], "+", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"c", "d", 
                    RowBox[{",", "e"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`e][
              $CellContext`h1[-$CellContext`c, -$CellContext`d]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", 
                    RowBox[{",", "e"}]},
                    {"a", "b", "  "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[$CellContext`e][
              $CellContext`h1[-$CellContext`a, -$CellContext`b]],
             Editable->False]}], "+", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"b", "e", 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              $CellContext`h1[-$CellContext`b, -$CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", 
                    RowBox[{",", "e"}]},
                    {"a", "c", "  "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[$CellContext`e][
              $CellContext`h1[-$CellContext`a, -$CellContext`c]],
             Editable->False]}], "-", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"b", "d", 
                    RowBox[{",", "e"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`e][
              $CellContext`h1[-$CellContext`b, -$CellContext`d]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", 
                    RowBox[{",", "e"}]},
                    {"a", "c", "  "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[$CellContext`e][
              $CellContext`h1[-$CellContext`a, -$CellContext`c]],
             Editable->False]}], "+", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"g", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"a", "b"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`g[-$CellContext`a, -$CellContext`b],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {"e", "f"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`h1[$CellContext`e, $CellContext`f],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  ", "  "},
                    {"c", "e", 
                    RowBox[{",", "d"}], 
                    RowBox[{",", "f"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`f][
              xAct`xTensor`PD[-$CellContext`d][
               $CellContext`h1[-$CellContext`c, -$CellContext`e]]],
             Editable->False]}], "-", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"g", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"a", "b"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`g[-$CellContext`a, -$CellContext`b],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {"e", "f"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`h1[$CellContext`e, $CellContext`f],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  ", "  "},
                    {"c", "d", 
                    RowBox[{",", "e"}], 
                    RowBox[{",", "f"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`f][
              xAct`xTensor`PD[-$CellContext`e][
               $CellContext`h1[-$CellContext`c, -$CellContext`d]]],
             Editable->False]}], "-", 
           RowBox[{"4", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"g", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"a", "b"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`g[-$CellContext`a, -$CellContext`b],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"e", "f", 
                    RowBox[{",", "d"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`d][
              $CellContext`h1[-$CellContext`e, -$CellContext`f]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", 
                    RowBox[{",", "f"}]},
                    {"c", " ", "  "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[$CellContext`f][
              $CellContext`h1[-$CellContext`c, $CellContext`e]],
             Editable->False]}], "+", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"g", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"a", "b"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`g[-$CellContext`a, -$CellContext`b],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"d", "f", 
                    RowBox[{",", "e"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`e][
              $CellContext`h1[-$CellContext`d, -$CellContext`f]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", 
                    RowBox[{",", "f"}]},
                    {"c", " ", "  "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[$CellContext`f][
              $CellContext`h1[-$CellContext`c, $CellContext`e]],
             Editable->False]}], "+", 
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"g", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"a", "b"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`g[-$CellContext`a, -$CellContext`b],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", " ", "  "},
                    {"d", "e", 
                    RowBox[{",", "f"}]}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[-$CellContext`f][
              $CellContext`h1[-$CellContext`d, -$CellContext`e]],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[GridBox[{
                {"h\.b9", 
                 StyleBox[GridBox[{
                    {" ", "e", 
                    RowBox[{",", "f"}]},
                    {"c", " ", "  "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->9]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`PD[$CellContext`f][
              $CellContext`h1[-$CellContext`c, $CellContext`e]],
             Editable->False]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.577789106465993*^9, 3.5777891280744*^9}, 
   3.577854279809713*^9, 3.577890102843939*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.4. Gauge transformation", "Subsection",
 CellChangeTimes->{{3.576566696520385*^9, 3.5765667138203983`*^9}, 
   3.576567341262363*^9, {3.5776264575469313`*^9, 3.577626458592226*^9}, {
   3.5778840890459337`*^9, 3.577884091578231*^9}, 3.577884211723555*^9}],

Cell["\<\
In this section we make use of the xPert capabilities to compute gauge \
changes of tensors.
First we go back to using the original perturbations internal to xPert (we \
clean up the previous substitution in terms of the trace-reversed \
perturbation):\
\>", "Text",
 CellChangeTimes->{{3.5778902215154676`*^9, 3.577890299989222*^9}, {
  3.578074434168025*^9, 3.578074457366455*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "1", "]"}], ",", "a_", ",", "b_"}], "]"}], "=."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "2", "]"}], ",", "a_", ",", "b_"}], "]"}], "=."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "3", "]"}], ",", "a_", ",", "b_"}], "]"}], "=."}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5778545730974817`*^9, 3.577854574688665*^9}, {
  3.577854627397244*^9, 3.5778546390560703`*^9}, {3.577855310512381*^9, 
  3.577855311755913*^9}}],

Cell["Then define the set of gauge transformation vectors:", "Text",
 CellChangeTimes->{{3.577890308247714*^9, 3.577890335683682*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[Xi]", "[", 
    RowBox[{
     RowBox[{"LI", "[", "n", "]"}], ",", "a"}], "]"}], ",", "M"}], 
  "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Xi]", "[", 
    RowBox[{
     RowBox[{"LI", "[", "n", "]"}], ",", "a"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Xi][
    xAct`xTensor`LI[$CellContext`n], $CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.5778903027600183`*^9}]
}, Open  ]],

Cell["Gauge change at first order...", "Text",
 CellChangeTimes->{{3.577890339001299*^9, 3.577890347089528*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GaugeChange", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "1", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "\[Xi]"}], "]"}]], "Input",
 CellChangeTimes->{{3.577853982694491*^9, 3.577854003727404*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"h", 
       StyleBox[GridBox[{
          {
           StyleBox["1",
            FontColor->RGBColor[0., 0., 1.]], " ", " "},
          {" ", "a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h[
    xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
   Editable->False], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[0., 0., 1.]]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`a]][
    $CellContext`g[-$CellContext`a, -$CellContext`b]],
   Editable->False]}]], "Output",
 CellChangeTimes->{3.577854004764027*^9, 3.577854325611926*^9, 
  3.577854578751665*^9, 3.5778546443463593`*^9}]
}, Open  ]],

Cell["... and a familiar form with covariant derivatives.", "Text",
 CellChangeTimes->{{3.577890349655452*^9, 3.577890363583899*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gauge1", "=", 
  RowBox[{
   RowBox[{"LieDToCovD", "[", 
    RowBox[{
     RowBox[{"GaugeChange", "[", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"-", "a"}], ",", 
         RowBox[{"-", "b"}]}], "]"}], ",", "\[Xi]"}], "]"}], ",", "CD"}], 
    "]"}], "//", "org"}]}]], "Input",
 CellChangeTimes->{{3.57785342951038*^9, 3.577853437349258*^9}, {
  3.577853560006433*^9, 3.577853578798876*^9}, {3.577853858688862*^9, 
  3.577853862342211*^9}, {3.57785468269491*^9, 3.5778546853947973`*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"h", 
       StyleBox[GridBox[{
          {
           StyleBox["1",
            FontColor->RGBColor[0., 0., 1.]], " ", " "},
          {" ", "a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h[
    xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b],
   Editable->False], "+", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"\[Xi]", 
       StyleBox[GridBox[{
          {
           StyleBox["1",
            FontColor->RGBColor[0., 0., 1.]], " ", "  "},
          {" ", "b", 
           RowBox[{";", "a"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`a][
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], -$CellContext`b]],
   Editable->False], "+", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"\[Xi]", 
       StyleBox[GridBox[{
          {
           StyleBox["1",
            FontColor->RGBColor[0., 0., 1.]], " ", "  "},
          {" ", "a", 
           RowBox[{";", "b"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`b][
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], -$CellContext`a]],
   Editable->False]}]], "Output",
 CellChangeTimes->{3.577853408884007*^9, 3.5778535794882812`*^9, 
  3.5778538629676113`*^9, 3.577854582122058*^9, 3.577854646017655*^9, 
  3.5778546862761908`*^9, 3.57789039884002*^9}]
}, Open  ]],

Cell["\<\
At higher orders the pattern is similar with Lie derivatives and coefficients \
given by the binomial expansion...\
\>", "Text",
 CellChangeTimes->{{3.57789036803133*^9, 3.577890393936151*^9}, 
   3.5780744694686813`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GaugeChange", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "2", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "\[Xi]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"h", 
       StyleBox[GridBox[{
          {
           StyleBox["2",
            FontColor->RGBColor[0., 0., 1.]], " ", " "},
          {" ", "a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h[
    xAct`xTensor`LI[2], -$CellContext`a, -$CellContext`b],
   Editable->False], "+", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {
              StyleBox["1",
               FontColor->RGBColor[0., 0., 1.]], " ", " "},
             {" ", "a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      $CellContext`h[
       xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]],
     Editable->False], ")"}]}], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[0., 0., 1.]]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]], 
     RowBox[{
      SubscriptBox["\[ScriptCapitalL]", GridBox[{
         {"\[Xi]", 
          StyleBox[GridBox[{
             {
              StyleBox["1",
               FontColor->RGBColor[0., 0., 1.]]},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`a]][
    xAct`xTensor`LieD[
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`a]][
     $CellContext`g[-$CellContext`a, -$CellContext`b]]],
   Editable->False], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[0., 0., 1.]]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`\[Xi][
     xAct`xTensor`LI[2], $CellContext`a]][
    $CellContext`g[-$CellContext`a, -$CellContext`b]],
   Editable->False]}]], "Output",
 CellChangeTimes->{
  3.577854016701735*^9, 3.5778543659818296`*^9, 3.577854647184947*^9, {
   3.5778903964459743`*^9, 3.57789040032261*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gauge2", "=", 
  RowBox[{
   RowBox[{"LieDToCovD", "[", 
    RowBox[{
     RowBox[{"GaugeChange", "[", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{
         RowBox[{"LI", "[", "2", "]"}], ",", 
         RowBox[{"-", "a"}], ",", 
         RowBox[{"-", "b"}]}], "]"}], ",", "\[Xi]"}], "]"}], ",", "CD"}], 
    "]"}], "//", "org"}]}]], "Input",
 CellChangeTimes->{{3.577853448397089*^9, 3.577853452810548*^9}, {
  3.5778535847749567`*^9, 3.577853588891696*^9}, {3.5778538657377377`*^9, 
  3.5778538667311897`*^9}, {3.57785465944573*^9, 3.577854689971017*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"h", 
       StyleBox[GridBox[{
          {
           StyleBox["2",
            FontColor->RGBColor[0., 0., 1.]], " ", " "},
          {" ", "a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h[
    xAct`xTensor`LI[2], -$CellContext`a, -$CellContext`b],
   Editable->False], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "c"},
           {" ", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], -$CellContext`b, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"\[Xi]", 
       StyleBox[GridBox[{
          {
           StyleBox["2",
            FontColor->RGBColor[0., 0., 1.]], " ", "  "},
          {" ", "b", 
           RowBox[{";", "a"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`a][
    $CellContext`\[Xi][
     xAct`xTensor`LI[2], -$CellContext`b]],
   Editable->False], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "c"},
           {" ", "a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], -$CellContext`a, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"\[Xi]", 
       StyleBox[GridBox[{
          {
           StyleBox["2",
            FontColor->RGBColor[0., 0., 1.]], " ", "  "},
          {" ", "a", 
           RowBox[{";", "b"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`b][
    $CellContext`\[Xi][
     xAct`xTensor`LI[2], -$CellContext`a]],
   Editable->False], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", " ", "  "},
           {" ", "a", "b", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`h[
      xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "b", 
            RowBox[{";", "a"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`b]]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "a", 
            RowBox[{";", "b"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`a]]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", 
            RowBox[{";", "c"}]},
           {" ", "a", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`a]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", 
            RowBox[{";", "c"}]},
           {" ", "b", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`b]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{
  3.577853453451639*^9, 3.5778535904052467`*^9, 3.577853867669198*^9, {
   3.577854648691804*^9, 3.577854690569214*^9}, 3.577890402105447*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GaugeChange", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "3", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "\[Xi]"}], "]"}]], "Input",
 CellChangeTimes->{{3.57785809299576*^9, 3.577858098630975*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"h", 
       StyleBox[GridBox[{
          {
           StyleBox["3",
            FontColor->RGBColor[0., 0., 1.]], " ", " "},
          {" ", "a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h[
    xAct`xTensor`LI[3], -$CellContext`a, -$CellContext`b],
   Editable->False], "+", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {
              StyleBox["2",
               FontColor->RGBColor[0., 0., 1.]], " ", " "},
             {" ", "a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      $CellContext`h[
       xAct`xTensor`LI[2], -$CellContext`a, -$CellContext`b]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
          {"h", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]], " ", " "},
              {" ", "a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[1], $CellContext`a]][
       $CellContext`h[
        xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]]],
     Editable->False], ")"}]}], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[0., 0., 1.]]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]], 
     RowBox[{
      SubscriptBox["\[ScriptCapitalL]", GridBox[{
         {"\[Xi]", 
          StyleBox[GridBox[{
             {
              StyleBox["1",
               FontColor->RGBColor[0., 0., 1.]]},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]], 
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}]}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`a]][
    xAct`xTensor`LieD[
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`a]][
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      $CellContext`g[-$CellContext`a, -$CellContext`b]]]],
   Editable->False], "+", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["2",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[2], $CellContext`a]][
       $CellContext`g[-$CellContext`a, -$CellContext`b]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {
              StyleBox["1",
               FontColor->RGBColor[0., 0., 1.]], " ", " "},
             {" ", "a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[2], $CellContext`a]][
      $CellContext`h[
       xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]],
     Editable->False], ")"}]}], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[0., 0., 1.]]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`\[Xi][
     xAct`xTensor`LI[3], $CellContext`a]][
    $CellContext`g[-$CellContext`a, -$CellContext`b]],
   Editable->False]}]], "Output",
 CellChangeTimes->{
  3.577856083245105*^9, {3.577858095348042*^9, 3.577858098996663*^9}, 
   3.577890403637985*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gauge3", "=", 
  RowBox[{
   RowBox[{"LieDToCovD", "[", 
    RowBox[{
     RowBox[{"GaugeChange", "[", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{
         RowBox[{"LI", "[", "3", "]"}], ",", 
         RowBox[{"-", "a"}], ",", 
         RowBox[{"-", "b"}]}], "]"}], ",", "\[Xi]"}], "]"}], ",", "CD"}], 
    "]"}], "//", "org"}]}]], "Input",
 CellChangeTimes->{{3.57785345778764*^9, 3.5778534691777277`*^9}, {
  3.57785360989186*^9, 3.577853640250897*^9}, {3.5778538461099577`*^9, 
  3.577853876390201*^9}, {3.577854693895776*^9, 3.577854695124324*^9}}],

Cell[BoxData["0.3320220000000518`"], "Print",
 CellChangeTimes->{3.577853877939315*^9, 3.577854650186172*^9, 
  3.5778546962361393`*^9, 3.577890405522707*^9}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"h", 
       StyleBox[GridBox[{
          {
           StyleBox["3",
            FontColor->RGBColor[0., 0., 1.]], " ", " "},
          {" ", "a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h[
    xAct`xTensor`LI[3], -$CellContext`a, -$CellContext`b],
   Editable->False], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", "c"},
           {" ", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[2], -$CellContext`b, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "c"},
           {" ", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], -$CellContext`b, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[2], -$CellContext`c]],
    Editable->False]}], "+", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"\[Xi]", 
       StyleBox[GridBox[{
          {
           StyleBox["3",
            FontColor->RGBColor[0., 0., 1.]], " ", "  "},
          {" ", "b", 
           RowBox[{";", "a"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`a][
    $CellContext`\[Xi][
     xAct`xTensor`LI[3], -$CellContext`b]],
   Editable->False], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", "c"},
           {" ", "a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[2], -$CellContext`a, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], "c", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[2], $CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{"6", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c", "d"},
           {" ", " ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], $CellContext`c, $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "d", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`d]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "c"},
           {" ", "a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], -$CellContext`a, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[2], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[2], -$CellContext`c]],
    Editable->False]}], "+", 
  InterpretationBox[
   StyleBox[GridBox[{
      {"\[Xi]", 
       StyleBox[GridBox[{
          {
           StyleBox["3",
            FontColor->RGBColor[0., 0., 1.]], " ", "  "},
          {" ", "a", 
           RowBox[{";", "b"}]}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`CD[-$CellContext`b][
    $CellContext`\[Xi][
     xAct`xTensor`LI[3], -$CellContext`a]],
   Editable->False], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[2], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", " ", "  "},
           {" ", "a", "b", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`h[
      xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]],
    Editable->False]}], "+", 
  RowBox[{"6", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", " ", "  "},
           {" ", "a", "d", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`h[
      xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`d]],
    Editable->False]}], "+", 
  RowBox[{"6", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", " ", "  "},
           {" ", "b", "d", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`h[
      xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`d]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", " ", "  "},
           {" ", "a", "b", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`h[
      xAct`xTensor`LI[2], -$CellContext`a, -$CellContext`b]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "d", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`d]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "d"},
           {" ", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], -$CellContext`b, $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "d", 
            RowBox[{";", "a"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`d]]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "d", 
            RowBox[{";", "a"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`d]]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "b", 
            RowBox[{";", "a"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Xi][
       xAct`xTensor`LI[2], -$CellContext`b]]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "d"},
           {" ", "a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], -$CellContext`a, $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "d", 
            RowBox[{";", "b"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`d]]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "d", 
            RowBox[{";", "b"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`d]]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "a", 
            RowBox[{";", "b"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Xi][
       xAct`xTensor`LI[2], -$CellContext`a]]],
    Editable->False]}], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "a", 
            RowBox[{";", "d"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`d][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`a]]],
    Editable->False]}], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "b", 
            RowBox[{";", "d"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`d][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`b]]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", 
            RowBox[{";", "c"}]},
           {" ", "a", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[2], -$CellContext`a]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["2",
             FontColor->RGBColor[0., 0., 1.]], " ", 
            RowBox[{";", "c"}]},
           {" ", "b", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[2], -$CellContext`b]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", " ", "  "},
           {" ", "a", "b", 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`h[
      xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "c"},
           {" ", "b", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], -$CellContext`b, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "c"},
           {" ", "a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[
     xAct`xTensor`LI[1], -$CellContext`a, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`c]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "b"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`b][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", 
            RowBox[{";", "c"}]},
           {" ", "a", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`a]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "a"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`a][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", 
            RowBox[{";", "c"}]},
           {" ", "b", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`b]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  "},
           {" ", "c", 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`c]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "b", 
            RowBox[{";", "a"}], 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`b]]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d", "  "},
           {" ", " ", 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`d]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "a", 
            RowBox[{";", "b"}], 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`a]]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", " ", "  ", "  "},
           {" ", "a", "b", 
            RowBox[{";", "c"}], 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`c][
      $CellContext`h[
       xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  ", "  "},
           {" ", "b", 
            RowBox[{";", "a"}], 
            RowBox[{";", "c"}], 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Xi][
        xAct`xTensor`LI[1], -$CellContext`b]]]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "d"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`d],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  ", "  "},
           {" ", "a", 
            RowBox[{";", "b"}], 
            RowBox[{";", "c"}], 
            RowBox[{";", "d"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`d][
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Xi][
        xAct`xTensor`LI[1], -$CellContext`a]]]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "d", 
            RowBox[{";", "b"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`d]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", 
            RowBox[{";", "d"}]},
           {" ", "a", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`d][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`a]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], "c"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", "  ", "  "},
           {" ", "d", 
            RowBox[{";", "a"}], 
            RowBox[{";", "c"}]}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[-$CellContext`c][
     $CellContext`CD[-$CellContext`a][
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], -$CellContext`d]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {
            StyleBox["1",
             FontColor->RGBColor[0., 0., 1.]], " ", 
            RowBox[{";", "d"}]},
           {" ", "b", "  "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`CD[$CellContext`d][
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], -$CellContext`b]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{{3.5778534584815807`*^9, 3.577853469823352*^9}, {
   3.5778536248120327`*^9, 3.577853650477272*^9}, {3.5778538484298143`*^9, 
   3.577853878255307*^9}, 3.577854650263863*^9, 3.577854696312688*^9, 
   3.577890405597824*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GaugeChange", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "4", "]"}], ",", 
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "\[Xi]"}], "]"}]], "Input",
 CellChangeTimes->{3.577856099709923*^9}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"h", 
       StyleBox[GridBox[{
          {
           StyleBox["4",
            FontColor->RGBColor[0., 0., 1.]], " ", " "},
          {" ", "a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`h[
    xAct`xTensor`LI[4], -$CellContext`a, -$CellContext`b],
   Editable->False], "+", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {
              StyleBox["3",
               FontColor->RGBColor[0., 0., 1.]], " ", " "},
             {" ", "a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      $CellContext`h[
       xAct`xTensor`LI[3], -$CellContext`a, -$CellContext`b]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
          {"h", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[0., 0., 1.]], " ", " "},
              {" ", "a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[1], $CellContext`a]][
       $CellContext`h[
        xAct`xTensor`LI[2], -$CellContext`a, -$CellContext`b]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", GridBox[{
            {"\[Xi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["1",
                  FontColor->RGBColor[0., 0., 1.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[0., 0., 1.]], " ", " "},
               {" ", "a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}]}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[1], $CellContext`a]][
       xAct`xTensor`LieD[
        $CellContext`\[Xi][
         xAct`xTensor`LI[1], $CellContext`a]][
        $CellContext`h[
         xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]]]],
     Editable->False], ")"}]}], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[0., 0., 1.]]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]], 
     RowBox[{
      SubscriptBox["\[ScriptCapitalL]", GridBox[{
         {"\[Xi]", 
          StyleBox[GridBox[{
             {
              StyleBox["1",
               FontColor->RGBColor[0., 0., 1.]]},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]], 
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}]}]}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`\[Xi][
     xAct`xTensor`LI[1], $CellContext`a]][
    xAct`xTensor`LieD[
     $CellContext`\[Xi][
      xAct`xTensor`LI[1], $CellContext`a]][
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[1], $CellContext`a]][
       $CellContext`g[-$CellContext`a, -$CellContext`b]]]]],
   Editable->False], "+", 
  RowBox[{"6", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["1",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", GridBox[{
            {"\[Xi]", 
             StyleBox[GridBox[{
                {
                 StyleBox["2",
                  FontColor->RGBColor[0., 0., 1.]]},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}]}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[1], $CellContext`a]][
       xAct`xTensor`LieD[
        $CellContext`\[Xi][
         xAct`xTensor`LI[2], $CellContext`a]][
        $CellContext`g[-$CellContext`a, -$CellContext`b]]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"12", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["2",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
          {"h", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]], " ", " "},
              {" ", "a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[2], $CellContext`a]][
       $CellContext`h[
        xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["3",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[1], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[3], $CellContext`a]][
       $CellContext`g[-$CellContext`a, -$CellContext`b]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {
              StyleBox["2",
               FontColor->RGBColor[0., 0., 1.]], " ", " "},
             {" ", "a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[2], $CellContext`a]][
      $CellContext`h[
       xAct`xTensor`LI[2], -$CellContext`a, -$CellContext`b]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], 
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", GridBox[{
           {"\[Xi]", 
            StyleBox[GridBox[{
               {
                StyleBox["2",
                 FontColor->RGBColor[0., 0., 1.]]},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[2], $CellContext`a]][
      xAct`xTensor`LieD[
       $CellContext`\[Xi][
        xAct`xTensor`LI[2], $CellContext`a]][
       $CellContext`g[-$CellContext`a, -$CellContext`b]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", GridBox[{
          {"\[Xi]", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[0., 0., 1.]]},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {
              StyleBox["1",
               FontColor->RGBColor[0., 0., 1.]], " ", " "},
             {" ", "a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Xi][
       xAct`xTensor`LI[3], $CellContext`a]][
      $CellContext`h[
       xAct`xTensor`LI[1], -$CellContext`a, -$CellContext`b]],
     Editable->False], ")"}]}], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {
             StyleBox["4",
              FontColor->RGBColor[0., 0., 1.]]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`\[Xi][
     xAct`xTensor`LI[4], $CellContext`a]][
    $CellContext`g[-$CellContext`a, -$CellContext`b]],
   Editable->False]}]], "Output",
 CellChangeTimes->{3.577856100427443*^9, 3.5778904073108788`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1335, 691},
WindowMargins->{{0, Automatic}, {Automatic, 24}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Linux x86 (64-bit) (November 11, 2008)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Report"}, "StandardReport.nb", CharacterEncoding -> 
       "iso8859-1"]]], 
   Cell[
    StyleData["Section"]]}, Visible -> False, FrontEndVersion -> 
  "7.0 for Linux x86 (64-bit) (November 11, 2008)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 314, 5, 170, "Title"],
Cell[884, 29, 104, 1, 53, "Author"],
Cell[991, 32, 110, 1, 23, "Department"],
Cell[1104, 35, 161, 2, 55, "Date"],
Cell[1268, 39, 397, 7, 61, "Text"],
Cell[CellGroupData[{
Cell[1690, 50, 269, 3, 92, "Section"],
Cell[1962, 55, 275, 5, 61, "Text"],
Cell[2240, 62, 98, 1, 50, "Input"],
Cell[CellGroupData[{
Cell[2363, 67, 197, 2, 32, "Subsection"],
Cell[2563, 71, 251, 5, 37, "Text"],
Cell[2817, 78, 323, 6, 37, "Text"],
Cell[CellGroupData[{
Cell[3165, 88, 550, 18, 50, "Input"],
Cell[3718, 108, 845, 20, 71, "Output"]
}, Open  ]],
Cell[4578, 131, 595, 10, 61, "Text"],
Cell[CellGroupData[{
Cell[5198, 145, 724, 20, 50, "Input"],
Cell[5925, 167, 1286, 36, 74, "Output"]
}, Open  ]],
Cell[7226, 206, 216, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[7467, 214, 620, 11, 50, "Input"],
Cell[8090, 227, 946, 22, 71, "Output"]
}, Open  ]],
Cell[9051, 252, 279, 5, 37, "Text"],
Cell[CellGroupData[{
Cell[9355, 261, 799, 24, 50, "Input"],
Cell[10157, 287, 781, 17, 78, "Output"]
}, Open  ]],
Cell[10953, 307, 280, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[11258, 316, 338, 9, 50, "Input"],
Cell[11599, 327, 677, 14, 80, "Output"]
}, Open  ]],
Cell[12291, 344, 124, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[12440, 349, 668, 16, 93, "Input"],
Cell[13111, 367, 1233, 29, 73, "Output"]
}, Open  ]],
Cell[14359, 399, 380, 7, 61, "Text"],
Cell[CellGroupData[{
Cell[14764, 410, 1055, 23, 50, "Input"],
Cell[15822, 435, 1497, 37, 72, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[17368, 478, 406, 5, 31, "Subsection"],
Cell[17777, 485, 460, 8, 85, "Text"],
Cell[18240, 495, 124, 2, 50, "Input"],
Cell[18367, 499, 112, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[18504, 504, 243, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[18772, 512, 695, 10, 30, "Print"],
Cell[19470, 524, 968, 18, 30, "Print"],
Cell[20441, 544, 717, 10, 30, "Print"],
Cell[21161, 556, 676, 9, 30, "Print"],
Cell[21840, 567, 657, 9, 30, "Print"],
Cell[22500, 578, 698, 10, 30, "Print"],
Cell[23201, 590, 972, 18, 30, "Print"],
Cell[24176, 610, 717, 10, 30, "Print"],
Cell[24896, 622, 696, 10, 30, "Print"],
Cell[25595, 634, 970, 18, 30, "Print"],
Cell[26568, 654, 737, 10, 30, "Print"],
Cell[27308, 666, 696, 10, 30, "Print"],
Cell[28007, 678, 851, 12, 56, "Print"],
Cell[28861, 692, 696, 10, 30, "Print"]
}, Open  ]]
}, Open  ]],
Cell[29584, 706, 122, 1, 37, "Text"],
Cell[29709, 709, 310, 7, 76, "Input"],
Cell[CellGroupData[{
Cell[30044, 720, 98, 1, 30, "Subsubsection"],
Cell[30145, 723, 254, 5, 37, "Text"],
Cell[30402, 730, 297, 7, 50, "Input"],
Cell[30702, 739, 161, 3, 37, "Text"],
Cell[30866, 744, 449, 12, 50, "Input"],
Cell[31318, 758, 394, 7, 61, "Text"],
Cell[31715, 767, 642, 15, 50, "Input"],
Cell[32360, 784, 248, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[32633, 792, 1528, 42, 76, "Input"],
Cell[34164, 836, 2159, 62, 149, "Output"]
}, Open  ]],
Cell[36338, 901, 217, 5, 37, "Text"],
Cell[CellGroupData[{
Cell[36580, 910, 243, 5, 50, "Input"],
Cell[36826, 917, 21899, 579, 102, "Output"]
}, Open  ]],
Cell[58740, 1499, 168, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[58933, 1506, 744, 16, 50, "Input"],
Cell[CellGroupData[{
Cell[59702, 1526, 487, 12, 30, "Print"],
Cell[60192, 1540, 448, 9, 30, "Print"],
Cell[60643, 1551, 457, 9, 30, "Print"],
Cell[61103, 1562, 568, 15, 30, "Print"],
Cell[61674, 1579, 449, 9, 30, "Print"],
Cell[62126, 1590, 463, 10, 30, "Print"],
Cell[62592, 1602, 576, 15, 30, "Print"],
Cell[63171, 1619, 449, 9, 30, "Print"],
Cell[63623, 1630, 469, 11, 30, "Print"],
Cell[64095, 1643, 552, 14, 30, "Print"],
Cell[64650, 1659, 449, 9, 30, "Print"],
Cell[65102, 1670, 463, 10, 30, "Print"],
Cell[65568, 1682, 603, 16, 30, "Print"],
Cell[66174, 1700, 448, 9, 30, "Print"],
Cell[66625, 1711, 467, 10, 30, "Print"],
Cell[67095, 1723, 601, 16, 30, "Print"],
Cell[67699, 1741, 449, 9, 30, "Print"],
Cell[68151, 1752, 473, 11, 30, "Print"],
Cell[68627, 1765, 581, 15, 30, "Print"],
Cell[69211, 1782, 449, 9, 30, "Print"],
Cell[69663, 1793, 463, 10, 30, "Print"],
Cell[70129, 1805, 526, 14, 30, "Print"],
Cell[70658, 1821, 451, 9, 30, "Print"],
Cell[71112, 1832, 467, 11, 30, "Print"],
Cell[71582, 1845, 462, 11, 30, "Print"],
Cell[72047, 1858, 453, 9, 30, "Print"],
Cell[72503, 1869, 453, 9, 30, "Print"],
Cell[72959, 1880, 535, 14, 30, "Print"],
Cell[73497, 1896, 451, 9, 30, "Print"],
Cell[73951, 1907, 458, 10, 30, "Print"]
}, Open  ]]
}, Open  ]],
Cell[74436, 1921, 304, 6, 37, "Text"],
Cell[74743, 1929, 297, 6, 50, "Input"],
Cell[75043, 1937, 278, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[75346, 1946, 208, 4, 50, "Input"],
Cell[75557, 1952, 15975, 441, 329, "Output"]
}, Open  ]],
Cell[91547, 2396, 302, 5, 37, "Text"],
Cell[91852, 2403, 2017, 63, 125, "Input"],
Cell[93872, 2468, 283, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[94180, 2477, 765, 19, 50, "Input"],
Cell[94948, 2498, 922, 23, 65, "Output"]
}, Open  ]],
Cell[95885, 2524, 254, 5, 37, "Text"],
Cell[96142, 2531, 195, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[96362, 2539, 694, 19, 50, "Input"],
Cell[97059, 2560, 39399, 1057, 633, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[136507, 3623, 124, 2, 30, "Subsubsection"],
Cell[136634, 3627, 362, 7, 61, "Text"],
Cell[136999, 3636, 348, 8, 50, "Input"],
Cell[137350, 3646, 499, 13, 50, "Input"],
Cell[137852, 3661, 688, 16, 50, "Input"],
Cell[CellGroupData[{
Cell[138565, 3681, 1576, 39, 101, "Input"],
Cell[140144, 3722, 2404, 69, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142585, 3796, 295, 6, 50, "Input"],
Cell[142883, 3804, 33626, 885, 143, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176546, 4694, 798, 17, 50, "Input"],
Cell[CellGroupData[{
Cell[177369, 4715, 436, 10, 30, "Print"],
Cell[177808, 4727, 404, 8, 30, "Print"],
Cell[178215, 4737, 420, 10, 30, "Print"],
Cell[178638, 4749, 518, 14, 30, "Print"],
Cell[179159, 4765, 402, 8, 30, "Print"],
Cell[179564, 4775, 418, 9, 30, "Print"],
Cell[179985, 4786, 527, 14, 30, "Print"],
Cell[180515, 4802, 400, 8, 30, "Print"],
Cell[180918, 4812, 424, 10, 30, "Print"],
Cell[181345, 4824, 505, 13, 30, "Print"],
Cell[181853, 4839, 399, 8, 30, "Print"],
Cell[182255, 4849, 418, 9, 30, "Print"],
Cell[182676, 4860, 556, 15, 30, "Print"],
Cell[183235, 4877, 402, 8, 30, "Print"],
Cell[183640, 4887, 418, 9, 30, "Print"],
Cell[184061, 4898, 556, 15, 30, "Print"],
Cell[184620, 4915, 402, 8, 30, "Print"],
Cell[185025, 4925, 418, 9, 30, "Print"],
Cell[185446, 4936, 530, 14, 30, "Print"],
Cell[185979, 4952, 402, 8, 30, "Print"],
Cell[186384, 4962, 420, 9, 30, "Print"],
Cell[186807, 4973, 480, 13, 30, "Print"],
Cell[187290, 4988, 404, 8, 30, "Print"],
Cell[187697, 4998, 422, 10, 30, "Print"],
Cell[188122, 5010, 418, 10, 30, "Print"],
Cell[188543, 5022, 406, 8, 30, "Print"],
Cell[188952, 5032, 414, 9, 30, "Print"],
Cell[189369, 5043, 486, 13, 30, "Print"],
Cell[189858, 5058, 404, 8, 30, "Print"],
Cell[190265, 5068, 424, 10, 30, "Print"]
}, Open  ]]
}, Open  ]],
Cell[190716, 5082, 349, 7, 50, "Input"],
Cell[CellGroupData[{
Cell[191090, 5093, 231, 4, 50, "Input"],
Cell[191324, 5099, 23466, 644, 464, "Output"]
}, Open  ]],
Cell[214805, 5746, 2773, 86, 125, "Input"],
Cell[CellGroupData[{
Cell[217603, 5836, 807, 19, 50, "Input"],
Cell[218413, 5857, 973, 24, 65, "Output"]
}, Open  ]],
Cell[219401, 5884, 244, 5, 50, "Input"],
Cell[CellGroupData[{
Cell[219670, 5893, 860, 23, 50, "Input"],
Cell[220533, 5918, 100338, 2691, 1586, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[320944, 8617, 179, 2, 92, "Section"],
Cell[321126, 8621, 340, 6, 61, "Text"],
Cell[321469, 8629, 96, 1, 50, "Input"],
Cell[CellGroupData[{
Cell[321590, 8634, 178, 2, 32, "Subsection"],
Cell[CellGroupData[{
Cell[321793, 8640, 122, 2, 50, "Input"],
Cell[CellGroupData[{
Cell[321940, 8646, 162, 2, 30, "Print"],
Cell[322105, 8650, 432, 10, 30, "Print"],
Cell[322540, 8662, 181, 2, 30, "Print"],
Cell[322724, 8666, 140, 1, 30, "Print"],
Cell[322867, 8669, 121, 1, 30, "Print"],
Cell[322991, 8672, 160, 2, 30, "Print"],
Cell[323154, 8676, 436, 10, 30, "Print"],
Cell[323593, 8688, 181, 2, 30, "Print"],
Cell[323777, 8692, 162, 2, 30, "Print"],
Cell[323942, 8696, 434, 10, 30, "Print"],
Cell[324379, 8708, 229, 3, 56, "Print"],
Cell[324611, 8713, 159, 2, 30, "Print"],
Cell[324773, 8717, 315, 4, 56, "Print"],
Cell[325091, 8723, 162, 2, 30, "Print"],
Cell[325256, 8727, 404, 9, 30, "Print"],
Cell[325663, 8738, 486, 10, 30, "Print"],
Cell[326152, 8750, 587, 10, 30, "Print"],
Cell[326742, 8762, 545, 10, 30, "Print"],
Cell[327290, 8774, 562, 10, 30, "Print"],
Cell[327855, 8786, 522, 11, 30, "Print"]
}, Open  ]]
}, Open  ]],
Cell[328404, 8801, 105, 1, 37, "Text"],
Cell[328512, 8804, 59, 1, 50, "Input"],
Cell[328574, 8807, 152, 3, 50, "Input"],
Cell[328729, 8812, 338, 6, 61, "Text"],
Cell[329070, 8820, 234, 6, 50, "Input"],
Cell[329307, 8828, 247, 5, 37, "Text"],
Cell[CellGroupData[{
Cell[329579, 8837, 225, 5, 50, "Input"],
Cell[329807, 8844, 619, 12, 30, "Print"]
}, Open  ]],
Cell[330441, 8859, 139, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[330605, 8864, 441, 9, 50, "Input"],
Cell[CellGroupData[{
Cell[331071, 8877, 677, 13, 30, "Print"],
Cell[331751, 8892, 687, 13, 30, "Print"]
}, Open  ]]
}, Open  ]],
Cell[332465, 8909, 136, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[332626, 8914, 415, 11, 50, "Input"],
Cell[CellGroupData[{
Cell[333066, 8929, 1034, 23, 30, "Print"],
Cell[334103, 8954, 1042, 23, 30, "Print"],
Cell[335148, 8979, 962, 21, 30, "Print"],
Cell[336113, 9002, 1082, 24, 30, "Print"],
Cell[337198, 9028, 1100, 25, 30, "Print"],
Cell[338301, 9055, 1126, 25, 30, "Print"],
Cell[339430, 9082, 1044, 23, 30, "Print"],
Cell[340477, 9107, 551, 10, 30, "Print"],
Cell[341031, 9119, 928, 19, 30, "Print"],
Cell[341962, 9140, 555, 10, 30, "Print"],
Cell[342520, 9152, 1060, 24, 30, "Print"],
Cell[343583, 9178, 1111, 24, 30, "Print"],
Cell[344697, 9204, 1052, 23, 30, "Print"],
Cell[345752, 9229, 940, 19, 30, "Print"],
Cell[346695, 9250, 838, 21, 30, "Print"],
Cell[347536, 9273, 830, 21, 30, "Print"],
Cell[348369, 9296, 842, 21, 30, "Print"],
Cell[349214, 9319, 944, 19, 30, "Print"],
Cell[350161, 9340, 491, 9, 30, "Print"]
}, Open  ]]
}, Open  ]],
Cell[350679, 9353, 207, 2, 37, "Text"],
Cell[350889, 9357, 567, 19, 151, "Input"],
Cell[351459, 9378, 364, 7, 61, "Text"],
Cell[CellGroupData[{
Cell[351848, 9389, 116, 2, 50, "Input"],
Cell[CellGroupData[{
Cell[351989, 9395, 993, 18, 30, "Print"],
Cell[352985, 9415, 1171, 22, 30, "Print"]
}, Open  ]]
}, Open  ]],
Cell[354183, 9441, 189, 4, 37, "Text"],
Cell[354375, 9447, 458, 13, 101, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[354870, 9465, 204, 2, 31, "Subsection"],
Cell[355077, 9469, 494, 8, 85, "Text"],
Cell[355574, 9479, 556, 13, 50, "Input"],
Cell[356133, 9494, 395, 12, 50, "Input"],
Cell[356531, 9508, 393, 12, 50, "Input"],
Cell[356927, 9522, 309, 6, 61, "Text"],
Cell[CellGroupData[{
Cell[357261, 9532, 656, 16, 50, "Input"],
Cell[357920, 9550, 1106, 20, 30, "Print"]
}, Open  ]],
Cell[359041, 9573, 226, 4, 37, "Text"],
Cell[359270, 9579, 813, 23, 50, "Input"],
Cell[360086, 9604, 261, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[360372, 9613, 318, 10, 50, "Input"],
Cell[360693, 9625, 299, 4, 30, "Print"],
Cell[360995, 9631, 9844, 264, 65, "Output"]
}, Open  ]],
Cell[370854, 9898, 1460, 39, 52, "Text"],
Cell[372317, 9939, 928, 30, 101, "Input"],
Cell[373248, 9971, 97, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[373370, 9976, 1285, 24, 50, "Input"],
Cell[374658, 10002, 523, 7, 30, "Print"],
Cell[375184, 10011, 9457, 266, 65, "Output"]
}, Open  ]],
Cell[384656, 10280, 495, 8, 85, "Text"],
Cell[CellGroupData[{
Cell[385176, 10292, 805, 24, 50, "Input"],
Cell[385984, 10318, 5503, 153, 52, "Output"]
}, Open  ]],
Cell[391502, 10474, 188, 2, 37, "Text"],
Cell[CellGroupData[{
Cell[391715, 10480, 612, 16, 50, "Input"],
Cell[392330, 10498, 4124, 117, 52, "Output"]
}, Open  ]],
Cell[396469, 10618, 111, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[396605, 10623, 133, 2, 50, "Input"],
Cell[396741, 10627, 12425, 343, 65, "Output"]
}, Open  ]],
Cell[409181, 10973, 275, 6, 37, "Text"],
Cell[CellGroupData[{
Cell[409481, 10983, 387, 12, 50, "Input"],
Cell[409871, 10997, 708, 15, 30, "Print"]
}, Open  ]],
Cell[410594, 11015, 128, 3, 37, "Text"],
Cell[410725, 11020, 553, 19, 50, "Input"],
Cell[411281, 11041, 135, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[411441, 11046, 186, 6, 50, "Input"],
Cell[411630, 11054, 250, 3, 30, "Print"]
}, Open  ]],
Cell[411895, 11060, 224, 4, 37, "Text"],
Cell[412122, 11066, 125, 4, 50, "Input"],
Cell[412250, 11072, 102, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[412377, 11077, 96, 2, 50, "Input"],
Cell[412476, 11081, 12378, 342, 65, "Output"]
}, Open  ]],
Cell[424869, 11426, 123, 1, 37, "Text"],
Cell[424995, 11429, 624, 18, 76, "Input"],
Cell[CellGroupData[{
Cell[425644, 11451, 137, 2, 50, "Input"],
Cell[425784, 11455, 12399, 343, 65, "Output"]
}, Open  ]],
Cell[438198, 11801, 143, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[438366, 11806, 661, 22, 50, "Input"],
Cell[439030, 11830, 4293, 120, 52, "Output"]
}, Open  ]],
Cell[443338, 11953, 464, 14, 50, "Input"],
Cell[443805, 11969, 173, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[444003, 11977, 134, 2, 50, "Input"],
Cell[444140, 11981, 12377, 342, 65, "Output"]
}, Open  ]],
Cell[456532, 12326, 211, 4, 37, "Text"],
Cell[456746, 12332, 186, 5, 50, "Input"],
Cell[456935, 12339, 195, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[457155, 12347, 387, 12, 50, "Input"],
Cell[457545, 12361, 756, 15, 30, "Print"]
}, Open  ]],
Cell[458316, 12379, 553, 19, 50, "Input"],
Cell[458872, 12400, 132, 1, 37, "Text"],
Cell[459007, 12403, 324, 10, 76, "Input"],
Cell[CellGroupData[{
Cell[459356, 12417, 312, 6, 50, "Input"],
Cell[459671, 12425, 278, 4, 30, "Print"],
Cell[459952, 12431, 9869, 264, 65, "Output"]
}, Open  ]],
Cell[469836, 12698, 673, 19, 76, "Input"],
Cell[CellGroupData[{
Cell[470534, 12721, 138, 2, 50, "Input"],
Cell[470675, 12725, 8272, 228, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[478984, 12958, 714, 23, 50, "Input"],
Cell[479701, 12983, 4319, 121, 52, "Output"]
}, Open  ]],
Cell[484035, 13107, 462, 14, 50, "Input"],
Cell[CellGroupData[{
Cell[484522, 13125, 70, 1, 50, "Input"],
Cell[484595, 13128, 12327, 341, 65, "Output"]
}, Open  ]],
Cell[496937, 13472, 311, 9, 76, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[497285, 13486, 120, 1, 31, "Subsection"],
Cell[497408, 13489, 127, 1, 37, "Text"],
Cell[497538, 13492, 461, 14, 101, "Input"],
Cell[498002, 13508, 188, 4, 37, "Text"],
Cell[498193, 13514, 1394, 42, 126, "Input"],
Cell[499590, 13558, 121, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[499736, 13563, 947, 14, 50, "Input"],
Cell[500686, 13579, 1932, 46, 65, "Output"]
}, Open  ]],
Cell[502633, 13628, 103, 1, 37, "Text"],
Cell[502739, 13631, 1051, 37, 126, "Input"],
Cell[CellGroupData[{
Cell[503815, 13672, 457, 10, 50, "Input"],
Cell[504275, 13684, 734, 10, 30, "Print"]
}, Open  ]],
Cell[505024, 13697, 125, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[505174, 13705, 164, 3, 50, "Input"],
Cell[505341, 13710, 1455, 39, 65, "Output"]
}, Open  ]],
Cell[506811, 13752, 186, 5, 50, "Input"],
Cell[507000, 13759, 261, 5, 61, "Text"],
Cell[507264, 13766, 145, 5, 50, "Input"],
Cell[507412, 13773, 158, 3, 37, "Text"],
Cell[507573, 13778, 421, 15, 50, "Input"],
Cell[507997, 13795, 130, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[508152, 13800, 569, 19, 50, "Input"],
Cell[508724, 13821, 328, 5, 30, "Print"],
Cell[509055, 13828, 21103, 589, 107, "Output"]
}, Open  ]],
Cell[530173, 14420, 114, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[530312, 14425, 222, 5, 50, "Input"],
Cell[530537, 14432, 638, 12, 30, "Print"]
}, Open  ]],
Cell[531190, 14447, 139, 1, 37, "Text"],
Cell[531332, 14450, 215, 6, 50, "Input"],
Cell[531550, 14458, 288, 6, 61, "Text"],
Cell[CellGroupData[{
Cell[531863, 14468, 824, 16, 50, "Input"],
Cell[532690, 14486, 871, 12, 30, "Print"],
Cell[533564, 14500, 6494, 173, 52, "Output"]
}, Open  ]],
Cell[540073, 14676, 128, 1, 37, "Text"],
Cell[540204, 14679, 1102, 38, 126, "Input"],
Cell[CellGroupData[{
Cell[541331, 14721, 505, 10, 50, "Input"],
Cell[541839, 14733, 760, 10, 30, "Print"]
}, Open  ]],
Cell[542614, 14746, 324, 10, 76, "Input"],
Cell[CellGroupData[{
Cell[542963, 14760, 214, 4, 50, "Input"],
Cell[543180, 14766, 1479, 39, 65, "Output"]
}, Open  ]],
Cell[544674, 14808, 1165, 33, 126, "Input"],
Cell[545842, 14843, 326, 6, 61, "Text"],
Cell[546171, 14851, 1843, 62, 151, "Input"],
Cell[548017, 14915, 294, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[548336, 14924, 418, 10, 50, "Input"],
Cell[548757, 14936, 235, 3, 30, "Print"],
Cell[548995, 14941, 9319, 265, 65, "Output"]
}, Open  ]],
Cell[558329, 15209, 286, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[558640, 15218, 235, 5, 50, "Input"],
Cell[558878, 15225, 9148, 264, 65, "Output"]
}, Open  ]],
Cell[568041, 15492, 201, 4, 37, "Text"],
Cell[568245, 15498, 4514, 143, 201, "Input"],
Cell[572762, 15643, 206, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[572993, 15651, 635, 19, 50, "Input"],
Cell[573631, 15672, 400, 6, 30, "Print"],
Cell[574034, 15680, 251739, 7164, 826, "Output"]
}, Open  ]],
Cell[825788, 22847, 109, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[825922, 22852, 504, 12, 50, "Input"],
Cell[826429, 22866, 372, 6, 30, "Print"],
Cell[826804, 22874, 4426, 112, 65, "Output"]
}, Open  ]],
Cell[831245, 22989, 303, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[831573, 22998, 726, 23, 76, "Input"],
Cell[832302, 23023, 454, 10, 28, "Message"],
Cell[832759, 23035, 454, 10, 28, "Message"],
Cell[833216, 23047, 456, 10, 28, "Message"],
Cell[833675, 23059, 683, 12, 28, "Message"],
Cell[834361, 23073, 133, 2, 30, "Print"],
Cell[834497, 23077, 119286, 2917, 231, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[953832, 26000, 263, 3, 31, "Subsection"],
Cell[954098, 26005, 393, 8, 61, "Text"],
Cell[954494, 26015, 664, 21, 101, "Input"],
Cell[955161, 26038, 134, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[955320, 26043, 178, 6, 50, "Input"],
Cell[955501, 26051, 609, 13, 30, "Print"]
}, Open  ]],
Cell[956125, 26067, 112, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[956262, 26072, 295, 8, 50, "Input"],
Cell[956560, 26082, 3220, 91, 61, "Output"]
}, Open  ]],
Cell[959795, 26176, 133, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[959953, 26181, 589, 15, 50, "Input"],
Cell[960545, 26198, 3501, 101, 52, "Output"]
}, Open  ]],
Cell[964061, 26302, 231, 5, 37, "Text"],
Cell[CellGroupData[{
Cell[964317, 26311, 229, 7, 50, "Input"],
Cell[964549, 26320, 8681, 242, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[973267, 26567, 594, 15, 50, "Input"],
Cell[973864, 26584, 21802, 631, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[995703, 27220, 294, 8, 50, "Input"],
Cell[996000, 27230, 18904, 516, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1014941, 27751, 591, 15, 50, "Input"],
Cell[1015535, 27768, 158, 2, 30, "Print"],
Cell[1015696, 27772, 110093, 3176, 187, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1125826, 30953, 271, 8, 50, "Input"],
Cell[1126100, 30963, 38343, 1030, 117, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
